{
 "metadata": {
  "name": "",
  "signature": "sha256:818a4a74de89f7d6535437da31fe5b3add5fd9d0e11a4539fd2cfbbd1e8039e4"
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## Simple legend example\n",
      "\n",
      "This is the simplest use case for the plugin. We plot a few lines, instantiate the InteractiveLegendPlugin, and connect it to the figure. Note that we pass the labels for each of the lines explicitly. At the moment the label information of matplotlib is not passed along to D3. The plugin creates a legend to the right of the axes starting at the top. Each of the rectangles is clickable. When a legend item is selected, the rectangle is filled. \n"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "import mpld3\n",
      "from mpld3 import plugins\n",
      "from mpld3.utils import get_id\n",
      "import numpy as np\n",
      "import collections\n",
      "import matplotlib.pyplot as plt\n",
      "\n",
      "N_paths = 5\n",
      "N_steps = 100\n",
      "\n",
      "x = np.linspace(0, 10, 100)\n",
      "y = 0.1 * (np.random.random((N_paths, N_steps)) - 0.5)\n",
      "y = y.cumsum(1)\n",
      "\n",
      "fig, ax = plt.subplots()\n",
      "labels = [\"a\", \"b\", \"c\", \"d\", \"e\"]\n",
      "line_collections = ax.plot(x, y.T, lw=4, alpha=0.2)\n",
      "interactive_legend = plugins.InteractiveLegendPlugin(line_collections, labels)\n",
      "plugins.connect(fig, interactive_legend)\n",
      "\n",
      "mpld3.display()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "    .legend-box {\n",
        "      cursor: pointer;\n",
        "    }\n",
        "    \n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el1007545265792807069247217\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "       mpld3.draw_figure(\"fig_el1007545265792807069247217\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.30000000000000004, 0.69999999999999996], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754534840272\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535039632\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535040208\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535040656\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535041104\"}], \"markers\": [], \"id\": \"el100754534887760\", \"ydomain\": [-0.30000000000000004, 0.69999999999999996], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754534840272\", \"el100754534840272pts\"], [\"el100754535039632\", \"el100754535039632pts\"], [\"el100754535040208\", \"el100754535040208pts\"], [\"el100754535040656\", \"el100754535040656pts\"], [\"el100754535041104\", \"el100754535041104pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.01677784045871993, 0.01806442896779976, 0.026166937620281352, -0.024923718577488853, 0.04013046245768698], [0.10101010101010101, -0.019010427718803204, -0.009339950045466464, 0.023726200281504253, -0.0331983988051074, 0.05088494470600032], [0.20202020202020202, 0.007520520551093944, 0.02557012098500778, 0.011884189212601816, -0.05058772148993354, 0.06863911002640805], [0.30303030303030304, -0.03635916655754746, 0.06552237542228453, 0.0003510123133521406, -0.027302445083306273, 0.07078009582441927], [0.40404040404040403, 0.004314751821206629, 0.02524247894959533, -0.041377591149690564, 0.017999024281248333, 0.05728472960825523], [0.5050505050505051, 0.013244806218959326, 0.009003004971218725, -0.06123778436888614, 0.020039107663893007, 0.07637242311641029], [0.6060606060606061, 0.025371332948594272, 0.04139705388428942, -0.033121790652953995, -0.00040529889666890764, 0.09714621454008088], [0.7070707070707071, 0.05661027525086659, 0.00023211068643043398, -0.0496577461679167, 0.01180460413250651, 0.06940540337258212], [0.8080808080808081, 0.009752189436718614, -0.0374202718691629, -0.06953387540656573, -0.032312407970813965, 0.02274646444084131], [0.9090909090909091, 0.04741658559146038, -0.055186333124770746, -0.04164284505297457, 0.001086969439962636, 0.020390789636867603], [1.0101010101010102, 0.01569416202804092, -0.011820052010319958, -0.0459136715284825, 0.040788825914854075, 0.010563404582883585], [1.1111111111111112, -0.02255968121375311, 0.034908775559522126, -0.07979860931209234, 0.0540402222116906, -0.0028900582303800996], [1.2121212121212122, -0.05313963197179153, 0.014930028460955563, -0.07972558231756242, 0.02872176772144048, -0.012771875572369352], [1.3131313131313131, -0.08050390424461916, 0.06473003095115719, -0.0670937590047745, -0.010035882459713867, 0.021894194253673737], [1.4141414141414141, -0.09571307286047688, 0.040179947865303614, -0.022952048888230672, -0.006188902943942035, 0.05497413486408406], [1.5151515151515151, -0.06135628067511669, 0.07987341624583545, 0.011687675019073751, -0.03653573129100646, 0.10230895889480539], [1.6161616161616161, -0.10596181091549992, 0.03767724468975638, -0.03240046488947358, -0.07141156399907003, 0.08042264476494629], [1.7171717171717171, -0.11407334790567397, 0.07081227807410422, -0.05906517604884441, -0.05953357839496097, 0.08311492413854432], [1.8181818181818181, -0.0735037361535465, 0.10831927653785796, -0.052222218497341065, -0.06389473086863208, 0.05740929911335587], [1.9191919191919191, -0.10495050853071608, 0.07114368525682552, -0.09425686845215554, -0.10932881059729171, 0.09245137810941713], [2.0202020202020203, -0.08269799090068017, 0.1168389141786503, -0.1089566306896795, -0.13355433435178546, 0.04659067928134504], [2.121212121212121, -0.11605436928358967, 0.08484170252999645, -0.07025240195391935, -0.18223903927903645, 0.06444501246352263], [2.2222222222222223, -0.12303801503839325, 0.11795700695888409, -0.043231016088033716, -0.15128068789681887, 0.09107600053058862], [2.323232323232323, -0.09396231504354813, 0.1467762983987218, -0.07581565841762479, -0.12163359290125908, 0.09590164060283968], [2.4242424242424243, -0.07502380353642504, 0.19106897339821, -0.05073515730013253, -0.1509631197348789, 0.04849717337710214], [2.525252525252525, -0.07034772018758945, 0.21553817145105486, -0.02050248170283579, -0.1998295045623508, 0.03207299481348276], [2.6262626262626263, -0.05754457721209381, 0.16675943239786503, -0.054167319494348484, -0.1950736914582679, 0.002153250225140159], [2.727272727272727, -0.029421423684566506, 0.19168048867178264, -0.03825473313779427, -0.15792546194513904, 0.017293386543379377], [2.8282828282828283, -0.05270402620477231, 0.23538052203290283, -0.06349638901184688, -0.17491272344892722, 0.009018056678024003], [2.929292929292929, -0.03263054013201232, 0.2007245055572402, -0.06024358310434821, -0.1756604523335887, -0.0031244705192199768], [3.0303030303030303, -0.01605079864169657, 0.22694385883206464, -0.08478810404646307, -0.1307404771190147, -0.00764441292179778], [3.131313131313131, 0.007967020113755913, 0.22003752829611933, -0.0879131761867085, -0.09649725744778095, 0.03969088528138636], [3.2323232323232323, -0.03280317801544969, 0.19769436345488445, -0.07637936566100939, -0.05330743874116178, 0.06462032760402298], [3.3333333333333335, -0.004477476007675389, 0.23095271350935812, -0.12084712541766236, -0.059982562551519694, 0.10742600577610142], [3.4343434343434343, -0.012271038149095196, 0.2548417653394151, -0.11099386372969014, -0.08998713716205725, 0.12117047115716194], [3.5353535353535355, 0.02692080439322021, 0.26395306623216896, -0.06862278504263356, -0.10023247515778261, 0.0921256153425158], [3.6363636363636362, -0.010868236573583958, 0.2722283831600947, -0.022485396895276594, -0.12028063434880594, 0.07144450895183496], [3.7373737373737375, -0.048980516937344745, 0.3144041431131827, -0.04825494117758225, -0.12038477529883283, 0.11098812892855667], [3.8383838383838382, -0.02366865277288449, 0.2878725342850316, -0.0281484818945577, -0.1697190201812837, 0.12252078111947654], [3.9393939393939394, -0.008031836257424707, 0.3333658263361184, -0.04317915314108842, -0.13304315213216622, 0.0974831116616411], [4.040404040404041, -0.0009719418812316194, 0.31033490921591506, -0.05164305561711712, -0.11374693209946685, 0.13159413713104992], [4.141414141414141, -0.010416898730140357, 0.35166529920714373, -0.06330034916853983, -0.09541900901066293, 0.14617766542781935], [4.242424242424242, 0.02308244568497548, 0.38203858943493724, -0.01654316540387768, -0.07508129355396653, 0.1629192576893463], [4.343434343434343, 0.014757768446967462, 0.40695980837436624, 0.0013399714980799407, -0.09096730815771148, 0.14029195907932834], [4.444444444444445, 0.038064803381142175, 0.41080752190846714, -0.012147611588628603, -0.09060708758587202, 0.13823979516222615], [4.545454545454545, 0.0033948651377890895, 0.4297288056652724, 0.008921586481357682, -0.1039049938729425, 0.15938266817702462], [4.646464646464646, -0.03818021709299843, 0.4444385330325871, 0.056016981174061176, -0.14228747875547437, 0.14316832751309086], [4.747474747474747, -0.07046763953393251, 0.4305330168559233, 0.03130009514528462, -0.19112460823209296, 0.13712682664297848], [4.848484848484849, -0.09008251633011466, 0.4297925026130274, 0.008716518299343418, -0.20951773047385075, 0.09347786075873729], [4.94949494949495, -0.1227800695166952, 0.41588377353980993, 0.015865321527938476, -0.23185357948362387, 0.050442451965388525], [5.05050505050505, -0.10063278388920724, 0.42334824149925293, 0.011644348314410597, -0.2563852677558308, 0.026850966254564623], [5.151515151515151, -0.07899662594604578, 0.47278617396060385, -0.023198843870607517, -0.2635235544867182, 0.05870647421625921], [5.252525252525253, -0.11752269611737831, 0.4749416205982514, 0.021268235082630853, -0.2605906454923125, 0.09566026317605415], [5.353535353535354, -0.1239534159651265, 0.46463624557416844, 0.020332950346656647, -0.22922916716766062, 0.07235420271843754], [5.454545454545454, -0.09535969701155926, 0.4444353900182764, 0.002545992225393992, -0.19824160310672007, 0.04204824094519578], [5.555555555555555, -0.07954996393942743, 0.4007061752832129, -0.035392741727166686, -0.2181001124576845, 0.00724471256362904], [5.656565656565657, -0.08844944032080872, 0.3883826547853665, -0.06002840489306699, -0.18594136439754225, -0.0003352336382978511], [5.757575757575758, -0.046900093260268116, 0.43223301189023566, -0.029793998546929743, -0.14525842531226899, -0.025235671592759523], [5.858585858585858, -0.0027312370312007617, 0.4552272743767757, -0.016899622302926916, -0.11222634046850505, -0.0039371145121524925], [5.959595959595959, 0.02698174253426874, 0.498586805924525, -0.04135549609693381, -0.1348546185085486, 0.043646554110552155], [6.0606060606060606, -0.00756235304467635, 0.5336578857305774, -0.017272759447941287, -0.08776954740902043, 0.0007834455432850496], [6.161616161616162, -0.054333650111764956, 0.515435343497819, 0.0009389983120029824, -0.07394730799104116, 0.0017252666125207095], [6.262626262626262, -0.04877565721461598, 0.5596765087970286, 0.02904575911610039, -0.07008991604142775, -0.028772174899200302], [6.363636363636363, -0.06171756301621753, 0.5750809846288243, 0.01023332953256605, -0.10289783674554759, -0.038687271295016326], [6.4646464646464645, -0.0664496254168696, 0.5464635971501387, -0.013714974794487255, -0.11466252846737107, -0.07134715714088533], [6.565656565656566, -0.03895791048437139, 0.5287424284137858, 0.028438050017853257, -0.07739091418488461, -0.049145871262067944], [6.666666666666667, -0.05683026504382227, 0.5212423117564362, 0.014675561957732886, -0.11022310713195435, -0.062330446835056875], [6.767676767676767, -0.016717152773040644, 0.5145342683185772, 0.04081355063115936, -0.06981799829344554, -0.0398569737810317], [6.8686868686868685, -0.0643435422665426, 0.5145702735357306, 0.08348104139319473, -0.04483720028785173, -0.049576611635298785], [6.96969696969697, -0.025408603838279552, 0.5542165350544352, 0.06456654768796949, -0.09370667822169973, -0.006371152501819008], [7.070707070707071, -0.059088602482838, 0.513839915713012, 0.10467324834290632, -0.05435420130275133, -0.023738611144977738], [7.171717171717171, -0.03837855129669279, 0.557783331281617, 0.07259259246861244, -0.014354398548344013, -0.05324620456405508], [7.2727272727272725, -0.051717326357281115, 0.6028672749079622, 0.04259563396520677, -0.009888391442990072, -0.008820437331778994], [7.373737373737374, -0.01536827966050415, 0.5598950160940432, 0.02212575322145419, -0.03739556019586232, 0.03532623118105999], [7.474747474747475, 0.0313539803652332, 0.5673740544273383, -0.00970011586136978, -0.028047212091982, 0.023699819183343913], [7.575757575757575, 0.030234946339973555, 0.5808925569869406, 0.012350149627934466, 0.008672051875525708, 0.025927340068537603], [7.6767676767676765, 0.057008023056710655, 0.6080408444021598, -0.027816996651782597, 0.04815356445633524, 0.07532500767261129], [7.777777777777778, 0.038739107129957304, 0.6084633937589834, -0.02144228380145847, 0.025075286002195732, 0.1228620764811755], [7.878787878787879, 0.08782824475495124, 0.598466807341982, 0.018080307884775847, 0.0315515991097075, 0.09674038356166718], [7.979797979797979, 0.041625431636574464, 0.5917543705565507, 0.0025958835507780085, -0.008803226212588722, 0.1422153872121711], [8.080808080808081, 0.00044646718762740567, 0.6030335725981733, 0.047462593729999815, -0.01986126722430881, 0.11924001244910698], [8.181818181818182, 0.006871497165874827, 0.5844284623750393, 0.08199045939412886, -0.0354645299560856, 0.08650696485224617], [8.282828282828282, -0.010401355925078086, 0.5785219222084881, 0.0910136414344528, 0.010998589497144676, 0.10330470708388996], [8.383838383838384, -0.017121280023205503, 0.601821797877215, 0.08082943802775613, -0.017709572487789302, 0.10921182503624853], [8.484848484848484, 0.028982543857982192, 0.5567649830272804, 0.10530026888679661, -0.0017964619406506468, 0.06947494722700875], [8.585858585858587, -0.007622856953925505, 0.5622077316989748, 0.06558371935101857, -0.03937427313861478, 0.08743078874557637], [8.686868686868687, -0.04794656704535524, 0.5235931104852414, 0.07232703141783073, -0.08410633356623301, 0.12093092041321364], [8.787878787878787, -0.08276738247355689, 0.5517608188159515, 0.0999813244188178, -0.12673952578518569, 0.13904389989206276], [8.88888888888889, -0.07797828673273287, 0.5472117561375607, 0.11555846060622565, -0.08522178354712359, 0.13063270251945594], [8.98989898989899, -0.07773391807632764, 0.5690962640832263, 0.12678744156122773, -0.03621633386282498, 0.17356199190805224], [9.09090909090909, -0.07487334611246527, 0.545118137797985, 0.09788839406315349, -0.03514208335133661, 0.1667110472243109], [9.191919191919192, -0.04585287925221192, 0.5376620708311213, 0.09788252425796067, 0.006900318283921333, 0.14353211308755914], [9.292929292929292, -0.0955544453944371, 0.5515605694321465, 0.054707160595279775, -0.008550284598436979, 0.10137264194614656], [9.393939393939394, -0.12454820787447593, 0.5386414878716467, 0.060984516925105495, -0.03292385436418278, 0.11663610917404593], [9.494949494949495, -0.0862620478048943, 0.5084668068077662, 0.07150548570369555, -0.01947305929687608, 0.1624257780322783], [9.595959595959595, -0.058668914948489526, 0.5339227673448799, 0.032312955267366696, 0.01748554793505977, 0.16509801329152218], [9.696969696969697, -0.08352422932226397, 0.5630959451921492, 0.05134633588047691, 0.021831588175602608, 0.21257824400799266], [9.797979797979798, -0.06115124319686115, 0.5992438205876706, 0.0918207464299871, -0.02698161086960018, 0.2528617678911851], [9.8989898989899, -0.09203042899024727, 0.5970803742581964, 0.08719466259985607, -0.0476132192895813, 0.2950712025907572], [10.0, -0.0986516862471709, 0.5505893550536144, 0.06921333307843593, -0.07452692199300451, 0.3374869036686362]]}, \"id\": \"el100754526579280\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "         \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "         mpld3.draw_figure(\"fig_el1007545265792807069247217\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.30000000000000004, 0.69999999999999996], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754534840272\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535039632\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535040208\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535040656\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535041104\"}], \"markers\": [], \"id\": \"el100754534887760\", \"ydomain\": [-0.30000000000000004, 0.69999999999999996], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754534840272\", \"el100754534840272pts\"], [\"el100754535039632\", \"el100754535039632pts\"], [\"el100754535040208\", \"el100754535040208pts\"], [\"el100754535040656\", \"el100754535040656pts\"], [\"el100754535041104\", \"el100754535041104pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.01677784045871993, 0.01806442896779976, 0.026166937620281352, -0.024923718577488853, 0.04013046245768698], [0.10101010101010101, -0.019010427718803204, -0.009339950045466464, 0.023726200281504253, -0.0331983988051074, 0.05088494470600032], [0.20202020202020202, 0.007520520551093944, 0.02557012098500778, 0.011884189212601816, -0.05058772148993354, 0.06863911002640805], [0.30303030303030304, -0.03635916655754746, 0.06552237542228453, 0.0003510123133521406, -0.027302445083306273, 0.07078009582441927], [0.40404040404040403, 0.004314751821206629, 0.02524247894959533, -0.041377591149690564, 0.017999024281248333, 0.05728472960825523], [0.5050505050505051, 0.013244806218959326, 0.009003004971218725, -0.06123778436888614, 0.020039107663893007, 0.07637242311641029], [0.6060606060606061, 0.025371332948594272, 0.04139705388428942, -0.033121790652953995, -0.00040529889666890764, 0.09714621454008088], [0.7070707070707071, 0.05661027525086659, 0.00023211068643043398, -0.0496577461679167, 0.01180460413250651, 0.06940540337258212], [0.8080808080808081, 0.009752189436718614, -0.0374202718691629, -0.06953387540656573, -0.032312407970813965, 0.02274646444084131], [0.9090909090909091, 0.04741658559146038, -0.055186333124770746, -0.04164284505297457, 0.001086969439962636, 0.020390789636867603], [1.0101010101010102, 0.01569416202804092, -0.011820052010319958, -0.0459136715284825, 0.040788825914854075, 0.010563404582883585], [1.1111111111111112, -0.02255968121375311, 0.034908775559522126, -0.07979860931209234, 0.0540402222116906, -0.0028900582303800996], [1.2121212121212122, -0.05313963197179153, 0.014930028460955563, -0.07972558231756242, 0.02872176772144048, -0.012771875572369352], [1.3131313131313131, -0.08050390424461916, 0.06473003095115719, -0.0670937590047745, -0.010035882459713867, 0.021894194253673737], [1.4141414141414141, -0.09571307286047688, 0.040179947865303614, -0.022952048888230672, -0.006188902943942035, 0.05497413486408406], [1.5151515151515151, -0.06135628067511669, 0.07987341624583545, 0.011687675019073751, -0.03653573129100646, 0.10230895889480539], [1.6161616161616161, -0.10596181091549992, 0.03767724468975638, -0.03240046488947358, -0.07141156399907003, 0.08042264476494629], [1.7171717171717171, -0.11407334790567397, 0.07081227807410422, -0.05906517604884441, -0.05953357839496097, 0.08311492413854432], [1.8181818181818181, -0.0735037361535465, 0.10831927653785796, -0.052222218497341065, -0.06389473086863208, 0.05740929911335587], [1.9191919191919191, -0.10495050853071608, 0.07114368525682552, -0.09425686845215554, -0.10932881059729171, 0.09245137810941713], [2.0202020202020203, -0.08269799090068017, 0.1168389141786503, -0.1089566306896795, -0.13355433435178546, 0.04659067928134504], [2.121212121212121, -0.11605436928358967, 0.08484170252999645, -0.07025240195391935, -0.18223903927903645, 0.06444501246352263], [2.2222222222222223, -0.12303801503839325, 0.11795700695888409, -0.043231016088033716, -0.15128068789681887, 0.09107600053058862], [2.323232323232323, -0.09396231504354813, 0.1467762983987218, -0.07581565841762479, -0.12163359290125908, 0.09590164060283968], [2.4242424242424243, -0.07502380353642504, 0.19106897339821, -0.05073515730013253, -0.1509631197348789, 0.04849717337710214], [2.525252525252525, -0.07034772018758945, 0.21553817145105486, -0.02050248170283579, -0.1998295045623508, 0.03207299481348276], [2.6262626262626263, -0.05754457721209381, 0.16675943239786503, -0.054167319494348484, -0.1950736914582679, 0.002153250225140159], [2.727272727272727, -0.029421423684566506, 0.19168048867178264, -0.03825473313779427, -0.15792546194513904, 0.017293386543379377], [2.8282828282828283, -0.05270402620477231, 0.23538052203290283, -0.06349638901184688, -0.17491272344892722, 0.009018056678024003], [2.929292929292929, -0.03263054013201232, 0.2007245055572402, -0.06024358310434821, -0.1756604523335887, -0.0031244705192199768], [3.0303030303030303, -0.01605079864169657, 0.22694385883206464, -0.08478810404646307, -0.1307404771190147, -0.00764441292179778], [3.131313131313131, 0.007967020113755913, 0.22003752829611933, -0.0879131761867085, -0.09649725744778095, 0.03969088528138636], [3.2323232323232323, -0.03280317801544969, 0.19769436345488445, -0.07637936566100939, -0.05330743874116178, 0.06462032760402298], [3.3333333333333335, -0.004477476007675389, 0.23095271350935812, -0.12084712541766236, -0.059982562551519694, 0.10742600577610142], [3.4343434343434343, -0.012271038149095196, 0.2548417653394151, -0.11099386372969014, -0.08998713716205725, 0.12117047115716194], [3.5353535353535355, 0.02692080439322021, 0.26395306623216896, -0.06862278504263356, -0.10023247515778261, 0.0921256153425158], [3.6363636363636362, -0.010868236573583958, 0.2722283831600947, -0.022485396895276594, -0.12028063434880594, 0.07144450895183496], [3.7373737373737375, -0.048980516937344745, 0.3144041431131827, -0.04825494117758225, -0.12038477529883283, 0.11098812892855667], [3.8383838383838382, -0.02366865277288449, 0.2878725342850316, -0.0281484818945577, -0.1697190201812837, 0.12252078111947654], [3.9393939393939394, -0.008031836257424707, 0.3333658263361184, -0.04317915314108842, -0.13304315213216622, 0.0974831116616411], [4.040404040404041, -0.0009719418812316194, 0.31033490921591506, -0.05164305561711712, -0.11374693209946685, 0.13159413713104992], [4.141414141414141, -0.010416898730140357, 0.35166529920714373, -0.06330034916853983, -0.09541900901066293, 0.14617766542781935], [4.242424242424242, 0.02308244568497548, 0.38203858943493724, -0.01654316540387768, -0.07508129355396653, 0.1629192576893463], [4.343434343434343, 0.014757768446967462, 0.40695980837436624, 0.0013399714980799407, -0.09096730815771148, 0.14029195907932834], [4.444444444444445, 0.038064803381142175, 0.41080752190846714, -0.012147611588628603, -0.09060708758587202, 0.13823979516222615], [4.545454545454545, 0.0033948651377890895, 0.4297288056652724, 0.008921586481357682, -0.1039049938729425, 0.15938266817702462], [4.646464646464646, -0.03818021709299843, 0.4444385330325871, 0.056016981174061176, -0.14228747875547437, 0.14316832751309086], [4.747474747474747, -0.07046763953393251, 0.4305330168559233, 0.03130009514528462, -0.19112460823209296, 0.13712682664297848], [4.848484848484849, -0.09008251633011466, 0.4297925026130274, 0.008716518299343418, -0.20951773047385075, 0.09347786075873729], [4.94949494949495, -0.1227800695166952, 0.41588377353980993, 0.015865321527938476, -0.23185357948362387, 0.050442451965388525], [5.05050505050505, -0.10063278388920724, 0.42334824149925293, 0.011644348314410597, -0.2563852677558308, 0.026850966254564623], [5.151515151515151, -0.07899662594604578, 0.47278617396060385, -0.023198843870607517, -0.2635235544867182, 0.05870647421625921], [5.252525252525253, -0.11752269611737831, 0.4749416205982514, 0.021268235082630853, -0.2605906454923125, 0.09566026317605415], [5.353535353535354, -0.1239534159651265, 0.46463624557416844, 0.020332950346656647, -0.22922916716766062, 0.07235420271843754], [5.454545454545454, -0.09535969701155926, 0.4444353900182764, 0.002545992225393992, -0.19824160310672007, 0.04204824094519578], [5.555555555555555, -0.07954996393942743, 0.4007061752832129, -0.035392741727166686, -0.2181001124576845, 0.00724471256362904], [5.656565656565657, -0.08844944032080872, 0.3883826547853665, -0.06002840489306699, -0.18594136439754225, -0.0003352336382978511], [5.757575757575758, -0.046900093260268116, 0.43223301189023566, -0.029793998546929743, -0.14525842531226899, -0.025235671592759523], [5.858585858585858, -0.0027312370312007617, 0.4552272743767757, -0.016899622302926916, -0.11222634046850505, -0.0039371145121524925], [5.959595959595959, 0.02698174253426874, 0.498586805924525, -0.04135549609693381, -0.1348546185085486, 0.043646554110552155], [6.0606060606060606, -0.00756235304467635, 0.5336578857305774, -0.017272759447941287, -0.08776954740902043, 0.0007834455432850496], [6.161616161616162, -0.054333650111764956, 0.515435343497819, 0.0009389983120029824, -0.07394730799104116, 0.0017252666125207095], [6.262626262626262, -0.04877565721461598, 0.5596765087970286, 0.02904575911610039, -0.07008991604142775, -0.028772174899200302], [6.363636363636363, -0.06171756301621753, 0.5750809846288243, 0.01023332953256605, -0.10289783674554759, -0.038687271295016326], [6.4646464646464645, -0.0664496254168696, 0.5464635971501387, -0.013714974794487255, -0.11466252846737107, -0.07134715714088533], [6.565656565656566, -0.03895791048437139, 0.5287424284137858, 0.028438050017853257, -0.07739091418488461, -0.049145871262067944], [6.666666666666667, -0.05683026504382227, 0.5212423117564362, 0.014675561957732886, -0.11022310713195435, -0.062330446835056875], [6.767676767676767, -0.016717152773040644, 0.5145342683185772, 0.04081355063115936, -0.06981799829344554, -0.0398569737810317], [6.8686868686868685, -0.0643435422665426, 0.5145702735357306, 0.08348104139319473, -0.04483720028785173, -0.049576611635298785], [6.96969696969697, -0.025408603838279552, 0.5542165350544352, 0.06456654768796949, -0.09370667822169973, -0.006371152501819008], [7.070707070707071, -0.059088602482838, 0.513839915713012, 0.10467324834290632, -0.05435420130275133, -0.023738611144977738], [7.171717171717171, -0.03837855129669279, 0.557783331281617, 0.07259259246861244, -0.014354398548344013, -0.05324620456405508], [7.2727272727272725, -0.051717326357281115, 0.6028672749079622, 0.04259563396520677, -0.009888391442990072, -0.008820437331778994], [7.373737373737374, -0.01536827966050415, 0.5598950160940432, 0.02212575322145419, -0.03739556019586232, 0.03532623118105999], [7.474747474747475, 0.0313539803652332, 0.5673740544273383, -0.00970011586136978, -0.028047212091982, 0.023699819183343913], [7.575757575757575, 0.030234946339973555, 0.5808925569869406, 0.012350149627934466, 0.008672051875525708, 0.025927340068537603], [7.6767676767676765, 0.057008023056710655, 0.6080408444021598, -0.027816996651782597, 0.04815356445633524, 0.07532500767261129], [7.777777777777778, 0.038739107129957304, 0.6084633937589834, -0.02144228380145847, 0.025075286002195732, 0.1228620764811755], [7.878787878787879, 0.08782824475495124, 0.598466807341982, 0.018080307884775847, 0.0315515991097075, 0.09674038356166718], [7.979797979797979, 0.041625431636574464, 0.5917543705565507, 0.0025958835507780085, -0.008803226212588722, 0.1422153872121711], [8.080808080808081, 0.00044646718762740567, 0.6030335725981733, 0.047462593729999815, -0.01986126722430881, 0.11924001244910698], [8.181818181818182, 0.006871497165874827, 0.5844284623750393, 0.08199045939412886, -0.0354645299560856, 0.08650696485224617], [8.282828282828282, -0.010401355925078086, 0.5785219222084881, 0.0910136414344528, 0.010998589497144676, 0.10330470708388996], [8.383838383838384, -0.017121280023205503, 0.601821797877215, 0.08082943802775613, -0.017709572487789302, 0.10921182503624853], [8.484848484848484, 0.028982543857982192, 0.5567649830272804, 0.10530026888679661, -0.0017964619406506468, 0.06947494722700875], [8.585858585858587, -0.007622856953925505, 0.5622077316989748, 0.06558371935101857, -0.03937427313861478, 0.08743078874557637], [8.686868686868687, -0.04794656704535524, 0.5235931104852414, 0.07232703141783073, -0.08410633356623301, 0.12093092041321364], [8.787878787878787, -0.08276738247355689, 0.5517608188159515, 0.0999813244188178, -0.12673952578518569, 0.13904389989206276], [8.88888888888889, -0.07797828673273287, 0.5472117561375607, 0.11555846060622565, -0.08522178354712359, 0.13063270251945594], [8.98989898989899, -0.07773391807632764, 0.5690962640832263, 0.12678744156122773, -0.03621633386282498, 0.17356199190805224], [9.09090909090909, -0.07487334611246527, 0.545118137797985, 0.09788839406315349, -0.03514208335133661, 0.1667110472243109], [9.191919191919192, -0.04585287925221192, 0.5376620708311213, 0.09788252425796067, 0.006900318283921333, 0.14353211308755914], [9.292929292929292, -0.0955544453944371, 0.5515605694321465, 0.054707160595279775, -0.008550284598436979, 0.10137264194614656], [9.393939393939394, -0.12454820787447593, 0.5386414878716467, 0.060984516925105495, -0.03292385436418278, 0.11663610917404593], [9.494949494949495, -0.0862620478048943, 0.5084668068077662, 0.07150548570369555, -0.01947305929687608, 0.1624257780322783], [9.595959595959595, -0.058668914948489526, 0.5339227673448799, 0.032312955267366696, 0.01748554793505977, 0.16509801329152218], [9.696969696969697, -0.08352422932226397, 0.5630959451921492, 0.05134633588047691, 0.021831588175602608, 0.21257824400799266], [9.797979797979798, -0.06115124319686115, 0.5992438205876706, 0.0918207464299871, -0.02698161086960018, 0.2528617678911851], [9.8989898989899, -0.09203042899024727, 0.5970803742581964, 0.08719466259985607, -0.0476132192895813, 0.2950712025907572], [10.0, -0.0986516862471709, 0.5505893550536144, 0.06921333307843593, -0.07452692199300451, 0.3374869036686362]]}, \"id\": \"el100754526579280\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "                 \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "                 mpld3.draw_figure(\"fig_el1007545265792807069247217\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.30000000000000004, 0.69999999999999996], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754534840272\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535039632\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535040208\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535040656\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535041104\"}], \"markers\": [], \"id\": \"el100754534887760\", \"ydomain\": [-0.30000000000000004, 0.69999999999999996], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754534840272\", \"el100754534840272pts\"], [\"el100754535039632\", \"el100754535039632pts\"], [\"el100754535040208\", \"el100754535040208pts\"], [\"el100754535040656\", \"el100754535040656pts\"], [\"el100754535041104\", \"el100754535041104pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.01677784045871993, 0.01806442896779976, 0.026166937620281352, -0.024923718577488853, 0.04013046245768698], [0.10101010101010101, -0.019010427718803204, -0.009339950045466464, 0.023726200281504253, -0.0331983988051074, 0.05088494470600032], [0.20202020202020202, 0.007520520551093944, 0.02557012098500778, 0.011884189212601816, -0.05058772148993354, 0.06863911002640805], [0.30303030303030304, -0.03635916655754746, 0.06552237542228453, 0.0003510123133521406, -0.027302445083306273, 0.07078009582441927], [0.40404040404040403, 0.004314751821206629, 0.02524247894959533, -0.041377591149690564, 0.017999024281248333, 0.05728472960825523], [0.5050505050505051, 0.013244806218959326, 0.009003004971218725, -0.06123778436888614, 0.020039107663893007, 0.07637242311641029], [0.6060606060606061, 0.025371332948594272, 0.04139705388428942, -0.033121790652953995, -0.00040529889666890764, 0.09714621454008088], [0.7070707070707071, 0.05661027525086659, 0.00023211068643043398, -0.0496577461679167, 0.01180460413250651, 0.06940540337258212], [0.8080808080808081, 0.009752189436718614, -0.0374202718691629, -0.06953387540656573, -0.032312407970813965, 0.02274646444084131], [0.9090909090909091, 0.04741658559146038, -0.055186333124770746, -0.04164284505297457, 0.001086969439962636, 0.020390789636867603], [1.0101010101010102, 0.01569416202804092, -0.011820052010319958, -0.0459136715284825, 0.040788825914854075, 0.010563404582883585], [1.1111111111111112, -0.02255968121375311, 0.034908775559522126, -0.07979860931209234, 0.0540402222116906, -0.0028900582303800996], [1.2121212121212122, -0.05313963197179153, 0.014930028460955563, -0.07972558231756242, 0.02872176772144048, -0.012771875572369352], [1.3131313131313131, -0.08050390424461916, 0.06473003095115719, -0.0670937590047745, -0.010035882459713867, 0.021894194253673737], [1.4141414141414141, -0.09571307286047688, 0.040179947865303614, -0.022952048888230672, -0.006188902943942035, 0.05497413486408406], [1.5151515151515151, -0.06135628067511669, 0.07987341624583545, 0.011687675019073751, -0.03653573129100646, 0.10230895889480539], [1.6161616161616161, -0.10596181091549992, 0.03767724468975638, -0.03240046488947358, -0.07141156399907003, 0.08042264476494629], [1.7171717171717171, -0.11407334790567397, 0.07081227807410422, -0.05906517604884441, -0.05953357839496097, 0.08311492413854432], [1.8181818181818181, -0.0735037361535465, 0.10831927653785796, -0.052222218497341065, -0.06389473086863208, 0.05740929911335587], [1.9191919191919191, -0.10495050853071608, 0.07114368525682552, -0.09425686845215554, -0.10932881059729171, 0.09245137810941713], [2.0202020202020203, -0.08269799090068017, 0.1168389141786503, -0.1089566306896795, -0.13355433435178546, 0.04659067928134504], [2.121212121212121, -0.11605436928358967, 0.08484170252999645, -0.07025240195391935, -0.18223903927903645, 0.06444501246352263], [2.2222222222222223, -0.12303801503839325, 0.11795700695888409, -0.043231016088033716, -0.15128068789681887, 0.09107600053058862], [2.323232323232323, -0.09396231504354813, 0.1467762983987218, -0.07581565841762479, -0.12163359290125908, 0.09590164060283968], [2.4242424242424243, -0.07502380353642504, 0.19106897339821, -0.05073515730013253, -0.1509631197348789, 0.04849717337710214], [2.525252525252525, -0.07034772018758945, 0.21553817145105486, -0.02050248170283579, -0.1998295045623508, 0.03207299481348276], [2.6262626262626263, -0.05754457721209381, 0.16675943239786503, -0.054167319494348484, -0.1950736914582679, 0.002153250225140159], [2.727272727272727, -0.029421423684566506, 0.19168048867178264, -0.03825473313779427, -0.15792546194513904, 0.017293386543379377], [2.8282828282828283, -0.05270402620477231, 0.23538052203290283, -0.06349638901184688, -0.17491272344892722, 0.009018056678024003], [2.929292929292929, -0.03263054013201232, 0.2007245055572402, -0.06024358310434821, -0.1756604523335887, -0.0031244705192199768], [3.0303030303030303, -0.01605079864169657, 0.22694385883206464, -0.08478810404646307, -0.1307404771190147, -0.00764441292179778], [3.131313131313131, 0.007967020113755913, 0.22003752829611933, -0.0879131761867085, -0.09649725744778095, 0.03969088528138636], [3.2323232323232323, -0.03280317801544969, 0.19769436345488445, -0.07637936566100939, -0.05330743874116178, 0.06462032760402298], [3.3333333333333335, -0.004477476007675389, 0.23095271350935812, -0.12084712541766236, -0.059982562551519694, 0.10742600577610142], [3.4343434343434343, -0.012271038149095196, 0.2548417653394151, -0.11099386372969014, -0.08998713716205725, 0.12117047115716194], [3.5353535353535355, 0.02692080439322021, 0.26395306623216896, -0.06862278504263356, -0.10023247515778261, 0.0921256153425158], [3.6363636363636362, -0.010868236573583958, 0.2722283831600947, -0.022485396895276594, -0.12028063434880594, 0.07144450895183496], [3.7373737373737375, -0.048980516937344745, 0.3144041431131827, -0.04825494117758225, -0.12038477529883283, 0.11098812892855667], [3.8383838383838382, -0.02366865277288449, 0.2878725342850316, -0.0281484818945577, -0.1697190201812837, 0.12252078111947654], [3.9393939393939394, -0.008031836257424707, 0.3333658263361184, -0.04317915314108842, -0.13304315213216622, 0.0974831116616411], [4.040404040404041, -0.0009719418812316194, 0.31033490921591506, -0.05164305561711712, -0.11374693209946685, 0.13159413713104992], [4.141414141414141, -0.010416898730140357, 0.35166529920714373, -0.06330034916853983, -0.09541900901066293, 0.14617766542781935], [4.242424242424242, 0.02308244568497548, 0.38203858943493724, -0.01654316540387768, -0.07508129355396653, 0.1629192576893463], [4.343434343434343, 0.014757768446967462, 0.40695980837436624, 0.0013399714980799407, -0.09096730815771148, 0.14029195907932834], [4.444444444444445, 0.038064803381142175, 0.41080752190846714, -0.012147611588628603, -0.09060708758587202, 0.13823979516222615], [4.545454545454545, 0.0033948651377890895, 0.4297288056652724, 0.008921586481357682, -0.1039049938729425, 0.15938266817702462], [4.646464646464646, -0.03818021709299843, 0.4444385330325871, 0.056016981174061176, -0.14228747875547437, 0.14316832751309086], [4.747474747474747, -0.07046763953393251, 0.4305330168559233, 0.03130009514528462, -0.19112460823209296, 0.13712682664297848], [4.848484848484849, -0.09008251633011466, 0.4297925026130274, 0.008716518299343418, -0.20951773047385075, 0.09347786075873729], [4.94949494949495, -0.1227800695166952, 0.41588377353980993, 0.015865321527938476, -0.23185357948362387, 0.050442451965388525], [5.05050505050505, -0.10063278388920724, 0.42334824149925293, 0.011644348314410597, -0.2563852677558308, 0.026850966254564623], [5.151515151515151, -0.07899662594604578, 0.47278617396060385, -0.023198843870607517, -0.2635235544867182, 0.05870647421625921], [5.252525252525253, -0.11752269611737831, 0.4749416205982514, 0.021268235082630853, -0.2605906454923125, 0.09566026317605415], [5.353535353535354, -0.1239534159651265, 0.46463624557416844, 0.020332950346656647, -0.22922916716766062, 0.07235420271843754], [5.454545454545454, -0.09535969701155926, 0.4444353900182764, 0.002545992225393992, -0.19824160310672007, 0.04204824094519578], [5.555555555555555, -0.07954996393942743, 0.4007061752832129, -0.035392741727166686, -0.2181001124576845, 0.00724471256362904], [5.656565656565657, -0.08844944032080872, 0.3883826547853665, -0.06002840489306699, -0.18594136439754225, -0.0003352336382978511], [5.757575757575758, -0.046900093260268116, 0.43223301189023566, -0.029793998546929743, -0.14525842531226899, -0.025235671592759523], [5.858585858585858, -0.0027312370312007617, 0.4552272743767757, -0.016899622302926916, -0.11222634046850505, -0.0039371145121524925], [5.959595959595959, 0.02698174253426874, 0.498586805924525, -0.04135549609693381, -0.1348546185085486, 0.043646554110552155], [6.0606060606060606, -0.00756235304467635, 0.5336578857305774, -0.017272759447941287, -0.08776954740902043, 0.0007834455432850496], [6.161616161616162, -0.054333650111764956, 0.515435343497819, 0.0009389983120029824, -0.07394730799104116, 0.0017252666125207095], [6.262626262626262, -0.04877565721461598, 0.5596765087970286, 0.02904575911610039, -0.07008991604142775, -0.028772174899200302], [6.363636363636363, -0.06171756301621753, 0.5750809846288243, 0.01023332953256605, -0.10289783674554759, -0.038687271295016326], [6.4646464646464645, -0.0664496254168696, 0.5464635971501387, -0.013714974794487255, -0.11466252846737107, -0.07134715714088533], [6.565656565656566, -0.03895791048437139, 0.5287424284137858, 0.028438050017853257, -0.07739091418488461, -0.049145871262067944], [6.666666666666667, -0.05683026504382227, 0.5212423117564362, 0.014675561957732886, -0.11022310713195435, -0.062330446835056875], [6.767676767676767, -0.016717152773040644, 0.5145342683185772, 0.04081355063115936, -0.06981799829344554, -0.0398569737810317], [6.8686868686868685, -0.0643435422665426, 0.5145702735357306, 0.08348104139319473, -0.04483720028785173, -0.049576611635298785], [6.96969696969697, -0.025408603838279552, 0.5542165350544352, 0.06456654768796949, -0.09370667822169973, -0.006371152501819008], [7.070707070707071, -0.059088602482838, 0.513839915713012, 0.10467324834290632, -0.05435420130275133, -0.023738611144977738], [7.171717171717171, -0.03837855129669279, 0.557783331281617, 0.07259259246861244, -0.014354398548344013, -0.05324620456405508], [7.2727272727272725, -0.051717326357281115, 0.6028672749079622, 0.04259563396520677, -0.009888391442990072, -0.008820437331778994], [7.373737373737374, -0.01536827966050415, 0.5598950160940432, 0.02212575322145419, -0.03739556019586232, 0.03532623118105999], [7.474747474747475, 0.0313539803652332, 0.5673740544273383, -0.00970011586136978, -0.028047212091982, 0.023699819183343913], [7.575757575757575, 0.030234946339973555, 0.5808925569869406, 0.012350149627934466, 0.008672051875525708, 0.025927340068537603], [7.6767676767676765, 0.057008023056710655, 0.6080408444021598, -0.027816996651782597, 0.04815356445633524, 0.07532500767261129], [7.777777777777778, 0.038739107129957304, 0.6084633937589834, -0.02144228380145847, 0.025075286002195732, 0.1228620764811755], [7.878787878787879, 0.08782824475495124, 0.598466807341982, 0.018080307884775847, 0.0315515991097075, 0.09674038356166718], [7.979797979797979, 0.041625431636574464, 0.5917543705565507, 0.0025958835507780085, -0.008803226212588722, 0.1422153872121711], [8.080808080808081, 0.00044646718762740567, 0.6030335725981733, 0.047462593729999815, -0.01986126722430881, 0.11924001244910698], [8.181818181818182, 0.006871497165874827, 0.5844284623750393, 0.08199045939412886, -0.0354645299560856, 0.08650696485224617], [8.282828282828282, -0.010401355925078086, 0.5785219222084881, 0.0910136414344528, 0.010998589497144676, 0.10330470708388996], [8.383838383838384, -0.017121280023205503, 0.601821797877215, 0.08082943802775613, -0.017709572487789302, 0.10921182503624853], [8.484848484848484, 0.028982543857982192, 0.5567649830272804, 0.10530026888679661, -0.0017964619406506468, 0.06947494722700875], [8.585858585858587, -0.007622856953925505, 0.5622077316989748, 0.06558371935101857, -0.03937427313861478, 0.08743078874557637], [8.686868686868687, -0.04794656704535524, 0.5235931104852414, 0.07232703141783073, -0.08410633356623301, 0.12093092041321364], [8.787878787878787, -0.08276738247355689, 0.5517608188159515, 0.0999813244188178, -0.12673952578518569, 0.13904389989206276], [8.88888888888889, -0.07797828673273287, 0.5472117561375607, 0.11555846060622565, -0.08522178354712359, 0.13063270251945594], [8.98989898989899, -0.07773391807632764, 0.5690962640832263, 0.12678744156122773, -0.03621633386282498, 0.17356199190805224], [9.09090909090909, -0.07487334611246527, 0.545118137797985, 0.09788839406315349, -0.03514208335133661, 0.1667110472243109], [9.191919191919192, -0.04585287925221192, 0.5376620708311213, 0.09788252425796067, 0.006900318283921333, 0.14353211308755914], [9.292929292929292, -0.0955544453944371, 0.5515605694321465, 0.054707160595279775, -0.008550284598436979, 0.10137264194614656], [9.393939393939394, -0.12454820787447593, 0.5386414878716467, 0.060984516925105495, -0.03292385436418278, 0.11663610917404593], [9.494949494949495, -0.0862620478048943, 0.5084668068077662, 0.07150548570369555, -0.01947305929687608, 0.1624257780322783], [9.595959595959595, -0.058668914948489526, 0.5339227673448799, 0.032312955267366696, 0.01748554793505977, 0.16509801329152218], [9.696969696969697, -0.08352422932226397, 0.5630959451921492, 0.05134633588047691, 0.021831588175602608, 0.21257824400799266], [9.797979797979798, -0.06115124319686115, 0.5992438205876706, 0.0918207464299871, -0.02698161086960018, 0.2528617678911851], [9.8989898989899, -0.09203042899024727, 0.5970803742581964, 0.08719466259985607, -0.0476132192895813, 0.2950712025907572], [10.0, -0.0986516862471709, 0.5505893550536144, 0.06921333307843593, -0.07452692199300451, 0.3374869036686362]]}, \"id\": \"el100754526579280\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 1,
       "text": [
        "<IPython.core.display.HTML at 0x10043da50>"
       ]
      }
     ],
     "prompt_number": 1
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## We can link multiple elements to a single legend item\n",
      "\n",
      "There is the possibility to link more than one matplotlib element (e.g. a line) to a single item in the legend. As demonstrated by the example below. The plugin needs a list of matplotlib items, a list of lists, or a hybrid. Thus, it is possible to link one legend item to several elements in the plot, while another legend item is linked only to a single item. In case of multiple items being associated with a single legend item, the box takes on the color of the first item in the list. "
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "N_paths = 5\n",
      "N_steps = 100\n",
      "\n",
      "x1 = np.linspace(0, 10, 100)\n",
      "y = 0.1 * (np.random.random((N_paths, N_steps)) - 0.5)\n",
      "y1 = y.cumsum(1)\n",
      "\n",
      "x2 = np.linspace(0, 10, 100)\n",
      "y = 0.1 * (np.random.random((N_paths, N_steps)) - 0.5)\n",
      "y2 = y.cumsum(1)\n",
      "\n",
      "fig, ax = plt.subplots()\n",
      "labels = [\"a\", \"b\",]\n",
      "l1 = ax.plot(x1, y1.T, lw=4, alpha=0.1, c='b', label='a')\n",
      "l2 = ax.plot(x2, y2.T, lw=4, alpha=0.2, c='r', label='b')\n",
      "\n",
      "line_collections = [l1,l2]\n",
      "plugins.connect(fig, plugins.InteractiveLegendPlugin(line_collections, labels))\n",
      "\n",
      "mpld3.display()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "    .legend-box {\n",
        "      cursor: pointer;\n",
        "    }\n",
        "    \n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el1007545351208486469406376\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "       mpld3.draw_figure(\"fig_el1007545351208486469406376\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.40000000000000002, 0.80000000000000016], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535120720\"}, {\"color\": \"#0000FF\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535538512\"}, {\"color\": \"#0000FF\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535539088\"}, {\"color\": \"#0000FF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535539536\"}, {\"color\": \"#0000FF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535539984\"}, {\"color\": \"#FF0000\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535120784\"}, {\"color\": \"#FF0000\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535563152\"}, {\"color\": \"#FF0000\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535176784\"}, {\"color\": \"#FF0000\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535564048\"}, {\"color\": \"#FF0000\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535564496\"}], \"markers\": [], \"id\": \"el100754535123216\", \"ydomain\": [-0.40000000000000002, 0.80000000000000016], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754535120720\", \"el100754535120720pts\", \"el100754535538512\", \"el100754535538512pts\", \"el100754535539088\", \"el100754535539088pts\", \"el100754535539536\", \"el100754535539536pts\", \"el100754535539984\", \"el100754535539984pts\"], [\"el100754535120784\", \"el100754535120784pts\", \"el100754535563152\", \"el100754535563152pts\", \"el100754535176784\", \"el100754535176784pts\", \"el100754535564048\", \"el100754535564048pts\", \"el100754535564496\", \"el100754535564496pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.03490324833371287, 0.033878183159034826, -0.043003751479301966, 0.04423068190955063, -0.013494933053202929, 0.04028480581396471, -0.007243667236936136, -0.046920402010741186, 0.020367149955244315, -0.03652998201005735], [0.10101010101010101, -0.0183985136332817, -0.013790912780609212, -0.00140808705548226, 0.03374393405304034, 0.006873965696707309, 0.07288334869042817, 0.039744307099609896, -0.01321316645323662, 0.01616648656371075, -0.05965628432488278], [0.20202020202020202, 0.015384499153983034, 0.023866894493403935, -0.03862846743651541, 0.023508567700489126, -0.03631778992185465, 0.10320524134402613, 0.03629769778713273, -0.04458250136578845, -0.01517023524072247, -0.052535706065269056], [0.30303030303030304, -0.015329733245276988, 0.03145039998734311, -0.001333506107658762, 0.013982541629512124, -0.07211358051921785, 0.12348839512127521, 0.027346306015770802, -0.08089916440402208, -0.06399366879155624, -0.08574837123641255], [0.40404040404040403, 0.027931587499750134, 0.0775490663057943, 0.04393185580930728, 0.00019084677943420614, -0.11096473840332573, 0.07675004588105236, 0.014263971373299697, -0.11883024578995964, -0.028913665991720468, -0.05559580967512362], [0.5050505050505051, -0.020293563774255372, 0.10743687528144012, 0.02875148141013957, -0.013154254569664759, -0.0895324845156526, 0.073320156156293, 0.036300603244236784, -0.09159403460012672, -0.04715587009019766, -0.10457439449716963], [0.6060606060606061, -0.023706161477857667, 0.06087535047581206, 0.03634612349830002, 0.015509915555664578, -0.1355981692571969, 0.025815393100450723, 0.01258992772058358, -0.10898044633833692, -0.00020354079559302407, -0.07469873821390871], [0.7070707070707071, -0.0008807521099839025, 0.09368957118405699, 0.017061285773550594, 0.02460124074812832, -0.163869853527821, 0.06742247014449596, 0.01699674551212888, -0.0952653282712404, 0.030930712136593156, -0.06920926295496918], [0.8080808080808081, -0.009182714773362995, 0.13766881718066204, -0.025334727171639232, 0.050962974403679855, -0.1458928740338573, 0.03308788722395107, 0.061476295954851885, -0.10300402254545586, 0.06672724194563752, -0.05855922893432654], [0.9090909090909091, -0.011133099272223432, 0.17237307280242897, -0.03337315098143408, 0.02068622076322453, -0.1922531404778499, 0.0317306066791487, 0.09312949504532494, -0.15233395238691194, 0.0789027363342257, -0.05771689975170664], [1.0101010101010102, -0.027276408255227754, 0.12686455644030115, -0.005271833331570143, 0.04525352441288247, -0.1961826278483047, 0.004048827544546114, 0.0494874151302821, -0.1164737347816388, 0.11076114141194324, -0.02484730770408594], [1.1111111111111112, -0.05530332062318094, 0.08594555583970975, -0.05421102142175685, 0.014583049087432236, -0.19410587982103422, -0.01992654867499059, 0.04267203873288863, -0.07683820275873962, 0.1495829018407091, 0.019438649931535205], [1.2121212121212122, -0.044299267174359, 0.10730941861756839, -0.03225312091350527, -0.001876647140179686, -0.16054349944981186, -0.0359062754020084, 0.025628930340264932, -0.08487994063474198, 0.17816290330772352, 0.04448260741172188], [1.3131313131313131, -0.018625065012425245, 0.07249436166221607, -0.052328472703100856, -0.004601862552203493, -0.15844526989784982, -0.017908067548457626, 0.041652879004564915, -0.1026882742878037, 0.21644259425505316, 0.03896398687392949], [1.4141414141414141, 0.019982948025866858, 0.029955464112805086, -0.036313373120631834, -0.024714631886575588, -0.14382433496380523, -0.02933036066726697, 0.09153203178498653, -0.14470920142333768, 0.21653070478351424, 0.0400761752719229], [1.5151515151515151, -0.022822002458357214, 0.0010132280460150023, -0.040365209194998475, 0.008808312248070261, -0.18579504334349126, -0.01727826322649849, 0.08226151916423019, -0.19005149111824102, 0.17026716869936204, 0.029157976625642325], [1.6161616161616161, -0.02855275742446166, 0.010559131459922533, -0.05065849999648149, -0.027750100551177482, -0.1591731728644316, 0.001852170568807092, 0.08514741242782979, -0.1862687443555631, 0.20566203893332588, 0.050723709315488856], [1.7171717171717171, -0.05369671568072393, 0.04926324263984809, -0.027153431909470217, 0.0025504702914188847, -0.14703469319920914, 0.04195262497603205, 0.13124572154097908, -0.23402363781452143, 0.20888165946300638, 0.0817757987575107], [1.8181818181818181, -0.009251937830241037, 0.09649356123390893, -0.0375027829437116, -0.03341251713035033, -0.19621744328970508, 0.044976092489951, 0.1264601876961891, -0.26638393489587225, 0.23603031169310082, 0.12969055764389797], [1.9191919191919191, -0.0029858544579611304, 0.09844382511357376, 0.0004669734307934312, -0.041558555052991934, -0.1892812156280778, 0.08791497483415273, 0.0981624393742895, -0.21921953598882585, 0.2690750755287698, 0.13216708565296362], [2.0202020202020203, -0.04171827341358348, 0.08836310594695491, -0.02516933942986221, 0.003538690408055975, -0.16037886212053043, 0.04164932663131457, 0.11190639756077839, -0.21858959033202277, 0.29986202539568235, 0.12690640455484123], [2.121212121212121, -0.026361729088059664, 0.08482080618249777, -0.03687924572183858, -0.011772483988344554, -0.17053949085751194, 0.00046456699191643053, 0.07064866254906244, -0.2069139689765679, 0.3469479041025343, 0.08663014279463757], [2.2222222222222223, 0.00887687656924676, 0.11268020003444407, -0.03628693758449636, -0.039437328694606893, -0.17864145202489243, 0.00873867648627346, 0.07330009400745449, -0.22130547825837102, 0.3485346572423149, 0.10293231790655188], [2.323232323232323, -0.01991669698123019, 0.0980895003446153, -0.07264614797774097, -0.08680737368869096, -0.13844768085698017, 0.0047691486831845245, 0.08705072859944069, -0.18822811512121532, 0.38286959480592286, 0.10015836904063666], [2.4242424242424243, -0.0443879751185634, 0.05569553916794839, -0.0633222978467946, -0.07548540044971416, -0.1806692809210965, 0.035486974011705835, 0.10334804858314542, -0.22258118728319914, 0.43198287540206126, 0.13988960287002972], [2.525252525252525, 0.0010768306309531933, 0.061756605691358595, -0.023592036937952032, -0.08212346747233419, -0.18115808791761023, 0.003515769977112407, 0.13314161584051232, -0.1765031009446358, 0.45564438655742273, 0.09926732721304335], [2.6262626262626263, -0.013339256011688009, 0.04278706922131542, -0.023460253512378272, -0.04910696961668919, -0.17181956181047883, 0.026781904594438147, 0.11498252017546848, -0.17277803654891655, 0.4811835927823546, 0.0785758607923184], [2.727272727272727, 0.005854140316139254, 0.022611902473933763, -0.019217195636767048, -0.0653401040684764, -0.21101756438239308, 0.04180105784698823, 0.14330917959681813, -0.13944626293420295, 0.4320061322106965, 0.09540108737854484], [2.8282828282828283, 0.04768355386972702, -0.00878306927695887, 0.009992361680128282, -0.030425404224047194, -0.23689932126418078, 0.04846699113792839, 0.18903622119102076, -0.16275559268350365, 0.4647015484217533, 0.14008163877698557], [2.929292929292929, 0.03384818541774519, -0.00042835412523484565, 0.03521383525909774, -0.056066960924972466, -0.22703508836806793, 0.024041753426694165, 0.14910129938658362, -0.11655646023442773, 0.47233710023989256, 0.18687183159424509], [3.0303030303030303, 0.01647625991848402, -0.009704537431216024, 0.04243299890142927, -0.0676816892304005, -0.20424667342388864, 0.026643497477766395, 0.15968488236951506, -0.1063249970885691, 0.44846332479787104, 0.20192986751217445], [3.131313131313131, 0.04350022514549329, -0.010882183815539417, 0.0284988114709726, -0.08592548376610586, -0.19987376319226977, 0.07241220895789083, 0.1342279626148657, -0.10974862535913261, 0.4201321333497451, 0.17620006823452944], [3.2323232323232323, 0.00213551607232388, 0.0032519554001541363, 0.05310127526648052, -0.10096017705699507, -0.16460041698205763, 0.03971560764218574, 0.10420331604129018, -0.08125978081418735, 0.38652462768240636, 0.17496536379842598], [3.3333333333333335, -0.030920391370552518, 0.013666651039968634, 0.09771853774364862, -0.0770499260098999, -0.18340914339059666, -0.007193974865715699, 0.12016560513932803, -0.0877096899457575, 0.4213708755676279, 0.1624824897908432], [3.4343434343434343, 0.0028716871651035397, 0.0552938583510111, 0.09186278710888526, -0.07756794306088158, -0.21250080132772747, 0.011726221781299045, 0.16356835256079252, -0.11425655384584915, 0.3811588479628387, 0.141521223246375], [3.5353535353535355, 0.004273229494279449, 0.0261572362552144, 0.13029616421867155, -0.03894745218339029, -0.24964867271913382, -0.026178667405890307, 0.2075916679912409, -0.10112521629479637, 0.41753548390971446, 0.16301563137671204], [3.6363636363636362, 0.01663789964976796, 0.009192554224119753, 0.09097371913793423, -0.026354717672698695, -0.237481835478575, -0.06018861540257875, 0.2456955385384506, -0.05753634563626435, 0.4127721063398594, 0.20825375637642726], [3.7373737373737375, -0.0167230807852961, -0.01125773710601562, 0.05936321652062384, -0.06142417135722879, -0.22706401019219863, -0.0746885979713027, 0.22188280557651383, -0.06669419611089207, 0.4285114363538632, 0.23697380677953303], [3.8383838383838382, -0.056539046123589384, 0.024166749143296484, 0.036484842231230635, -0.04722482594755265, -0.18381379265877548, -0.03242448897637597, 0.2058594632530817, -0.09627347594539441, 0.3976690001322558, 0.23587255171519705], [3.9393939393939394, -0.09631990899321712, -0.019007121538874964, 0.049758567545820115, -0.00522305880612018, -0.1382588514197492, -0.026808975026622387, 0.1888567111263076, -0.053881181919816605, 0.41346841727710903, 0.2757336768633223], [4.040404040404041, -0.11559116920122596, -0.011059452253664717, 0.07494549851977395, 0.013589741851713893, -0.1688650852410894, 0.00012124902388626832, 0.21843774993482412, -0.09051716275882941, 0.36873281238814526, 0.3045806806791219], [4.141414141414141, -0.10306769607792361, 0.009671820779958129, 0.06843217953962269, 0.059093241287180145, -0.1352754699513987, -0.01632275225061907, 0.2307460728871941, -0.04347265820468589, 0.41011314797918635, 0.27511664158880117], [4.242424242424242, -0.08158068697635507, 0.05500203411526216, 0.0837123746595331, 0.015147887059701992, -0.10133817699715299, -0.0655515439016606, 0.19108918948031353, -0.061375237690944814, 0.3629677038426524, 0.2879230976710254], [4.343434343434343, -0.11861501862028248, 0.10298129911199594, 0.09484460455535365, 0.03745600592382173, -0.09834445724607155, -0.07967736890715602, 0.1747845464611911, -0.0570363694573714, 0.34217952932003687, 0.32801539849499184], [4.444444444444445, -0.15892693258664428, 0.08074259526551741, 0.09199643143239764, 0.020875562093846882, -0.12866779543071008, -0.06946502233085128, 0.19470453558776768, -0.05465276507386389, 0.3602552764055016, 0.3471550211821037], [4.545454545454545, -0.12353121816012994, 0.10197404051238068, 0.11187687408045857, 0.05107453907697484, -0.0799596287521355, -0.06455474007410475, 0.17277335711001818, -0.06973078604695443, 0.31607730947791857, 0.36112448791230917], [4.646464646464646, -0.15739347319528155, 0.14227434259423494, 0.0905380678550903, 0.08361205126159382, -0.039388128300578064, -0.10350693082097329, 0.19582448970354135, -0.05549151519252056, 0.3252468061436249, 0.31825823666733444], [4.747474747474747, -0.19685446641691323, 0.11129421007785033, 0.06571962233917328, 0.12418739236555718, -0.0844450276587313, -0.09308300136437837, 0.21300864583748158, -0.10414345143833564, 0.2756383378648004, 0.3432978264989444], [4.848484848484849, -0.18045176687460443, 0.06160895785442843, 0.07853100920454456, 0.12768813079603486, -0.05039232497235533, -0.07975366287165517, 0.18672507351407314, -0.08200205563288127, 0.3115321303782288, 0.3439055191964769], [4.94949494949495, -0.19894088742834506, 0.09441617510448592, 0.06046781711506127, 0.1425497490781575, -0.04138913936264941, -0.09339901926996888, 0.20673730146947378, -0.052043996721075014, 0.35483874752889394, 0.37549491997774065], [5.05050505050505, -0.21950621329381093, 0.07497931844448902, 0.014084698355850286, 0.11145207701192321, -0.005318119743034776, -0.0793316856491068, 0.18470384815525118, -0.05601914657339354, 0.3218854870026257, 0.40728471100594577], [5.151515151515151, -0.17621178218408376, 0.0915195521332371, -0.027400415200157187, 0.06937445997481273, -0.020235794108621252, -0.08103658350703909, 0.2044168146870446, -0.01867121321942817, 0.3518979019385557, 0.41343903952604205], [5.252525252525253, -0.22093945135884552, 0.1404364630192523, 0.004808794575441137, 0.1142761846183314, -0.06314757400860863, -0.05073410902420644, 0.2172673225531427, -0.045616936185273814, 0.30265494246569585, 0.4574828032817965], [5.353535353535354, -0.22259940310934528, 0.10109624930557348, 0.006099200672734233, 0.0653098456790781, -0.06732575913615521, -0.09834572876130405, 0.20997842594477784, -0.03711123275685064, 0.278157387410089, 0.4520335059958384], [5.454545454545454, -0.26281685966738466, 0.08714253495460735, 0.01128938921833446, 0.027892140300945743, -0.0856757621076993, -0.14468842227746365, 0.2538082184581818, -0.05659669533416242, 0.32030739440657946, 0.46806321221835323], [5.555555555555555, -0.2254236464619762, 0.057750313908593004, 0.045135408321913664, 0.030566058176540623, -0.04847260891085764, -0.15698562507977926, 0.2701597086938966, -0.011957607747917057, 0.31743241260303057, 0.5149537980494749], [5.656565656565657, -0.21645037613054688, 0.06699688133632227, 0.054426853617729025, -0.005756248222118787, -0.04806878049831733, -0.12261343440495229, 0.22315446307183656, -0.02187090610584448, 0.3112315422662681, 0.47737533585100955], [5.757575757575758, -0.17314836309253648, 0.07091566840669408, 0.08151605285722967, 0.004666228709148946, -0.05196660832482103, -0.15943820922644236, 0.26800295020073744, -0.0043779027251495545, 0.3213463882970833, 0.4700702935860584], [5.858585858585858, -0.16621578394307257, 0.07505163242896146, 0.05465879202693969, -0.029112688955958598, -0.06503022087271437, -0.13521625461430678, 0.2776590615865013, -0.04494323179562125, 0.333574189686588, 0.4629761954531943], [5.959595959595959, -0.16112536111510778, 0.1070378667385187, 0.06758453321398314, -0.04247990091765287, -0.08719093474410317, -0.16156582155830557, 0.24176368901292078, -0.0748356861697864, 0.3570868975898537, 0.5081647511605756], [6.0606060606060606, -0.19243692262281795, 0.15254647251074144, 0.02714743320989569, -0.04431041430002658, -0.05883523199700584, -0.1132589925386685, 0.2106562793596793, -0.050817108482918455, 0.39870214644371565, 0.47793635731634443], [6.161616161616162, -0.20838561398829777, 0.1336769170169893, 0.01702094169946461, -0.02538233852107047, -0.10543040559314545, -0.07639195725875289, 0.2449967368297091, -0.011938892307493967, 0.42159018598965664, 0.4953950108089267], [6.262626262626262, -0.16363829614907258, 0.16449763105832516, 0.03211659692893901, 0.00651603031095687, -0.12363235952096592, -0.1049876943870961, 0.24253979578489565, 0.011334554436213992, 0.3848358351890678, 0.5290028771407445], [6.363636363636363, -0.13634031577760206, 0.16073381005439755, -0.012007764568539005, 0.018377409627434976, -0.08468593091965693, -0.08113591294072144, 0.234444810249734, 0.059449929186828364, 0.42726003717462785, 0.551568337334745], [6.4646464646464645, -0.11682767839296608, 0.14128488077177445, -0.026495456316656577, 0.034522072625519436, -0.09137088806460475, -0.039198209720847074, 0.24188537021154766, 0.021753094526943233, 0.43389562134623844, 0.5446138619981084], [6.565656565656566, -0.14871565182109417, 0.17424237753004024, 0.0019100319849553286, 0.083773872754896, -0.062261852730316564, -0.016543768983726656, 0.22555640670324373, 0.013082652333959936, 0.42994237508792227, 0.5182268997224956], [6.666666666666667, -0.18874392150899966, 0.1454949770257246, -0.04513834507402459, 0.07551923902731286, -0.07179971672862079, -0.06626244062715063, 0.21341972191284614, 0.02589361758152367, 0.4705654941460204, 0.46873570293484695], [6.767676767676767, -0.22485730225062592, 0.131804678660933, -0.06490526563708507, 0.09970930262019898, -0.04063196003284908, -0.045474749265438305, 0.1739920121000114, 0.06002150667448091, 0.493714190154653, 0.4721082002871755], [6.8686868686868685, -0.2535513166047431, 0.1320057371076148, -0.09441260632354136, 0.14202352555228703, -0.04728790063272274, -0.001615740873373142, 0.12524836943549744, 0.048048727248946245, 0.45671657933228077, 0.4276356028203348], [6.96969696969697, -0.21253663201683, 0.09608604458697173, -0.11558254383633451, 0.12850137849370036, -0.0638007870392889, -0.04812020933882495, 0.11996966530795669, 0.0680386162644882, 0.4325545130113222, 0.4548028350888082], [7.070707070707071, -0.23085580731290598, 0.0809355379330261, -0.13941098800923496, 0.13932101402531816, -0.10104613548256419, -0.08756368745093784, 0.1696244670371927, 0.08606135600162187, 0.4591754287941087, 0.4286805065856091], [7.171717171717171, -0.2206004590488264, 0.10465667955465675, -0.14834843161579678, 0.09421955282810428, -0.08889269469095556, -0.06946532099720923, 0.13588382788944892, 0.10872945422321892, 0.435063014429973, 0.45184152382575715], [7.2727272727272725, -0.26634456169398, 0.12622909435206187, -0.186445065560151, 0.10166835410242642, -0.0469226684235935, -0.0701419425419906, 0.1701132748097273, 0.08499916476835229, 0.47232433339583996, 0.41408301925581753], [7.373737373737374, -0.21768964922230039, 0.12111412639889477, -0.18004803334343697, 0.14002748016827318, -0.0415128215771494, -0.08751347582748809, 0.13214689282890302, 0.12637202149968585, 0.4440843826477167, 0.445135384606509], [7.474747474747475, -0.2335113748748071, 0.1318166785424321, -0.17185439567340202, 0.1765317850712973, -0.0326548040962763, -0.08606648036299028, 0.17654839527369157, 0.09689153300516429, 0.42341745852099544, 0.4007524633447051], [7.575757575757575, -0.2525878668375522, 0.09401228764648911, -0.12371694591250817, 0.20735876601263373, -0.039736889581881055, -0.04713788741505995, 0.15753239023496485, 0.14358049237244588, 0.42829693966012794, 0.3721560826678414], [7.6767676767676765, -0.22692479965887297, 0.06172346680337813, -0.0752614535726564, 0.15777298857610955, -0.07556098576250855, -0.026726968513495812, 0.1936832616964019, 0.10552324648635361, 0.4060091154082384, 0.41708951562451824], [7.777777777777778, -0.24433850338068822, 0.09495922168287571, -0.09647024675132795, 0.17073328932861356, -0.1249833059237369, -0.036745529577741104, 0.22054301296169185, 0.15335330656638665, 0.40077298749933093, 0.4017840308385833], [7.878787878787879, -0.2877990778624865, 0.056789319802179564, -0.09194517171689431, 0.1563654332191596, -0.17073686586586795, 0.007226734867366198, 0.21885543483833786, 0.16939976034404575, 0.4100301491556841, 0.409716443415785], [7.979797979797979, -0.30700286250351116, 0.027235772270362748, -0.04885539624760825, 0.12886329750633263, -0.1856207237850308, -0.03867831500892239, 0.18608437170267436, 0.18318407290210367, 0.4092290936828996, 0.4053241269734778], [8.080808080808081, -0.2995577355321243, -0.018616344579469844, -0.07984141116472016, 0.13777843274899293, -0.20045088705860553, -0.07339295305254223, 0.14494902077812516, 0.1443798057097059, 0.4540744728556655, 0.41851003111263196], [8.181818181818182, -0.263996310470014, -0.05757001705231235, -0.11759708133730264, 0.17497465641802964, -0.2326184322354542, -0.08272234830227775, 0.17216769922164088, 0.15417493082313946, 0.4480694029246636, 0.4563903585961941], [8.282828282828282, -0.2924226716245204, -0.06804924689084983, -0.08101629148046674, 0.15371900441696837, -0.26200537326286993, -0.11357280851891882, 0.2001175496319359, 0.12303307931446375, 0.48490951249934766, 0.44203243642610757], [8.383838383838384, -0.33589628689590667, -0.08699159205450242, -0.07705479212357302, 0.13089533098982875, -0.30273801464973027, -0.0886289275927861, 0.19789496181624802, 0.07726158673456288, 0.46444289779751446, 0.39729936985276654], [8.484848484848484, -0.350111152098984, -0.051547111089351075, -0.11975510057732419, 0.11518885450402963, -0.28474060485751457, -0.13209735271484668, 0.21399235036933822, 0.09431116006245657, 0.4929304233874552, 0.3721513012764771], [8.585858585858587, -0.38095997797326325, -0.03223676376691185, -0.12837271619892934, 0.0651987512865527, -0.27440001488621657, -0.12252723578318793, 0.16832527109986425, 0.06859061423972201, 0.5013581805624265, 0.36440427326357533], [8.686868686868687, -0.39269173001648267, -0.007699542417483683, -0.09550706506032669, 0.05477328947734812, -0.30127953865199825, -0.1115492461927611, 0.16180688828574008, 0.03926405595817352, 0.539735964745768, 0.39675825656864316], [8.787878787878787, -0.3623371590517501, -0.02563453612148644, -0.07997993741155737, 0.047923862539244945, -0.27955713819015265, -0.08326218209504789, 0.11242556552901084, 0.03062500066374079, 0.589160056323885, 0.39700227511329816], [8.88888888888889, -0.348704642332408, -0.03452507352744595, -0.1119217952067855, 0.02482344625704145, -0.2503888351296222, -0.07461226675369201, 0.08606194596502367, 0.02485494359994343, 0.6150929575704881, 0.41124828574491806], [8.98989898989899, -0.32744463244674116, -0.015459529925908766, -0.11395636968567736, 0.06489125629920559, -0.20262712732578117, -0.09208844471151888, 0.05415684242371591, 0.034400504739847786, 0.6581961850643782, 0.3784565712171111], [9.09090909090909, -0.3226542387181737, -0.046169842370611905, -0.06537010955256775, 0.1065939926377648, -0.1992783327706226, -0.12567529239090855, 0.040868537904920246, 0.08393356109702907, 0.6330151948952903, 0.34631444405499406], [9.191919191919192, -0.2760193843392182, -0.06898450766307213, -0.03251652205091881, 0.12867600271489077, -0.1944543966485349, -0.15020964414326435, 0.06360606370118572, 0.06291420733492126, 0.6816067837837958, 0.33048095522054677], [9.292929292929292, -0.26389065303206993, -0.11507347026434425, 0.013087388980551104, 0.1642831584557092, -0.14956012115007514, -0.17690561744845806, 0.06764832287727215, 0.018156835907595446, 0.6946829560571791, 0.3083528603465027], [9.393939393939394, -0.31327084784434156, -0.08400473619937476, 0.032611042067471965, 0.17454226337574125, -0.1880688191315526, -0.13995175872954022, 0.08407472448034924, 0.038029155939079004, 0.7037772573508425, 0.35426792049578926], [9.494949494949495, -0.3142058935986316, -0.06348812406995144, -0.01636621022185762, 0.13997159069519882, -0.15879459583556194, -0.11066510175883891, 0.1337026816475659, -0.0007134198097654421, 0.6607583392734975, 0.36251308047923164], [9.595959595959595, -0.3250103705610946, -0.04352694268747587, -0.05088796324367132, 0.12412975685634552, -0.14420662220221997, -0.1340235758098544, 0.11588116210445669, -0.04902657765715783, 0.6655607333385336, 0.31849184506567213], [9.696969696969697, -0.2909919121403937, -0.08226214232233856, -0.033421494039123464, 0.09847559701418847, -0.1368304557084392, -0.11432562452595217, 0.11952865674173498, -0.050175350485801046, 0.68073545351974, 0.33711108366260134], [9.797979797979798, -0.3394029058981474, -0.12530382888531033, -0.044675869210569236, 0.09924719035009606, -0.15122917749935313, -0.10412030432556452, 0.1382280739317157, -0.052844720569949606, 0.6664539978430725, 0.29807158251380467], [9.8989898989899, -0.3658213554996122, -0.12741639914053776, -0.06589123766088176, 0.06141779227400905, -0.19828941742777265, -0.10534004528128424, 0.16857501243703307, -0.026262200504066364, 0.7022584922892326, 0.28204348235021115], [10.0, -0.37924224422194197, -0.0808967525034193, -0.1131625505151774, 0.05086614228967248, -0.165498790153196, -0.1365316358287621, 0.15312187518785908, -0.016312065415761384, 0.6545382396099495, 0.2873157626968275]]}, \"id\": \"el100754535120848\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "         \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "         mpld3.draw_figure(\"fig_el1007545351208486469406376\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.40000000000000002, 0.80000000000000016], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535120720\"}, {\"color\": \"#0000FF\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535538512\"}, {\"color\": \"#0000FF\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535539088\"}, {\"color\": \"#0000FF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535539536\"}, {\"color\": \"#0000FF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535539984\"}, {\"color\": \"#FF0000\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535120784\"}, {\"color\": \"#FF0000\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535563152\"}, {\"color\": \"#FF0000\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535176784\"}, {\"color\": \"#FF0000\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535564048\"}, {\"color\": \"#FF0000\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535564496\"}], \"markers\": [], \"id\": \"el100754535123216\", \"ydomain\": [-0.40000000000000002, 0.80000000000000016], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754535120720\", \"el100754535120720pts\", \"el100754535538512\", \"el100754535538512pts\", \"el100754535539088\", \"el100754535539088pts\", \"el100754535539536\", \"el100754535539536pts\", \"el100754535539984\", \"el100754535539984pts\"], [\"el100754535120784\", \"el100754535120784pts\", \"el100754535563152\", \"el100754535563152pts\", \"el100754535176784\", \"el100754535176784pts\", \"el100754535564048\", \"el100754535564048pts\", \"el100754535564496\", \"el100754535564496pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.03490324833371287, 0.033878183159034826, -0.043003751479301966, 0.04423068190955063, -0.013494933053202929, 0.04028480581396471, -0.007243667236936136, -0.046920402010741186, 0.020367149955244315, -0.03652998201005735], [0.10101010101010101, -0.0183985136332817, -0.013790912780609212, -0.00140808705548226, 0.03374393405304034, 0.006873965696707309, 0.07288334869042817, 0.039744307099609896, -0.01321316645323662, 0.01616648656371075, -0.05965628432488278], [0.20202020202020202, 0.015384499153983034, 0.023866894493403935, -0.03862846743651541, 0.023508567700489126, -0.03631778992185465, 0.10320524134402613, 0.03629769778713273, -0.04458250136578845, -0.01517023524072247, -0.052535706065269056], [0.30303030303030304, -0.015329733245276988, 0.03145039998734311, -0.001333506107658762, 0.013982541629512124, -0.07211358051921785, 0.12348839512127521, 0.027346306015770802, -0.08089916440402208, -0.06399366879155624, -0.08574837123641255], [0.40404040404040403, 0.027931587499750134, 0.0775490663057943, 0.04393185580930728, 0.00019084677943420614, -0.11096473840332573, 0.07675004588105236, 0.014263971373299697, -0.11883024578995964, -0.028913665991720468, -0.05559580967512362], [0.5050505050505051, -0.020293563774255372, 0.10743687528144012, 0.02875148141013957, -0.013154254569664759, -0.0895324845156526, 0.073320156156293, 0.036300603244236784, -0.09159403460012672, -0.04715587009019766, -0.10457439449716963], [0.6060606060606061, -0.023706161477857667, 0.06087535047581206, 0.03634612349830002, 0.015509915555664578, -0.1355981692571969, 0.025815393100450723, 0.01258992772058358, -0.10898044633833692, -0.00020354079559302407, -0.07469873821390871], [0.7070707070707071, -0.0008807521099839025, 0.09368957118405699, 0.017061285773550594, 0.02460124074812832, -0.163869853527821, 0.06742247014449596, 0.01699674551212888, -0.0952653282712404, 0.030930712136593156, -0.06920926295496918], [0.8080808080808081, -0.009182714773362995, 0.13766881718066204, -0.025334727171639232, 0.050962974403679855, -0.1458928740338573, 0.03308788722395107, 0.061476295954851885, -0.10300402254545586, 0.06672724194563752, -0.05855922893432654], [0.9090909090909091, -0.011133099272223432, 0.17237307280242897, -0.03337315098143408, 0.02068622076322453, -0.1922531404778499, 0.0317306066791487, 0.09312949504532494, -0.15233395238691194, 0.0789027363342257, -0.05771689975170664], [1.0101010101010102, -0.027276408255227754, 0.12686455644030115, -0.005271833331570143, 0.04525352441288247, -0.1961826278483047, 0.004048827544546114, 0.0494874151302821, -0.1164737347816388, 0.11076114141194324, -0.02484730770408594], [1.1111111111111112, -0.05530332062318094, 0.08594555583970975, -0.05421102142175685, 0.014583049087432236, -0.19410587982103422, -0.01992654867499059, 0.04267203873288863, -0.07683820275873962, 0.1495829018407091, 0.019438649931535205], [1.2121212121212122, -0.044299267174359, 0.10730941861756839, -0.03225312091350527, -0.001876647140179686, -0.16054349944981186, -0.0359062754020084, 0.025628930340264932, -0.08487994063474198, 0.17816290330772352, 0.04448260741172188], [1.3131313131313131, -0.018625065012425245, 0.07249436166221607, -0.052328472703100856, -0.004601862552203493, -0.15844526989784982, -0.017908067548457626, 0.041652879004564915, -0.1026882742878037, 0.21644259425505316, 0.03896398687392949], [1.4141414141414141, 0.019982948025866858, 0.029955464112805086, -0.036313373120631834, -0.024714631886575588, -0.14382433496380523, -0.02933036066726697, 0.09153203178498653, -0.14470920142333768, 0.21653070478351424, 0.0400761752719229], [1.5151515151515151, -0.022822002458357214, 0.0010132280460150023, -0.040365209194998475, 0.008808312248070261, -0.18579504334349126, -0.01727826322649849, 0.08226151916423019, -0.19005149111824102, 0.17026716869936204, 0.029157976625642325], [1.6161616161616161, -0.02855275742446166, 0.010559131459922533, -0.05065849999648149, -0.027750100551177482, -0.1591731728644316, 0.001852170568807092, 0.08514741242782979, -0.1862687443555631, 0.20566203893332588, 0.050723709315488856], [1.7171717171717171, -0.05369671568072393, 0.04926324263984809, -0.027153431909470217, 0.0025504702914188847, -0.14703469319920914, 0.04195262497603205, 0.13124572154097908, -0.23402363781452143, 0.20888165946300638, 0.0817757987575107], [1.8181818181818181, -0.009251937830241037, 0.09649356123390893, -0.0375027829437116, -0.03341251713035033, -0.19621744328970508, 0.044976092489951, 0.1264601876961891, -0.26638393489587225, 0.23603031169310082, 0.12969055764389797], [1.9191919191919191, -0.0029858544579611304, 0.09844382511357376, 0.0004669734307934312, -0.041558555052991934, -0.1892812156280778, 0.08791497483415273, 0.0981624393742895, -0.21921953598882585, 0.2690750755287698, 0.13216708565296362], [2.0202020202020203, -0.04171827341358348, 0.08836310594695491, -0.02516933942986221, 0.003538690408055975, -0.16037886212053043, 0.04164932663131457, 0.11190639756077839, -0.21858959033202277, 0.29986202539568235, 0.12690640455484123], [2.121212121212121, -0.026361729088059664, 0.08482080618249777, -0.03687924572183858, -0.011772483988344554, -0.17053949085751194, 0.00046456699191643053, 0.07064866254906244, -0.2069139689765679, 0.3469479041025343, 0.08663014279463757], [2.2222222222222223, 0.00887687656924676, 0.11268020003444407, -0.03628693758449636, -0.039437328694606893, -0.17864145202489243, 0.00873867648627346, 0.07330009400745449, -0.22130547825837102, 0.3485346572423149, 0.10293231790655188], [2.323232323232323, -0.01991669698123019, 0.0980895003446153, -0.07264614797774097, -0.08680737368869096, -0.13844768085698017, 0.0047691486831845245, 0.08705072859944069, -0.18822811512121532, 0.38286959480592286, 0.10015836904063666], [2.4242424242424243, -0.0443879751185634, 0.05569553916794839, -0.0633222978467946, -0.07548540044971416, -0.1806692809210965, 0.035486974011705835, 0.10334804858314542, -0.22258118728319914, 0.43198287540206126, 0.13988960287002972], [2.525252525252525, 0.0010768306309531933, 0.061756605691358595, -0.023592036937952032, -0.08212346747233419, -0.18115808791761023, 0.003515769977112407, 0.13314161584051232, -0.1765031009446358, 0.45564438655742273, 0.09926732721304335], [2.6262626262626263, -0.013339256011688009, 0.04278706922131542, -0.023460253512378272, -0.04910696961668919, -0.17181956181047883, 0.026781904594438147, 0.11498252017546848, -0.17277803654891655, 0.4811835927823546, 0.0785758607923184], [2.727272727272727, 0.005854140316139254, 0.022611902473933763, -0.019217195636767048, -0.0653401040684764, -0.21101756438239308, 0.04180105784698823, 0.14330917959681813, -0.13944626293420295, 0.4320061322106965, 0.09540108737854484], [2.8282828282828283, 0.04768355386972702, -0.00878306927695887, 0.009992361680128282, -0.030425404224047194, -0.23689932126418078, 0.04846699113792839, 0.18903622119102076, -0.16275559268350365, 0.4647015484217533, 0.14008163877698557], [2.929292929292929, 0.03384818541774519, -0.00042835412523484565, 0.03521383525909774, -0.056066960924972466, -0.22703508836806793, 0.024041753426694165, 0.14910129938658362, -0.11655646023442773, 0.47233710023989256, 0.18687183159424509], [3.0303030303030303, 0.01647625991848402, -0.009704537431216024, 0.04243299890142927, -0.0676816892304005, -0.20424667342388864, 0.026643497477766395, 0.15968488236951506, -0.1063249970885691, 0.44846332479787104, 0.20192986751217445], [3.131313131313131, 0.04350022514549329, -0.010882183815539417, 0.0284988114709726, -0.08592548376610586, -0.19987376319226977, 0.07241220895789083, 0.1342279626148657, -0.10974862535913261, 0.4201321333497451, 0.17620006823452944], [3.2323232323232323, 0.00213551607232388, 0.0032519554001541363, 0.05310127526648052, -0.10096017705699507, -0.16460041698205763, 0.03971560764218574, 0.10420331604129018, -0.08125978081418735, 0.38652462768240636, 0.17496536379842598], [3.3333333333333335, -0.030920391370552518, 0.013666651039968634, 0.09771853774364862, -0.0770499260098999, -0.18340914339059666, -0.007193974865715699, 0.12016560513932803, -0.0877096899457575, 0.4213708755676279, 0.1624824897908432], [3.4343434343434343, 0.0028716871651035397, 0.0552938583510111, 0.09186278710888526, -0.07756794306088158, -0.21250080132772747, 0.011726221781299045, 0.16356835256079252, -0.11425655384584915, 0.3811588479628387, 0.141521223246375], [3.5353535353535355, 0.004273229494279449, 0.0261572362552144, 0.13029616421867155, -0.03894745218339029, -0.24964867271913382, -0.026178667405890307, 0.2075916679912409, -0.10112521629479637, 0.41753548390971446, 0.16301563137671204], [3.6363636363636362, 0.01663789964976796, 0.009192554224119753, 0.09097371913793423, -0.026354717672698695, -0.237481835478575, -0.06018861540257875, 0.2456955385384506, -0.05753634563626435, 0.4127721063398594, 0.20825375637642726], [3.7373737373737375, -0.0167230807852961, -0.01125773710601562, 0.05936321652062384, -0.06142417135722879, -0.22706401019219863, -0.0746885979713027, 0.22188280557651383, -0.06669419611089207, 0.4285114363538632, 0.23697380677953303], [3.8383838383838382, -0.056539046123589384, 0.024166749143296484, 0.036484842231230635, -0.04722482594755265, -0.18381379265877548, -0.03242448897637597, 0.2058594632530817, -0.09627347594539441, 0.3976690001322558, 0.23587255171519705], [3.9393939393939394, -0.09631990899321712, -0.019007121538874964, 0.049758567545820115, -0.00522305880612018, -0.1382588514197492, -0.026808975026622387, 0.1888567111263076, -0.053881181919816605, 0.41346841727710903, 0.2757336768633223], [4.040404040404041, -0.11559116920122596, -0.011059452253664717, 0.07494549851977395, 0.013589741851713893, -0.1688650852410894, 0.00012124902388626832, 0.21843774993482412, -0.09051716275882941, 0.36873281238814526, 0.3045806806791219], [4.141414141414141, -0.10306769607792361, 0.009671820779958129, 0.06843217953962269, 0.059093241287180145, -0.1352754699513987, -0.01632275225061907, 0.2307460728871941, -0.04347265820468589, 0.41011314797918635, 0.27511664158880117], [4.242424242424242, -0.08158068697635507, 0.05500203411526216, 0.0837123746595331, 0.015147887059701992, -0.10133817699715299, -0.0655515439016606, 0.19108918948031353, -0.061375237690944814, 0.3629677038426524, 0.2879230976710254], [4.343434343434343, -0.11861501862028248, 0.10298129911199594, 0.09484460455535365, 0.03745600592382173, -0.09834445724607155, -0.07967736890715602, 0.1747845464611911, -0.0570363694573714, 0.34217952932003687, 0.32801539849499184], [4.444444444444445, -0.15892693258664428, 0.08074259526551741, 0.09199643143239764, 0.020875562093846882, -0.12866779543071008, -0.06946502233085128, 0.19470453558776768, -0.05465276507386389, 0.3602552764055016, 0.3471550211821037], [4.545454545454545, -0.12353121816012994, 0.10197404051238068, 0.11187687408045857, 0.05107453907697484, -0.0799596287521355, -0.06455474007410475, 0.17277335711001818, -0.06973078604695443, 0.31607730947791857, 0.36112448791230917], [4.646464646464646, -0.15739347319528155, 0.14227434259423494, 0.0905380678550903, 0.08361205126159382, -0.039388128300578064, -0.10350693082097329, 0.19582448970354135, -0.05549151519252056, 0.3252468061436249, 0.31825823666733444], [4.747474747474747, -0.19685446641691323, 0.11129421007785033, 0.06571962233917328, 0.12418739236555718, -0.0844450276587313, -0.09308300136437837, 0.21300864583748158, -0.10414345143833564, 0.2756383378648004, 0.3432978264989444], [4.848484848484849, -0.18045176687460443, 0.06160895785442843, 0.07853100920454456, 0.12768813079603486, -0.05039232497235533, -0.07975366287165517, 0.18672507351407314, -0.08200205563288127, 0.3115321303782288, 0.3439055191964769], [4.94949494949495, -0.19894088742834506, 0.09441617510448592, 0.06046781711506127, 0.1425497490781575, -0.04138913936264941, -0.09339901926996888, 0.20673730146947378, -0.052043996721075014, 0.35483874752889394, 0.37549491997774065], [5.05050505050505, -0.21950621329381093, 0.07497931844448902, 0.014084698355850286, 0.11145207701192321, -0.005318119743034776, -0.0793316856491068, 0.18470384815525118, -0.05601914657339354, 0.3218854870026257, 0.40728471100594577], [5.151515151515151, -0.17621178218408376, 0.0915195521332371, -0.027400415200157187, 0.06937445997481273, -0.020235794108621252, -0.08103658350703909, 0.2044168146870446, -0.01867121321942817, 0.3518979019385557, 0.41343903952604205], [5.252525252525253, -0.22093945135884552, 0.1404364630192523, 0.004808794575441137, 0.1142761846183314, -0.06314757400860863, -0.05073410902420644, 0.2172673225531427, -0.045616936185273814, 0.30265494246569585, 0.4574828032817965], [5.353535353535354, -0.22259940310934528, 0.10109624930557348, 0.006099200672734233, 0.0653098456790781, -0.06732575913615521, -0.09834572876130405, 0.20997842594477784, -0.03711123275685064, 0.278157387410089, 0.4520335059958384], [5.454545454545454, -0.26281685966738466, 0.08714253495460735, 0.01128938921833446, 0.027892140300945743, -0.0856757621076993, -0.14468842227746365, 0.2538082184581818, -0.05659669533416242, 0.32030739440657946, 0.46806321221835323], [5.555555555555555, -0.2254236464619762, 0.057750313908593004, 0.045135408321913664, 0.030566058176540623, -0.04847260891085764, -0.15698562507977926, 0.2701597086938966, -0.011957607747917057, 0.31743241260303057, 0.5149537980494749], [5.656565656565657, -0.21645037613054688, 0.06699688133632227, 0.054426853617729025, -0.005756248222118787, -0.04806878049831733, -0.12261343440495229, 0.22315446307183656, -0.02187090610584448, 0.3112315422662681, 0.47737533585100955], [5.757575757575758, -0.17314836309253648, 0.07091566840669408, 0.08151605285722967, 0.004666228709148946, -0.05196660832482103, -0.15943820922644236, 0.26800295020073744, -0.0043779027251495545, 0.3213463882970833, 0.4700702935860584], [5.858585858585858, -0.16621578394307257, 0.07505163242896146, 0.05465879202693969, -0.029112688955958598, -0.06503022087271437, -0.13521625461430678, 0.2776590615865013, -0.04494323179562125, 0.333574189686588, 0.4629761954531943], [5.959595959595959, -0.16112536111510778, 0.1070378667385187, 0.06758453321398314, -0.04247990091765287, -0.08719093474410317, -0.16156582155830557, 0.24176368901292078, -0.0748356861697864, 0.3570868975898537, 0.5081647511605756], [6.0606060606060606, -0.19243692262281795, 0.15254647251074144, 0.02714743320989569, -0.04431041430002658, -0.05883523199700584, -0.1132589925386685, 0.2106562793596793, -0.050817108482918455, 0.39870214644371565, 0.47793635731634443], [6.161616161616162, -0.20838561398829777, 0.1336769170169893, 0.01702094169946461, -0.02538233852107047, -0.10543040559314545, -0.07639195725875289, 0.2449967368297091, -0.011938892307493967, 0.42159018598965664, 0.4953950108089267], [6.262626262626262, -0.16363829614907258, 0.16449763105832516, 0.03211659692893901, 0.00651603031095687, -0.12363235952096592, -0.1049876943870961, 0.24253979578489565, 0.011334554436213992, 0.3848358351890678, 0.5290028771407445], [6.363636363636363, -0.13634031577760206, 0.16073381005439755, -0.012007764568539005, 0.018377409627434976, -0.08468593091965693, -0.08113591294072144, 0.234444810249734, 0.059449929186828364, 0.42726003717462785, 0.551568337334745], [6.4646464646464645, -0.11682767839296608, 0.14128488077177445, -0.026495456316656577, 0.034522072625519436, -0.09137088806460475, -0.039198209720847074, 0.24188537021154766, 0.021753094526943233, 0.43389562134623844, 0.5446138619981084], [6.565656565656566, -0.14871565182109417, 0.17424237753004024, 0.0019100319849553286, 0.083773872754896, -0.062261852730316564, -0.016543768983726656, 0.22555640670324373, 0.013082652333959936, 0.42994237508792227, 0.5182268997224956], [6.666666666666667, -0.18874392150899966, 0.1454949770257246, -0.04513834507402459, 0.07551923902731286, -0.07179971672862079, -0.06626244062715063, 0.21341972191284614, 0.02589361758152367, 0.4705654941460204, 0.46873570293484695], [6.767676767676767, -0.22485730225062592, 0.131804678660933, -0.06490526563708507, 0.09970930262019898, -0.04063196003284908, -0.045474749265438305, 0.1739920121000114, 0.06002150667448091, 0.493714190154653, 0.4721082002871755], [6.8686868686868685, -0.2535513166047431, 0.1320057371076148, -0.09441260632354136, 0.14202352555228703, -0.04728790063272274, -0.001615740873373142, 0.12524836943549744, 0.048048727248946245, 0.45671657933228077, 0.4276356028203348], [6.96969696969697, -0.21253663201683, 0.09608604458697173, -0.11558254383633451, 0.12850137849370036, -0.0638007870392889, -0.04812020933882495, 0.11996966530795669, 0.0680386162644882, 0.4325545130113222, 0.4548028350888082], [7.070707070707071, -0.23085580731290598, 0.0809355379330261, -0.13941098800923496, 0.13932101402531816, -0.10104613548256419, -0.08756368745093784, 0.1696244670371927, 0.08606135600162187, 0.4591754287941087, 0.4286805065856091], [7.171717171717171, -0.2206004590488264, 0.10465667955465675, -0.14834843161579678, 0.09421955282810428, -0.08889269469095556, -0.06946532099720923, 0.13588382788944892, 0.10872945422321892, 0.435063014429973, 0.45184152382575715], [7.2727272727272725, -0.26634456169398, 0.12622909435206187, -0.186445065560151, 0.10166835410242642, -0.0469226684235935, -0.0701419425419906, 0.1701132748097273, 0.08499916476835229, 0.47232433339583996, 0.41408301925581753], [7.373737373737374, -0.21768964922230039, 0.12111412639889477, -0.18004803334343697, 0.14002748016827318, -0.0415128215771494, -0.08751347582748809, 0.13214689282890302, 0.12637202149968585, 0.4440843826477167, 0.445135384606509], [7.474747474747475, -0.2335113748748071, 0.1318166785424321, -0.17185439567340202, 0.1765317850712973, -0.0326548040962763, -0.08606648036299028, 0.17654839527369157, 0.09689153300516429, 0.42341745852099544, 0.4007524633447051], [7.575757575757575, -0.2525878668375522, 0.09401228764648911, -0.12371694591250817, 0.20735876601263373, -0.039736889581881055, -0.04713788741505995, 0.15753239023496485, 0.14358049237244588, 0.42829693966012794, 0.3721560826678414], [7.6767676767676765, -0.22692479965887297, 0.06172346680337813, -0.0752614535726564, 0.15777298857610955, -0.07556098576250855, -0.026726968513495812, 0.1936832616964019, 0.10552324648635361, 0.4060091154082384, 0.41708951562451824], [7.777777777777778, -0.24433850338068822, 0.09495922168287571, -0.09647024675132795, 0.17073328932861356, -0.1249833059237369, -0.036745529577741104, 0.22054301296169185, 0.15335330656638665, 0.40077298749933093, 0.4017840308385833], [7.878787878787879, -0.2877990778624865, 0.056789319802179564, -0.09194517171689431, 0.1563654332191596, -0.17073686586586795, 0.007226734867366198, 0.21885543483833786, 0.16939976034404575, 0.4100301491556841, 0.409716443415785], [7.979797979797979, -0.30700286250351116, 0.027235772270362748, -0.04885539624760825, 0.12886329750633263, -0.1856207237850308, -0.03867831500892239, 0.18608437170267436, 0.18318407290210367, 0.4092290936828996, 0.4053241269734778], [8.080808080808081, -0.2995577355321243, -0.018616344579469844, -0.07984141116472016, 0.13777843274899293, -0.20045088705860553, -0.07339295305254223, 0.14494902077812516, 0.1443798057097059, 0.4540744728556655, 0.41851003111263196], [8.181818181818182, -0.263996310470014, -0.05757001705231235, -0.11759708133730264, 0.17497465641802964, -0.2326184322354542, -0.08272234830227775, 0.17216769922164088, 0.15417493082313946, 0.4480694029246636, 0.4563903585961941], [8.282828282828282, -0.2924226716245204, -0.06804924689084983, -0.08101629148046674, 0.15371900441696837, -0.26200537326286993, -0.11357280851891882, 0.2001175496319359, 0.12303307931446375, 0.48490951249934766, 0.44203243642610757], [8.383838383838384, -0.33589628689590667, -0.08699159205450242, -0.07705479212357302, 0.13089533098982875, -0.30273801464973027, -0.0886289275927861, 0.19789496181624802, 0.07726158673456288, 0.46444289779751446, 0.39729936985276654], [8.484848484848484, -0.350111152098984, -0.051547111089351075, -0.11975510057732419, 0.11518885450402963, -0.28474060485751457, -0.13209735271484668, 0.21399235036933822, 0.09431116006245657, 0.4929304233874552, 0.3721513012764771], [8.585858585858587, -0.38095997797326325, -0.03223676376691185, -0.12837271619892934, 0.0651987512865527, -0.27440001488621657, -0.12252723578318793, 0.16832527109986425, 0.06859061423972201, 0.5013581805624265, 0.36440427326357533], [8.686868686868687, -0.39269173001648267, -0.007699542417483683, -0.09550706506032669, 0.05477328947734812, -0.30127953865199825, -0.1115492461927611, 0.16180688828574008, 0.03926405595817352, 0.539735964745768, 0.39675825656864316], [8.787878787878787, -0.3623371590517501, -0.02563453612148644, -0.07997993741155737, 0.047923862539244945, -0.27955713819015265, -0.08326218209504789, 0.11242556552901084, 0.03062500066374079, 0.589160056323885, 0.39700227511329816], [8.88888888888889, -0.348704642332408, -0.03452507352744595, -0.1119217952067855, 0.02482344625704145, -0.2503888351296222, -0.07461226675369201, 0.08606194596502367, 0.02485494359994343, 0.6150929575704881, 0.41124828574491806], [8.98989898989899, -0.32744463244674116, -0.015459529925908766, -0.11395636968567736, 0.06489125629920559, -0.20262712732578117, -0.09208844471151888, 0.05415684242371591, 0.034400504739847786, 0.6581961850643782, 0.3784565712171111], [9.09090909090909, -0.3226542387181737, -0.046169842370611905, -0.06537010955256775, 0.1065939926377648, -0.1992783327706226, -0.12567529239090855, 0.040868537904920246, 0.08393356109702907, 0.6330151948952903, 0.34631444405499406], [9.191919191919192, -0.2760193843392182, -0.06898450766307213, -0.03251652205091881, 0.12867600271489077, -0.1944543966485349, -0.15020964414326435, 0.06360606370118572, 0.06291420733492126, 0.6816067837837958, 0.33048095522054677], [9.292929292929292, -0.26389065303206993, -0.11507347026434425, 0.013087388980551104, 0.1642831584557092, -0.14956012115007514, -0.17690561744845806, 0.06764832287727215, 0.018156835907595446, 0.6946829560571791, 0.3083528603465027], [9.393939393939394, -0.31327084784434156, -0.08400473619937476, 0.032611042067471965, 0.17454226337574125, -0.1880688191315526, -0.13995175872954022, 0.08407472448034924, 0.038029155939079004, 0.7037772573508425, 0.35426792049578926], [9.494949494949495, -0.3142058935986316, -0.06348812406995144, -0.01636621022185762, 0.13997159069519882, -0.15879459583556194, -0.11066510175883891, 0.1337026816475659, -0.0007134198097654421, 0.6607583392734975, 0.36251308047923164], [9.595959595959595, -0.3250103705610946, -0.04352694268747587, -0.05088796324367132, 0.12412975685634552, -0.14420662220221997, -0.1340235758098544, 0.11588116210445669, -0.04902657765715783, 0.6655607333385336, 0.31849184506567213], [9.696969696969697, -0.2909919121403937, -0.08226214232233856, -0.033421494039123464, 0.09847559701418847, -0.1368304557084392, -0.11432562452595217, 0.11952865674173498, -0.050175350485801046, 0.68073545351974, 0.33711108366260134], [9.797979797979798, -0.3394029058981474, -0.12530382888531033, -0.044675869210569236, 0.09924719035009606, -0.15122917749935313, -0.10412030432556452, 0.1382280739317157, -0.052844720569949606, 0.6664539978430725, 0.29807158251380467], [9.8989898989899, -0.3658213554996122, -0.12741639914053776, -0.06589123766088176, 0.06141779227400905, -0.19828941742777265, -0.10534004528128424, 0.16857501243703307, -0.026262200504066364, 0.7022584922892326, 0.28204348235021115], [10.0, -0.37924224422194197, -0.0808967525034193, -0.1131625505151774, 0.05086614228967248, -0.165498790153196, -0.1365316358287621, 0.15312187518785908, -0.016312065415761384, 0.6545382396099495, 0.2873157626968275]]}, \"id\": \"el100754535120848\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "                 \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "                 mpld3.draw_figure(\"fig_el1007545351208486469406376\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.40000000000000002, 0.80000000000000016], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535120720\"}, {\"color\": \"#0000FF\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535538512\"}, {\"color\": \"#0000FF\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535539088\"}, {\"color\": \"#0000FF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535539536\"}, {\"color\": \"#0000FF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535539984\"}, {\"color\": \"#FF0000\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535120784\"}, {\"color\": \"#FF0000\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535563152\"}, {\"color\": \"#FF0000\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535176784\"}, {\"color\": \"#FF0000\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535564048\"}, {\"color\": \"#FF0000\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.2, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535564496\"}], \"markers\": [], \"id\": \"el100754535123216\", \"ydomain\": [-0.40000000000000002, 0.80000000000000016], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754535120720\", \"el100754535120720pts\", \"el100754535538512\", \"el100754535538512pts\", \"el100754535539088\", \"el100754535539088pts\", \"el100754535539536\", \"el100754535539536pts\", \"el100754535539984\", \"el100754535539984pts\"], [\"el100754535120784\", \"el100754535120784pts\", \"el100754535563152\", \"el100754535563152pts\", \"el100754535176784\", \"el100754535176784pts\", \"el100754535564048\", \"el100754535564048pts\", \"el100754535564496\", \"el100754535564496pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.03490324833371287, 0.033878183159034826, -0.043003751479301966, 0.04423068190955063, -0.013494933053202929, 0.04028480581396471, -0.007243667236936136, -0.046920402010741186, 0.020367149955244315, -0.03652998201005735], [0.10101010101010101, -0.0183985136332817, -0.013790912780609212, -0.00140808705548226, 0.03374393405304034, 0.006873965696707309, 0.07288334869042817, 0.039744307099609896, -0.01321316645323662, 0.01616648656371075, -0.05965628432488278], [0.20202020202020202, 0.015384499153983034, 0.023866894493403935, -0.03862846743651541, 0.023508567700489126, -0.03631778992185465, 0.10320524134402613, 0.03629769778713273, -0.04458250136578845, -0.01517023524072247, -0.052535706065269056], [0.30303030303030304, -0.015329733245276988, 0.03145039998734311, -0.001333506107658762, 0.013982541629512124, -0.07211358051921785, 0.12348839512127521, 0.027346306015770802, -0.08089916440402208, -0.06399366879155624, -0.08574837123641255], [0.40404040404040403, 0.027931587499750134, 0.0775490663057943, 0.04393185580930728, 0.00019084677943420614, -0.11096473840332573, 0.07675004588105236, 0.014263971373299697, -0.11883024578995964, -0.028913665991720468, -0.05559580967512362], [0.5050505050505051, -0.020293563774255372, 0.10743687528144012, 0.02875148141013957, -0.013154254569664759, -0.0895324845156526, 0.073320156156293, 0.036300603244236784, -0.09159403460012672, -0.04715587009019766, -0.10457439449716963], [0.6060606060606061, -0.023706161477857667, 0.06087535047581206, 0.03634612349830002, 0.015509915555664578, -0.1355981692571969, 0.025815393100450723, 0.01258992772058358, -0.10898044633833692, -0.00020354079559302407, -0.07469873821390871], [0.7070707070707071, -0.0008807521099839025, 0.09368957118405699, 0.017061285773550594, 0.02460124074812832, -0.163869853527821, 0.06742247014449596, 0.01699674551212888, -0.0952653282712404, 0.030930712136593156, -0.06920926295496918], [0.8080808080808081, -0.009182714773362995, 0.13766881718066204, -0.025334727171639232, 0.050962974403679855, -0.1458928740338573, 0.03308788722395107, 0.061476295954851885, -0.10300402254545586, 0.06672724194563752, -0.05855922893432654], [0.9090909090909091, -0.011133099272223432, 0.17237307280242897, -0.03337315098143408, 0.02068622076322453, -0.1922531404778499, 0.0317306066791487, 0.09312949504532494, -0.15233395238691194, 0.0789027363342257, -0.05771689975170664], [1.0101010101010102, -0.027276408255227754, 0.12686455644030115, -0.005271833331570143, 0.04525352441288247, -0.1961826278483047, 0.004048827544546114, 0.0494874151302821, -0.1164737347816388, 0.11076114141194324, -0.02484730770408594], [1.1111111111111112, -0.05530332062318094, 0.08594555583970975, -0.05421102142175685, 0.014583049087432236, -0.19410587982103422, -0.01992654867499059, 0.04267203873288863, -0.07683820275873962, 0.1495829018407091, 0.019438649931535205], [1.2121212121212122, -0.044299267174359, 0.10730941861756839, -0.03225312091350527, -0.001876647140179686, -0.16054349944981186, -0.0359062754020084, 0.025628930340264932, -0.08487994063474198, 0.17816290330772352, 0.04448260741172188], [1.3131313131313131, -0.018625065012425245, 0.07249436166221607, -0.052328472703100856, -0.004601862552203493, -0.15844526989784982, -0.017908067548457626, 0.041652879004564915, -0.1026882742878037, 0.21644259425505316, 0.03896398687392949], [1.4141414141414141, 0.019982948025866858, 0.029955464112805086, -0.036313373120631834, -0.024714631886575588, -0.14382433496380523, -0.02933036066726697, 0.09153203178498653, -0.14470920142333768, 0.21653070478351424, 0.0400761752719229], [1.5151515151515151, -0.022822002458357214, 0.0010132280460150023, -0.040365209194998475, 0.008808312248070261, -0.18579504334349126, -0.01727826322649849, 0.08226151916423019, -0.19005149111824102, 0.17026716869936204, 0.029157976625642325], [1.6161616161616161, -0.02855275742446166, 0.010559131459922533, -0.05065849999648149, -0.027750100551177482, -0.1591731728644316, 0.001852170568807092, 0.08514741242782979, -0.1862687443555631, 0.20566203893332588, 0.050723709315488856], [1.7171717171717171, -0.05369671568072393, 0.04926324263984809, -0.027153431909470217, 0.0025504702914188847, -0.14703469319920914, 0.04195262497603205, 0.13124572154097908, -0.23402363781452143, 0.20888165946300638, 0.0817757987575107], [1.8181818181818181, -0.009251937830241037, 0.09649356123390893, -0.0375027829437116, -0.03341251713035033, -0.19621744328970508, 0.044976092489951, 0.1264601876961891, -0.26638393489587225, 0.23603031169310082, 0.12969055764389797], [1.9191919191919191, -0.0029858544579611304, 0.09844382511357376, 0.0004669734307934312, -0.041558555052991934, -0.1892812156280778, 0.08791497483415273, 0.0981624393742895, -0.21921953598882585, 0.2690750755287698, 0.13216708565296362], [2.0202020202020203, -0.04171827341358348, 0.08836310594695491, -0.02516933942986221, 0.003538690408055975, -0.16037886212053043, 0.04164932663131457, 0.11190639756077839, -0.21858959033202277, 0.29986202539568235, 0.12690640455484123], [2.121212121212121, -0.026361729088059664, 0.08482080618249777, -0.03687924572183858, -0.011772483988344554, -0.17053949085751194, 0.00046456699191643053, 0.07064866254906244, -0.2069139689765679, 0.3469479041025343, 0.08663014279463757], [2.2222222222222223, 0.00887687656924676, 0.11268020003444407, -0.03628693758449636, -0.039437328694606893, -0.17864145202489243, 0.00873867648627346, 0.07330009400745449, -0.22130547825837102, 0.3485346572423149, 0.10293231790655188], [2.323232323232323, -0.01991669698123019, 0.0980895003446153, -0.07264614797774097, -0.08680737368869096, -0.13844768085698017, 0.0047691486831845245, 0.08705072859944069, -0.18822811512121532, 0.38286959480592286, 0.10015836904063666], [2.4242424242424243, -0.0443879751185634, 0.05569553916794839, -0.0633222978467946, -0.07548540044971416, -0.1806692809210965, 0.035486974011705835, 0.10334804858314542, -0.22258118728319914, 0.43198287540206126, 0.13988960287002972], [2.525252525252525, 0.0010768306309531933, 0.061756605691358595, -0.023592036937952032, -0.08212346747233419, -0.18115808791761023, 0.003515769977112407, 0.13314161584051232, -0.1765031009446358, 0.45564438655742273, 0.09926732721304335], [2.6262626262626263, -0.013339256011688009, 0.04278706922131542, -0.023460253512378272, -0.04910696961668919, -0.17181956181047883, 0.026781904594438147, 0.11498252017546848, -0.17277803654891655, 0.4811835927823546, 0.0785758607923184], [2.727272727272727, 0.005854140316139254, 0.022611902473933763, -0.019217195636767048, -0.0653401040684764, -0.21101756438239308, 0.04180105784698823, 0.14330917959681813, -0.13944626293420295, 0.4320061322106965, 0.09540108737854484], [2.8282828282828283, 0.04768355386972702, -0.00878306927695887, 0.009992361680128282, -0.030425404224047194, -0.23689932126418078, 0.04846699113792839, 0.18903622119102076, -0.16275559268350365, 0.4647015484217533, 0.14008163877698557], [2.929292929292929, 0.03384818541774519, -0.00042835412523484565, 0.03521383525909774, -0.056066960924972466, -0.22703508836806793, 0.024041753426694165, 0.14910129938658362, -0.11655646023442773, 0.47233710023989256, 0.18687183159424509], [3.0303030303030303, 0.01647625991848402, -0.009704537431216024, 0.04243299890142927, -0.0676816892304005, -0.20424667342388864, 0.026643497477766395, 0.15968488236951506, -0.1063249970885691, 0.44846332479787104, 0.20192986751217445], [3.131313131313131, 0.04350022514549329, -0.010882183815539417, 0.0284988114709726, -0.08592548376610586, -0.19987376319226977, 0.07241220895789083, 0.1342279626148657, -0.10974862535913261, 0.4201321333497451, 0.17620006823452944], [3.2323232323232323, 0.00213551607232388, 0.0032519554001541363, 0.05310127526648052, -0.10096017705699507, -0.16460041698205763, 0.03971560764218574, 0.10420331604129018, -0.08125978081418735, 0.38652462768240636, 0.17496536379842598], [3.3333333333333335, -0.030920391370552518, 0.013666651039968634, 0.09771853774364862, -0.0770499260098999, -0.18340914339059666, -0.007193974865715699, 0.12016560513932803, -0.0877096899457575, 0.4213708755676279, 0.1624824897908432], [3.4343434343434343, 0.0028716871651035397, 0.0552938583510111, 0.09186278710888526, -0.07756794306088158, -0.21250080132772747, 0.011726221781299045, 0.16356835256079252, -0.11425655384584915, 0.3811588479628387, 0.141521223246375], [3.5353535353535355, 0.004273229494279449, 0.0261572362552144, 0.13029616421867155, -0.03894745218339029, -0.24964867271913382, -0.026178667405890307, 0.2075916679912409, -0.10112521629479637, 0.41753548390971446, 0.16301563137671204], [3.6363636363636362, 0.01663789964976796, 0.009192554224119753, 0.09097371913793423, -0.026354717672698695, -0.237481835478575, -0.06018861540257875, 0.2456955385384506, -0.05753634563626435, 0.4127721063398594, 0.20825375637642726], [3.7373737373737375, -0.0167230807852961, -0.01125773710601562, 0.05936321652062384, -0.06142417135722879, -0.22706401019219863, -0.0746885979713027, 0.22188280557651383, -0.06669419611089207, 0.4285114363538632, 0.23697380677953303], [3.8383838383838382, -0.056539046123589384, 0.024166749143296484, 0.036484842231230635, -0.04722482594755265, -0.18381379265877548, -0.03242448897637597, 0.2058594632530817, -0.09627347594539441, 0.3976690001322558, 0.23587255171519705], [3.9393939393939394, -0.09631990899321712, -0.019007121538874964, 0.049758567545820115, -0.00522305880612018, -0.1382588514197492, -0.026808975026622387, 0.1888567111263076, -0.053881181919816605, 0.41346841727710903, 0.2757336768633223], [4.040404040404041, -0.11559116920122596, -0.011059452253664717, 0.07494549851977395, 0.013589741851713893, -0.1688650852410894, 0.00012124902388626832, 0.21843774993482412, -0.09051716275882941, 0.36873281238814526, 0.3045806806791219], [4.141414141414141, -0.10306769607792361, 0.009671820779958129, 0.06843217953962269, 0.059093241287180145, -0.1352754699513987, -0.01632275225061907, 0.2307460728871941, -0.04347265820468589, 0.41011314797918635, 0.27511664158880117], [4.242424242424242, -0.08158068697635507, 0.05500203411526216, 0.0837123746595331, 0.015147887059701992, -0.10133817699715299, -0.0655515439016606, 0.19108918948031353, -0.061375237690944814, 0.3629677038426524, 0.2879230976710254], [4.343434343434343, -0.11861501862028248, 0.10298129911199594, 0.09484460455535365, 0.03745600592382173, -0.09834445724607155, -0.07967736890715602, 0.1747845464611911, -0.0570363694573714, 0.34217952932003687, 0.32801539849499184], [4.444444444444445, -0.15892693258664428, 0.08074259526551741, 0.09199643143239764, 0.020875562093846882, -0.12866779543071008, -0.06946502233085128, 0.19470453558776768, -0.05465276507386389, 0.3602552764055016, 0.3471550211821037], [4.545454545454545, -0.12353121816012994, 0.10197404051238068, 0.11187687408045857, 0.05107453907697484, -0.0799596287521355, -0.06455474007410475, 0.17277335711001818, -0.06973078604695443, 0.31607730947791857, 0.36112448791230917], [4.646464646464646, -0.15739347319528155, 0.14227434259423494, 0.0905380678550903, 0.08361205126159382, -0.039388128300578064, -0.10350693082097329, 0.19582448970354135, -0.05549151519252056, 0.3252468061436249, 0.31825823666733444], [4.747474747474747, -0.19685446641691323, 0.11129421007785033, 0.06571962233917328, 0.12418739236555718, -0.0844450276587313, -0.09308300136437837, 0.21300864583748158, -0.10414345143833564, 0.2756383378648004, 0.3432978264989444], [4.848484848484849, -0.18045176687460443, 0.06160895785442843, 0.07853100920454456, 0.12768813079603486, -0.05039232497235533, -0.07975366287165517, 0.18672507351407314, -0.08200205563288127, 0.3115321303782288, 0.3439055191964769], [4.94949494949495, -0.19894088742834506, 0.09441617510448592, 0.06046781711506127, 0.1425497490781575, -0.04138913936264941, -0.09339901926996888, 0.20673730146947378, -0.052043996721075014, 0.35483874752889394, 0.37549491997774065], [5.05050505050505, -0.21950621329381093, 0.07497931844448902, 0.014084698355850286, 0.11145207701192321, -0.005318119743034776, -0.0793316856491068, 0.18470384815525118, -0.05601914657339354, 0.3218854870026257, 0.40728471100594577], [5.151515151515151, -0.17621178218408376, 0.0915195521332371, -0.027400415200157187, 0.06937445997481273, -0.020235794108621252, -0.08103658350703909, 0.2044168146870446, -0.01867121321942817, 0.3518979019385557, 0.41343903952604205], [5.252525252525253, -0.22093945135884552, 0.1404364630192523, 0.004808794575441137, 0.1142761846183314, -0.06314757400860863, -0.05073410902420644, 0.2172673225531427, -0.045616936185273814, 0.30265494246569585, 0.4574828032817965], [5.353535353535354, -0.22259940310934528, 0.10109624930557348, 0.006099200672734233, 0.0653098456790781, -0.06732575913615521, -0.09834572876130405, 0.20997842594477784, -0.03711123275685064, 0.278157387410089, 0.4520335059958384], [5.454545454545454, -0.26281685966738466, 0.08714253495460735, 0.01128938921833446, 0.027892140300945743, -0.0856757621076993, -0.14468842227746365, 0.2538082184581818, -0.05659669533416242, 0.32030739440657946, 0.46806321221835323], [5.555555555555555, -0.2254236464619762, 0.057750313908593004, 0.045135408321913664, 0.030566058176540623, -0.04847260891085764, -0.15698562507977926, 0.2701597086938966, -0.011957607747917057, 0.31743241260303057, 0.5149537980494749], [5.656565656565657, -0.21645037613054688, 0.06699688133632227, 0.054426853617729025, -0.005756248222118787, -0.04806878049831733, -0.12261343440495229, 0.22315446307183656, -0.02187090610584448, 0.3112315422662681, 0.47737533585100955], [5.757575757575758, -0.17314836309253648, 0.07091566840669408, 0.08151605285722967, 0.004666228709148946, -0.05196660832482103, -0.15943820922644236, 0.26800295020073744, -0.0043779027251495545, 0.3213463882970833, 0.4700702935860584], [5.858585858585858, -0.16621578394307257, 0.07505163242896146, 0.05465879202693969, -0.029112688955958598, -0.06503022087271437, -0.13521625461430678, 0.2776590615865013, -0.04494323179562125, 0.333574189686588, 0.4629761954531943], [5.959595959595959, -0.16112536111510778, 0.1070378667385187, 0.06758453321398314, -0.04247990091765287, -0.08719093474410317, -0.16156582155830557, 0.24176368901292078, -0.0748356861697864, 0.3570868975898537, 0.5081647511605756], [6.0606060606060606, -0.19243692262281795, 0.15254647251074144, 0.02714743320989569, -0.04431041430002658, -0.05883523199700584, -0.1132589925386685, 0.2106562793596793, -0.050817108482918455, 0.39870214644371565, 0.47793635731634443], [6.161616161616162, -0.20838561398829777, 0.1336769170169893, 0.01702094169946461, -0.02538233852107047, -0.10543040559314545, -0.07639195725875289, 0.2449967368297091, -0.011938892307493967, 0.42159018598965664, 0.4953950108089267], [6.262626262626262, -0.16363829614907258, 0.16449763105832516, 0.03211659692893901, 0.00651603031095687, -0.12363235952096592, -0.1049876943870961, 0.24253979578489565, 0.011334554436213992, 0.3848358351890678, 0.5290028771407445], [6.363636363636363, -0.13634031577760206, 0.16073381005439755, -0.012007764568539005, 0.018377409627434976, -0.08468593091965693, -0.08113591294072144, 0.234444810249734, 0.059449929186828364, 0.42726003717462785, 0.551568337334745], [6.4646464646464645, -0.11682767839296608, 0.14128488077177445, -0.026495456316656577, 0.034522072625519436, -0.09137088806460475, -0.039198209720847074, 0.24188537021154766, 0.021753094526943233, 0.43389562134623844, 0.5446138619981084], [6.565656565656566, -0.14871565182109417, 0.17424237753004024, 0.0019100319849553286, 0.083773872754896, -0.062261852730316564, -0.016543768983726656, 0.22555640670324373, 0.013082652333959936, 0.42994237508792227, 0.5182268997224956], [6.666666666666667, -0.18874392150899966, 0.1454949770257246, -0.04513834507402459, 0.07551923902731286, -0.07179971672862079, -0.06626244062715063, 0.21341972191284614, 0.02589361758152367, 0.4705654941460204, 0.46873570293484695], [6.767676767676767, -0.22485730225062592, 0.131804678660933, -0.06490526563708507, 0.09970930262019898, -0.04063196003284908, -0.045474749265438305, 0.1739920121000114, 0.06002150667448091, 0.493714190154653, 0.4721082002871755], [6.8686868686868685, -0.2535513166047431, 0.1320057371076148, -0.09441260632354136, 0.14202352555228703, -0.04728790063272274, -0.001615740873373142, 0.12524836943549744, 0.048048727248946245, 0.45671657933228077, 0.4276356028203348], [6.96969696969697, -0.21253663201683, 0.09608604458697173, -0.11558254383633451, 0.12850137849370036, -0.0638007870392889, -0.04812020933882495, 0.11996966530795669, 0.0680386162644882, 0.4325545130113222, 0.4548028350888082], [7.070707070707071, -0.23085580731290598, 0.0809355379330261, -0.13941098800923496, 0.13932101402531816, -0.10104613548256419, -0.08756368745093784, 0.1696244670371927, 0.08606135600162187, 0.4591754287941087, 0.4286805065856091], [7.171717171717171, -0.2206004590488264, 0.10465667955465675, -0.14834843161579678, 0.09421955282810428, -0.08889269469095556, -0.06946532099720923, 0.13588382788944892, 0.10872945422321892, 0.435063014429973, 0.45184152382575715], [7.2727272727272725, -0.26634456169398, 0.12622909435206187, -0.186445065560151, 0.10166835410242642, -0.0469226684235935, -0.0701419425419906, 0.1701132748097273, 0.08499916476835229, 0.47232433339583996, 0.41408301925581753], [7.373737373737374, -0.21768964922230039, 0.12111412639889477, -0.18004803334343697, 0.14002748016827318, -0.0415128215771494, -0.08751347582748809, 0.13214689282890302, 0.12637202149968585, 0.4440843826477167, 0.445135384606509], [7.474747474747475, -0.2335113748748071, 0.1318166785424321, -0.17185439567340202, 0.1765317850712973, -0.0326548040962763, -0.08606648036299028, 0.17654839527369157, 0.09689153300516429, 0.42341745852099544, 0.4007524633447051], [7.575757575757575, -0.2525878668375522, 0.09401228764648911, -0.12371694591250817, 0.20735876601263373, -0.039736889581881055, -0.04713788741505995, 0.15753239023496485, 0.14358049237244588, 0.42829693966012794, 0.3721560826678414], [7.6767676767676765, -0.22692479965887297, 0.06172346680337813, -0.0752614535726564, 0.15777298857610955, -0.07556098576250855, -0.026726968513495812, 0.1936832616964019, 0.10552324648635361, 0.4060091154082384, 0.41708951562451824], [7.777777777777778, -0.24433850338068822, 0.09495922168287571, -0.09647024675132795, 0.17073328932861356, -0.1249833059237369, -0.036745529577741104, 0.22054301296169185, 0.15335330656638665, 0.40077298749933093, 0.4017840308385833], [7.878787878787879, -0.2877990778624865, 0.056789319802179564, -0.09194517171689431, 0.1563654332191596, -0.17073686586586795, 0.007226734867366198, 0.21885543483833786, 0.16939976034404575, 0.4100301491556841, 0.409716443415785], [7.979797979797979, -0.30700286250351116, 0.027235772270362748, -0.04885539624760825, 0.12886329750633263, -0.1856207237850308, -0.03867831500892239, 0.18608437170267436, 0.18318407290210367, 0.4092290936828996, 0.4053241269734778], [8.080808080808081, -0.2995577355321243, -0.018616344579469844, -0.07984141116472016, 0.13777843274899293, -0.20045088705860553, -0.07339295305254223, 0.14494902077812516, 0.1443798057097059, 0.4540744728556655, 0.41851003111263196], [8.181818181818182, -0.263996310470014, -0.05757001705231235, -0.11759708133730264, 0.17497465641802964, -0.2326184322354542, -0.08272234830227775, 0.17216769922164088, 0.15417493082313946, 0.4480694029246636, 0.4563903585961941], [8.282828282828282, -0.2924226716245204, -0.06804924689084983, -0.08101629148046674, 0.15371900441696837, -0.26200537326286993, -0.11357280851891882, 0.2001175496319359, 0.12303307931446375, 0.48490951249934766, 0.44203243642610757], [8.383838383838384, -0.33589628689590667, -0.08699159205450242, -0.07705479212357302, 0.13089533098982875, -0.30273801464973027, -0.0886289275927861, 0.19789496181624802, 0.07726158673456288, 0.46444289779751446, 0.39729936985276654], [8.484848484848484, -0.350111152098984, -0.051547111089351075, -0.11975510057732419, 0.11518885450402963, -0.28474060485751457, -0.13209735271484668, 0.21399235036933822, 0.09431116006245657, 0.4929304233874552, 0.3721513012764771], [8.585858585858587, -0.38095997797326325, -0.03223676376691185, -0.12837271619892934, 0.0651987512865527, -0.27440001488621657, -0.12252723578318793, 0.16832527109986425, 0.06859061423972201, 0.5013581805624265, 0.36440427326357533], [8.686868686868687, -0.39269173001648267, -0.007699542417483683, -0.09550706506032669, 0.05477328947734812, -0.30127953865199825, -0.1115492461927611, 0.16180688828574008, 0.03926405595817352, 0.539735964745768, 0.39675825656864316], [8.787878787878787, -0.3623371590517501, -0.02563453612148644, -0.07997993741155737, 0.047923862539244945, -0.27955713819015265, -0.08326218209504789, 0.11242556552901084, 0.03062500066374079, 0.589160056323885, 0.39700227511329816], [8.88888888888889, -0.348704642332408, -0.03452507352744595, -0.1119217952067855, 0.02482344625704145, -0.2503888351296222, -0.07461226675369201, 0.08606194596502367, 0.02485494359994343, 0.6150929575704881, 0.41124828574491806], [8.98989898989899, -0.32744463244674116, -0.015459529925908766, -0.11395636968567736, 0.06489125629920559, -0.20262712732578117, -0.09208844471151888, 0.05415684242371591, 0.034400504739847786, 0.6581961850643782, 0.3784565712171111], [9.09090909090909, -0.3226542387181737, -0.046169842370611905, -0.06537010955256775, 0.1065939926377648, -0.1992783327706226, -0.12567529239090855, 0.040868537904920246, 0.08393356109702907, 0.6330151948952903, 0.34631444405499406], [9.191919191919192, -0.2760193843392182, -0.06898450766307213, -0.03251652205091881, 0.12867600271489077, -0.1944543966485349, -0.15020964414326435, 0.06360606370118572, 0.06291420733492126, 0.6816067837837958, 0.33048095522054677], [9.292929292929292, -0.26389065303206993, -0.11507347026434425, 0.013087388980551104, 0.1642831584557092, -0.14956012115007514, -0.17690561744845806, 0.06764832287727215, 0.018156835907595446, 0.6946829560571791, 0.3083528603465027], [9.393939393939394, -0.31327084784434156, -0.08400473619937476, 0.032611042067471965, 0.17454226337574125, -0.1880688191315526, -0.13995175872954022, 0.08407472448034924, 0.038029155939079004, 0.7037772573508425, 0.35426792049578926], [9.494949494949495, -0.3142058935986316, -0.06348812406995144, -0.01636621022185762, 0.13997159069519882, -0.15879459583556194, -0.11066510175883891, 0.1337026816475659, -0.0007134198097654421, 0.6607583392734975, 0.36251308047923164], [9.595959595959595, -0.3250103705610946, -0.04352694268747587, -0.05088796324367132, 0.12412975685634552, -0.14420662220221997, -0.1340235758098544, 0.11588116210445669, -0.04902657765715783, 0.6655607333385336, 0.31849184506567213], [9.696969696969697, -0.2909919121403937, -0.08226214232233856, -0.033421494039123464, 0.09847559701418847, -0.1368304557084392, -0.11432562452595217, 0.11952865674173498, -0.050175350485801046, 0.68073545351974, 0.33711108366260134], [9.797979797979798, -0.3394029058981474, -0.12530382888531033, -0.044675869210569236, 0.09924719035009606, -0.15122917749935313, -0.10412030432556452, 0.1382280739317157, -0.052844720569949606, 0.6664539978430725, 0.29807158251380467], [9.8989898989899, -0.3658213554996122, -0.12741639914053776, -0.06589123766088176, 0.06141779227400905, -0.19828941742777265, -0.10534004528128424, 0.16857501243703307, -0.026262200504066364, 0.7022584922892326, 0.28204348235021115], [10.0, -0.37924224422194197, -0.0808967525034193, -0.1131625505151774, 0.05086614228967248, -0.165498790153196, -0.1365316358287621, 0.15312187518785908, -0.016312065415761384, 0.6545382396099495, 0.2873157626968275]]}, \"id\": \"el100754535120848\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 2,
       "text": [
        "<IPython.core.display.HTML at 0x10e577fd0>"
       ]
      }
     ],
     "prompt_number": 2
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## Legends for different axes\n",
      "\n",
      "By default, the legend is shown to the right of the first axes. However, through the use of the optional keyword argument 'ax', we can specify the axes to the right of which the legend will be shown."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "N_paths = 5\n",
      "N_steps = 100\n",
      "\n",
      "x = np.linspace(0, 10, 100)\n",
      "y = 0.1 * (np.random.random((N_paths, N_steps)) - 0.5)\n",
      "y = y.cumsum(1)\n",
      "\n",
      "fig = plt.figure()\n",
      "ax1 = fig.add_subplot(2,1,1)\n",
      "ax2 = fig.add_subplot(2,1,2)\n",
      "\n",
      "labels = [\"a\", \"b\", \"c\", \"d\", \"e\"]\n",
      "l1 = ax1.plot(x, y.T, lw=4, alpha=0.1)\n",
      "s1 = []\n",
      "for i in range(N_paths):\n",
      "    s = ax2.scatter(x,y[i, :], c=next(ax2._get_lines.color_cycle), alpha=0.1)\n",
      "    s1.append(s)\n",
      "    \n",
      "plugins.connect(fig, plugins.InteractiveLegendPlugin(l1, labels, ax=ax1))\n",
      "plugins.connect(fig, plugins.InteractiveLegendPlugin(s1, labels, ax=ax2))\n",
      "mpld3.display()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "    .legend-box {\n",
        "      cursor: pointer;\n",
        "    }\n",
        "    \n",
        "    .legend-box {\n",
        "      cursor: pointer;\n",
        "    }\n",
        "    \n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el1007545350784807465296436\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "       mpld3.draw_figure(\"fig_el1007545350784807465296436\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.40000000000000002, 0.40000000000000002], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 10, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535757904\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535758480\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535775504\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535775952\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535776400\"}], \"markers\": [], \"id\": \"el100754535078544\", \"ydomain\": [-0.40000000000000002, 0.40000000000000002], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.54772727272727284, 0.77500000000000002, 0.35227272727272718]}, {\"xlim\": [-2.0, 12.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-2.0, 12.0], \"ylim\": [-0.40000000000000002, 0.40000000000000002], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 10, \"tickvalues\": null}], \"lines\": [], \"markers\": [], \"id\": \"el100754534880656\", \"ydomain\": [-0.40000000000000002, 0.40000000000000002], \"collections\": [{\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 1, \"id\": \"el100754535084624\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#0000FF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 2, \"id\": \"el100754535817488\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#007F00\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 3, \"id\": \"el100754535819408\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#FF0000\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 4, \"id\": \"el100754535821200\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#00BFBF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 5, \"id\": \"el100754535822800\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#BF00BF\"]}], \"xscale\": \"linear\", \"bbox\": [0.125, 0.12500000000000011, 0.77500000000000002, 0.35227272727272724]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754535757904\", \"el100754535757904pts\"], [\"el100754535758480\", \"el100754535758480pts\"], [\"el100754535775504\", \"el100754535775504pts\"], [\"el100754535775952\", \"el100754535775952pts\"], [\"el100754535776400\", \"el100754535776400pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": \"el100754535078544\", \"alpha_sel\": 1}, {\"element_ids\": [[\"el100754535084624\"], [\"el100754535817488\"], [\"el100754535819408\"], [\"el100754535821200\"], [\"el100754535822800\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": \"el100754534880656\", \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.04115664770414362, -0.048049157353564034, 0.03788510057419991, -0.045536568788255086, 0.04531887786735557], [0.10101010101010101, -0.08927699100122766, -0.05460463494448629, 0.01776348698207584, -0.08971278316961129, 0.07323942479393558], [0.20202020202020202, -0.04967921129298758, -0.0076984490292012, 0.010870272450665864, -0.08340578274392707, 0.08921842614934253], [0.30303030303030304, -0.05971690461547298, -0.017518131981640934, -0.004344706483998638, -0.047069336230050336, 0.07254560149663397], [0.40404040404040403, -0.10515036247494106, -0.031209345706198974, -0.006442225227171626, -0.09134302631466254, 0.03628997932691944], [0.5050505050505051, -0.062345644328017515, 0.01116532069884138, -0.037919948762198015, -0.14073868457819677, 0.07591532681220155], [0.6060606060606061, -0.08533223573732707, -0.028203720025242768, -0.008802224614687555, -0.1562257957062492, 0.11605519636214504], [0.7070707070707071, -0.11586004193599066, -0.070995677967056, -0.010086241970747574, -0.11937823501547536, 0.15537099747104507], [0.8080808080808081, -0.10430297372870087, -0.0901470012353897, -0.026418826616197592, -0.10030979373097956, 0.1909740864645194], [0.9090909090909091, -0.11563452171587255, -0.13969764703429205, 0.006757556260636094, -0.0902201722654079, 0.14881381980218983], [1.0101010101010102, -0.09711637434910542, -0.15526723897955794, 0.014681905664425616, -0.041880952019327684, 0.15075083857997695], [1.1111111111111112, -0.09266250639115454, -0.16647196608810558, -0.01188775374410997, -0.06705113439408865, 0.1696989935866236], [1.2121212121212122, -0.1212744067723128, -0.16932562345367194, 0.03389530250570889, -0.1168358816499669, 0.14473821482480703], [1.3131313131313131, -0.08207730311034678, -0.16689889591128737, 0.058831874923272826, -0.09552030053644277, 0.18346365902389236], [1.4141414141414141, -0.04023642558896386, -0.15579264975319868, 0.03209590241160251, -0.13554731226819958, 0.13969645224319], [1.5151515151515151, -0.0838965190150158, -0.11689057090398436, 0.03875290574828937, -0.16686640062035318, 0.09750031763871396], [1.6161616161616161, -0.06970079822576261, -0.07166452390780956, 0.04006006779450986, -0.12947009961729783, 0.060469993262570194], [1.7171717171717171, -0.0997770656953606, -0.07286977750473722, 0.05674081766789696, -0.10758573011062532, 0.036307897478279345], [1.8181818181818181, -0.06724943624969865, -0.06941219656851572, 0.04426637350123843, -0.1224418713792689, 0.02510996375790598], [1.9191919191919191, -0.09779823222555531, -0.10875059220936381, 0.035417775249112445, -0.17204604574060264, -0.019007166292564645], [2.0202020202020203, -0.04857455043350259, -0.07503609642580429, 0.055497096584885816, -0.17201696140550776, -0.02921473453893564], [2.121212121212121, -0.02471701492124017, -0.08095501882653716, 0.04607801569375233, -0.1955175291292604, -0.07149493712817062], [2.2222222222222223, -0.018713932845432518, -0.1288263740052685, 0.08733068763245039, -0.1773893759390561, -0.029015207578141744], [2.323232323232323, -0.04246078967409447, -0.17255757978220126, 0.11007374674915504, -0.17955008845651121, -0.04631699773199564], [2.4242424242424243, -0.08575199353340732, -0.1867872581615811, 0.11334442028975686, -0.1934860278064171, -0.05177563017841434], [2.525252525252525, -0.08550651494738654, -0.22023363736928175, 0.15034695867102346, -0.15018688649707682, -0.07217596669805475], [2.6262626262626263, -0.1322816753976196, -0.1829956174511691, 0.12443935397581267, -0.18041680564761559, -0.10517990841365402], [2.727272727272727, -0.11255366137331435, -0.19340505250548135, 0.1082392415595328, -0.1762463488139595, -0.12493383259469464], [2.8282828282828283, -0.12855344675886465, -0.2433300914296911, 0.10934061260186867, -0.1577418255817036, -0.0772412538135785], [2.929292929292929, -0.15816239605031673, -0.2221004340201769, 0.10597113084227949, -0.19584890771106545, -0.07904738769545379], [3.0303030303030303, -0.16407954588034607, -0.20622452852261977, 0.13717018459062133, -0.24069060199632886, -0.050768945398397325], [3.131313131313131, -0.1240376523522965, -0.20260458851067117, 0.15353639998906363, -0.21852038111420002, -0.0313420495981034], [3.2323232323232323, -0.17353709306990617, -0.20162376372716836, 0.10378280043467933, -0.20154128525676412, -0.07126814342161654], [3.3333333333333335, -0.15460242498840904, -0.19204308443854087, 0.08969687323547383, -0.22785991760987467, -0.10289189757447348], [3.4343434343434343, -0.12865068444478517, -0.1984256404595091, 0.05160487205293175, -0.2310280472684826, -0.10667599271082394], [3.5353535353535355, -0.08369811905601707, -0.15719504951205326, 0.021089358596747744, -0.25544314354835657, -0.07460176180781192], [3.6363636363636362, -0.06359995808651754, -0.14939650685527545, 0.04950373528410001, -0.282759903720899, -0.11482899633755039], [3.7373737373737375, -0.017234882553026035, -0.1956229398027834, 0.08659930988942666, -0.30979989593605867, -0.12988246164067946], [3.8383838383838382, 0.03070309278289831, -0.20159854959116505, 0.10214570684508253, -0.2682228089415979, -0.16348816836494934], [3.9393939393939394, 0.0499667116452898, -0.19644519398982477, 0.1354209867550918, -0.284517941436369, -0.13868094883019763], [4.040404040404041, 0.043763314274207044, -0.1992432087120353, 0.1595757055973647, -0.2616523609275467, -0.09596716706346856], [4.141414141414141, 0.08388593083792664, -0.2281616529491856, 0.12865962063273115, -0.290109000033615, -0.12794381450931447], [4.242424242424242, 0.07266201797352007, -0.2670065053281189, 0.12610353697572213, -0.30874211306197225, -0.13503984880196723], [4.343434343434343, 0.06901442354188567, -0.29021721494354774, 0.11070811519089516, -0.26032536826191427, -0.09424695209657388], [4.444444444444445, 0.06436390309720812, -0.2412040112556873, 0.14155798614013712, -0.30020105419465554, -0.13325521968592943], [4.545454545454545, 0.0769874908168521, -0.20817136400769543, 0.11347624433597994, -0.28671994790435174, -0.16270963314118853], [4.646464646464646, 0.03278735730204044, -0.16091948163129446, 0.0905723171934864, -0.31533693457766476, -0.12364463661552036], [4.747474747474747, 0.0444877728859006, -0.11544235072375078, 0.05280865885909375, -0.3094707598034151, -0.09453844998889094], [4.848484848484849, 0.017672317380623997, -0.12109908132539254, 0.09502774780309226, -0.29323367858908694, -0.07301929688367984], [4.94949494949495, -0.016415277190935544, -0.1658728958874847, 0.08474611744133873, -0.3095525147691089, -0.03906733223990159], [5.05050505050505, -0.04666580028857252, -0.13517439820015506, 0.04255611702867819, -0.28186181335750377, -0.07450723573491692], [5.151515151515151, -0.003935537615043352, -0.15087209698219303, 0.04449806667473447, -0.2509648626202112, -0.028947583431608706], [5.252525252525253, -0.028389221168473727, -0.17304281004682687, 0.0936534867385013, -0.2287020207504156, -0.007245865277220487], [5.353535353535354, -0.0407106833311685, -0.17421097944247202, 0.08630051450886549, -0.22674232625199156, 0.010140087637844786], [5.454545454545454, 0.0017440203509418786, -0.14520594483493418, 0.08087139462014056, -0.22522295085469432, 0.039155845639200756], [5.555555555555555, 0.02852644112034959, -0.1089149177779005, 0.09714686369281925, -0.18902636180551097, 0.0863180688061832], [5.656565656565657, 0.05097350288168366, -0.12893822875102148, 0.08208750235142574, -0.18997111954003296, 0.11853287911704424], [5.757575757575758, 0.021067501885617675, -0.1090228178579104, 0.06835291696764641, -0.18746270419305092, 0.10111729604077821], [5.858585858585858, -0.0013393449799598486, -0.10747528464275583, 0.04107350340317957, -0.16921402593031892, 0.10931615013888187], [5.959595959595959, -0.00946189978038165, -0.0753022447561143, 0.0476935973308841, -0.18361801396190455, 0.06566367128235472], [6.0606060606060606, -0.0017931197424129238, -0.029968966428255535, 0.05287635335855561, -0.20201113950929334, 0.029226861487080612], [6.161616161616162, -0.022900257698899078, 0.015779474355561013, 0.0844250681075579, -0.23140208113671643, 0.048251502441302815], [6.262626262626262, 0.01674777843506988, 0.03360143887747019, 0.09464971659933803, -0.18306377826803888, 0.053874342070306454], [6.363636363636363, 0.055934338437090024, -0.003895707415064363, 0.0984099046797347, -0.16616954672369832, 0.043722465646923496], [6.4646464646464645, 0.0898148470247052, -0.04584209746337732, 0.07113595117742758, -0.12690269560378328, 0.09285295416334531], [6.565656565656566, 0.09346919279667505, -0.06363840665726091, 0.07895180200756932, -0.14346218320974016, 0.05190024648633341], [6.666666666666667, 0.09237832109376351, -0.04936954527918082, 0.09629453794866577, -0.15537086509165066, 0.024458378565855605], [6.767676767676767, 0.06647387671349198, -0.021957389480929113, 0.1098722250682925, -0.14139355826941102, 0.045987795309294754], [6.8686868686868685, 0.09546113704965674, -0.07112787946418685, 0.1497428426240836, -0.188121908581815, 0.07413394892841604], [6.96969696969697, 0.1115760981728907, -0.06389319415210967, 0.1308985100136493, -0.2341399746266031, 0.05582507663675472], [7.070707070707071, 0.10479125434240265, -0.07099262677075889, 0.17328370709025298, -0.234059864263707, 0.03797003474382436], [7.171717171717171, 0.13232251739194772, -0.058498408769117737, 0.14463162818061243, -0.18817103686934447, 0.08706905241135049], [7.2727272727272725, 0.11547301515200643, -0.07489169098828122, 0.10269018368550431, -0.21104132014524163, 0.12820198485429607], [7.373737373737374, 0.14310350434025393, -0.025717407216927092, 0.11140164166411834, -0.19314757712674163, 0.16869068925327488], [7.474747474747475, 0.14414890505406702, 0.003951066334028343, 0.09858290034107764, -0.19442546722160467, 0.16048163969005078], [7.575757575757575, 0.14874983273279394, 0.04618066263373219, 0.14461543332168236, -0.22165637998368246, 0.14306348657133466], [7.6767676767676765, 0.19555292325066176, 0.004863784419171735, 0.10372468320778394, -0.2700678820543884, 0.12805540479066788], [7.777777777777778, 0.18368589692431972, -0.028751275076283722, 0.13091035054514422, -0.31780241524233244, 0.11484981440899783], [7.878787878787879, 0.1771880980798672, -0.009641625082180003, 0.09765515178755861, -0.34248972023659563, 0.15214464259341196], [7.979797979797979, 0.1873652469348349, -0.017525615539447856, 0.05897215771537501, -0.33108172741778286, 0.13071901814969164], [8.080808080808081, 0.22477296914921863, -0.017102352718936183, 0.09460156842887596, -0.28879998568633863, 0.10519191528660801], [8.181818181818182, 0.2738633512195425, -0.0017174003695022144, 0.11515523106981994, -0.28787761332120454, 0.0814920542405334], [8.282828282828282, 0.23368728366126587, 0.036720362680383666, 0.14379757525737963, -0.32453856342402926, 0.07435738911327806], [8.383838383838384, 0.27058163049858214, 0.00635624182072398, 0.10972930500613887, -0.2847561331095349, 0.10400330653226986], [8.484848484848484, 0.2565869271055691, 0.04806456153476761, 0.1531451019126603, -0.2522152352217555, 0.14374211559498512], [8.585858585858587, 0.25228851769076843, 0.006101819620032541, 0.168365939629834, -0.2349333212314259, 0.18911931635458915], [8.686868686868687, 0.26913571462637315, -0.011050398316563265, 0.14845654038657694, -0.2804098830419664, 0.20550970027142007], [8.787878787878787, 0.23157569567121947, -0.0004265554098648195, 0.10367373119926179, -0.28552089890673177, 0.22082836257190425], [8.88888888888889, 0.25386965043872683, 0.006645234092682047, 0.08068995147761558, -0.23897799348435161, 0.2539674755909058], [8.98989898989899, 0.2598821154362591, -0.03539159139760611, 0.05634463688776137, -0.2234049057541872, 0.2601597120997219], [9.09090909090909, 0.2625694921753903, -0.035837872773446834, 0.06650845999952401, -0.17513311737368592, 0.27310868840021874], [9.191919191919192, 0.28884823624584716, -0.039021578733584875, 0.017238727001464088, -0.17729911335170112, 0.2393602759593848], [9.292929292929292, 0.32128439103609513, -0.07388040150481341, -0.005340630860500913, -0.22135661834938805, 0.2449639511572952], [9.393939393939394, 0.28338272017298627, -0.11746953582116887, 0.04364362507368495, -0.17788602005000806, 0.20949543072409033], [9.494949494949495, 0.3302669629318954, -0.09457239524338934, 0.07263077221283612, -0.21200951061216686, 0.23312212899710255], [9.595959595959595, 0.3054449932012254, -0.10194952043588329, 0.09621121691267759, -0.2087852039252722, 0.22419621639801007], [9.696969696969697, 0.27320314731274414, -0.14721359008909235, 0.1270775779944514, -0.2371223198457389, 0.22163551825263458], [9.797979797979798, 0.29885520661421705, -0.18433715775756987, 0.1605408085236631, -0.21493553081986744, 0.2404701335232085], [9.8989898989899, 0.34125246806174536, -0.19718516739874217, 0.15638234106502386, -0.24734707836319134, 0.209808335283991], [10.0, 0.322509636449207, -0.24185140609223735, 0.11316676939611744, -0.2524067227864443, 0.1977981961999645]]}, \"id\": \"el100754535078480\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "         \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "         mpld3.draw_figure(\"fig_el1007545350784807465296436\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.40000000000000002, 0.40000000000000002], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 10, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535757904\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535758480\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535775504\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535775952\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535776400\"}], \"markers\": [], \"id\": \"el100754535078544\", \"ydomain\": [-0.40000000000000002, 0.40000000000000002], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.54772727272727284, 0.77500000000000002, 0.35227272727272718]}, {\"xlim\": [-2.0, 12.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-2.0, 12.0], \"ylim\": [-0.40000000000000002, 0.40000000000000002], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 10, \"tickvalues\": null}], \"lines\": [], \"markers\": [], \"id\": \"el100754534880656\", \"ydomain\": [-0.40000000000000002, 0.40000000000000002], \"collections\": [{\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 1, \"id\": \"el100754535084624\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#0000FF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 2, \"id\": \"el100754535817488\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#007F00\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 3, \"id\": \"el100754535819408\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#FF0000\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 4, \"id\": \"el100754535821200\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#00BFBF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 5, \"id\": \"el100754535822800\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#BF00BF\"]}], \"xscale\": \"linear\", \"bbox\": [0.125, 0.12500000000000011, 0.77500000000000002, 0.35227272727272724]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754535757904\", \"el100754535757904pts\"], [\"el100754535758480\", \"el100754535758480pts\"], [\"el100754535775504\", \"el100754535775504pts\"], [\"el100754535775952\", \"el100754535775952pts\"], [\"el100754535776400\", \"el100754535776400pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": \"el100754535078544\", \"alpha_sel\": 1}, {\"element_ids\": [[\"el100754535084624\"], [\"el100754535817488\"], [\"el100754535819408\"], [\"el100754535821200\"], [\"el100754535822800\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": \"el100754534880656\", \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.04115664770414362, -0.048049157353564034, 0.03788510057419991, -0.045536568788255086, 0.04531887786735557], [0.10101010101010101, -0.08927699100122766, -0.05460463494448629, 0.01776348698207584, -0.08971278316961129, 0.07323942479393558], [0.20202020202020202, -0.04967921129298758, -0.0076984490292012, 0.010870272450665864, -0.08340578274392707, 0.08921842614934253], [0.30303030303030304, -0.05971690461547298, -0.017518131981640934, -0.004344706483998638, -0.047069336230050336, 0.07254560149663397], [0.40404040404040403, -0.10515036247494106, -0.031209345706198974, -0.006442225227171626, -0.09134302631466254, 0.03628997932691944], [0.5050505050505051, -0.062345644328017515, 0.01116532069884138, -0.037919948762198015, -0.14073868457819677, 0.07591532681220155], [0.6060606060606061, -0.08533223573732707, -0.028203720025242768, -0.008802224614687555, -0.1562257957062492, 0.11605519636214504], [0.7070707070707071, -0.11586004193599066, -0.070995677967056, -0.010086241970747574, -0.11937823501547536, 0.15537099747104507], [0.8080808080808081, -0.10430297372870087, -0.0901470012353897, -0.026418826616197592, -0.10030979373097956, 0.1909740864645194], [0.9090909090909091, -0.11563452171587255, -0.13969764703429205, 0.006757556260636094, -0.0902201722654079, 0.14881381980218983], [1.0101010101010102, -0.09711637434910542, -0.15526723897955794, 0.014681905664425616, -0.041880952019327684, 0.15075083857997695], [1.1111111111111112, -0.09266250639115454, -0.16647196608810558, -0.01188775374410997, -0.06705113439408865, 0.1696989935866236], [1.2121212121212122, -0.1212744067723128, -0.16932562345367194, 0.03389530250570889, -0.1168358816499669, 0.14473821482480703], [1.3131313131313131, -0.08207730311034678, -0.16689889591128737, 0.058831874923272826, -0.09552030053644277, 0.18346365902389236], [1.4141414141414141, -0.04023642558896386, -0.15579264975319868, 0.03209590241160251, -0.13554731226819958, 0.13969645224319], [1.5151515151515151, -0.0838965190150158, -0.11689057090398436, 0.03875290574828937, -0.16686640062035318, 0.09750031763871396], [1.6161616161616161, -0.06970079822576261, -0.07166452390780956, 0.04006006779450986, -0.12947009961729783, 0.060469993262570194], [1.7171717171717171, -0.0997770656953606, -0.07286977750473722, 0.05674081766789696, -0.10758573011062532, 0.036307897478279345], [1.8181818181818181, -0.06724943624969865, -0.06941219656851572, 0.04426637350123843, -0.1224418713792689, 0.02510996375790598], [1.9191919191919191, -0.09779823222555531, -0.10875059220936381, 0.035417775249112445, -0.17204604574060264, -0.019007166292564645], [2.0202020202020203, -0.04857455043350259, -0.07503609642580429, 0.055497096584885816, -0.17201696140550776, -0.02921473453893564], [2.121212121212121, -0.02471701492124017, -0.08095501882653716, 0.04607801569375233, -0.1955175291292604, -0.07149493712817062], [2.2222222222222223, -0.018713932845432518, -0.1288263740052685, 0.08733068763245039, -0.1773893759390561, -0.029015207578141744], [2.323232323232323, -0.04246078967409447, -0.17255757978220126, 0.11007374674915504, -0.17955008845651121, -0.04631699773199564], [2.4242424242424243, -0.08575199353340732, -0.1867872581615811, 0.11334442028975686, -0.1934860278064171, -0.05177563017841434], [2.525252525252525, -0.08550651494738654, -0.22023363736928175, 0.15034695867102346, -0.15018688649707682, -0.07217596669805475], [2.6262626262626263, -0.1322816753976196, -0.1829956174511691, 0.12443935397581267, -0.18041680564761559, -0.10517990841365402], [2.727272727272727, -0.11255366137331435, -0.19340505250548135, 0.1082392415595328, -0.1762463488139595, -0.12493383259469464], [2.8282828282828283, -0.12855344675886465, -0.2433300914296911, 0.10934061260186867, -0.1577418255817036, -0.0772412538135785], [2.929292929292929, -0.15816239605031673, -0.2221004340201769, 0.10597113084227949, -0.19584890771106545, -0.07904738769545379], [3.0303030303030303, -0.16407954588034607, -0.20622452852261977, 0.13717018459062133, -0.24069060199632886, -0.050768945398397325], [3.131313131313131, -0.1240376523522965, -0.20260458851067117, 0.15353639998906363, -0.21852038111420002, -0.0313420495981034], [3.2323232323232323, -0.17353709306990617, -0.20162376372716836, 0.10378280043467933, -0.20154128525676412, -0.07126814342161654], [3.3333333333333335, -0.15460242498840904, -0.19204308443854087, 0.08969687323547383, -0.22785991760987467, -0.10289189757447348], [3.4343434343434343, -0.12865068444478517, -0.1984256404595091, 0.05160487205293175, -0.2310280472684826, -0.10667599271082394], [3.5353535353535355, -0.08369811905601707, -0.15719504951205326, 0.021089358596747744, -0.25544314354835657, -0.07460176180781192], [3.6363636363636362, -0.06359995808651754, -0.14939650685527545, 0.04950373528410001, -0.282759903720899, -0.11482899633755039], [3.7373737373737375, -0.017234882553026035, -0.1956229398027834, 0.08659930988942666, -0.30979989593605867, -0.12988246164067946], [3.8383838383838382, 0.03070309278289831, -0.20159854959116505, 0.10214570684508253, -0.2682228089415979, -0.16348816836494934], [3.9393939393939394, 0.0499667116452898, -0.19644519398982477, 0.1354209867550918, -0.284517941436369, -0.13868094883019763], [4.040404040404041, 0.043763314274207044, -0.1992432087120353, 0.1595757055973647, -0.2616523609275467, -0.09596716706346856], [4.141414141414141, 0.08388593083792664, -0.2281616529491856, 0.12865962063273115, -0.290109000033615, -0.12794381450931447], [4.242424242424242, 0.07266201797352007, -0.2670065053281189, 0.12610353697572213, -0.30874211306197225, -0.13503984880196723], [4.343434343434343, 0.06901442354188567, -0.29021721494354774, 0.11070811519089516, -0.26032536826191427, -0.09424695209657388], [4.444444444444445, 0.06436390309720812, -0.2412040112556873, 0.14155798614013712, -0.30020105419465554, -0.13325521968592943], [4.545454545454545, 0.0769874908168521, -0.20817136400769543, 0.11347624433597994, -0.28671994790435174, -0.16270963314118853], [4.646464646464646, 0.03278735730204044, -0.16091948163129446, 0.0905723171934864, -0.31533693457766476, -0.12364463661552036], [4.747474747474747, 0.0444877728859006, -0.11544235072375078, 0.05280865885909375, -0.3094707598034151, -0.09453844998889094], [4.848484848484849, 0.017672317380623997, -0.12109908132539254, 0.09502774780309226, -0.29323367858908694, -0.07301929688367984], [4.94949494949495, -0.016415277190935544, -0.1658728958874847, 0.08474611744133873, -0.3095525147691089, -0.03906733223990159], [5.05050505050505, -0.04666580028857252, -0.13517439820015506, 0.04255611702867819, -0.28186181335750377, -0.07450723573491692], [5.151515151515151, -0.003935537615043352, -0.15087209698219303, 0.04449806667473447, -0.2509648626202112, -0.028947583431608706], [5.252525252525253, -0.028389221168473727, -0.17304281004682687, 0.0936534867385013, -0.2287020207504156, -0.007245865277220487], [5.353535353535354, -0.0407106833311685, -0.17421097944247202, 0.08630051450886549, -0.22674232625199156, 0.010140087637844786], [5.454545454545454, 0.0017440203509418786, -0.14520594483493418, 0.08087139462014056, -0.22522295085469432, 0.039155845639200756], [5.555555555555555, 0.02852644112034959, -0.1089149177779005, 0.09714686369281925, -0.18902636180551097, 0.0863180688061832], [5.656565656565657, 0.05097350288168366, -0.12893822875102148, 0.08208750235142574, -0.18997111954003296, 0.11853287911704424], [5.757575757575758, 0.021067501885617675, -0.1090228178579104, 0.06835291696764641, -0.18746270419305092, 0.10111729604077821], [5.858585858585858, -0.0013393449799598486, -0.10747528464275583, 0.04107350340317957, -0.16921402593031892, 0.10931615013888187], [5.959595959595959, -0.00946189978038165, -0.0753022447561143, 0.0476935973308841, -0.18361801396190455, 0.06566367128235472], [6.0606060606060606, -0.0017931197424129238, -0.029968966428255535, 0.05287635335855561, -0.20201113950929334, 0.029226861487080612], [6.161616161616162, -0.022900257698899078, 0.015779474355561013, 0.0844250681075579, -0.23140208113671643, 0.048251502441302815], [6.262626262626262, 0.01674777843506988, 0.03360143887747019, 0.09464971659933803, -0.18306377826803888, 0.053874342070306454], [6.363636363636363, 0.055934338437090024, -0.003895707415064363, 0.0984099046797347, -0.16616954672369832, 0.043722465646923496], [6.4646464646464645, 0.0898148470247052, -0.04584209746337732, 0.07113595117742758, -0.12690269560378328, 0.09285295416334531], [6.565656565656566, 0.09346919279667505, -0.06363840665726091, 0.07895180200756932, -0.14346218320974016, 0.05190024648633341], [6.666666666666667, 0.09237832109376351, -0.04936954527918082, 0.09629453794866577, -0.15537086509165066, 0.024458378565855605], [6.767676767676767, 0.06647387671349198, -0.021957389480929113, 0.1098722250682925, -0.14139355826941102, 0.045987795309294754], [6.8686868686868685, 0.09546113704965674, -0.07112787946418685, 0.1497428426240836, -0.188121908581815, 0.07413394892841604], [6.96969696969697, 0.1115760981728907, -0.06389319415210967, 0.1308985100136493, -0.2341399746266031, 0.05582507663675472], [7.070707070707071, 0.10479125434240265, -0.07099262677075889, 0.17328370709025298, -0.234059864263707, 0.03797003474382436], [7.171717171717171, 0.13232251739194772, -0.058498408769117737, 0.14463162818061243, -0.18817103686934447, 0.08706905241135049], [7.2727272727272725, 0.11547301515200643, -0.07489169098828122, 0.10269018368550431, -0.21104132014524163, 0.12820198485429607], [7.373737373737374, 0.14310350434025393, -0.025717407216927092, 0.11140164166411834, -0.19314757712674163, 0.16869068925327488], [7.474747474747475, 0.14414890505406702, 0.003951066334028343, 0.09858290034107764, -0.19442546722160467, 0.16048163969005078], [7.575757575757575, 0.14874983273279394, 0.04618066263373219, 0.14461543332168236, -0.22165637998368246, 0.14306348657133466], [7.6767676767676765, 0.19555292325066176, 0.004863784419171735, 0.10372468320778394, -0.2700678820543884, 0.12805540479066788], [7.777777777777778, 0.18368589692431972, -0.028751275076283722, 0.13091035054514422, -0.31780241524233244, 0.11484981440899783], [7.878787878787879, 0.1771880980798672, -0.009641625082180003, 0.09765515178755861, -0.34248972023659563, 0.15214464259341196], [7.979797979797979, 0.1873652469348349, -0.017525615539447856, 0.05897215771537501, -0.33108172741778286, 0.13071901814969164], [8.080808080808081, 0.22477296914921863, -0.017102352718936183, 0.09460156842887596, -0.28879998568633863, 0.10519191528660801], [8.181818181818182, 0.2738633512195425, -0.0017174003695022144, 0.11515523106981994, -0.28787761332120454, 0.0814920542405334], [8.282828282828282, 0.23368728366126587, 0.036720362680383666, 0.14379757525737963, -0.32453856342402926, 0.07435738911327806], [8.383838383838384, 0.27058163049858214, 0.00635624182072398, 0.10972930500613887, -0.2847561331095349, 0.10400330653226986], [8.484848484848484, 0.2565869271055691, 0.04806456153476761, 0.1531451019126603, -0.2522152352217555, 0.14374211559498512], [8.585858585858587, 0.25228851769076843, 0.006101819620032541, 0.168365939629834, -0.2349333212314259, 0.18911931635458915], [8.686868686868687, 0.26913571462637315, -0.011050398316563265, 0.14845654038657694, -0.2804098830419664, 0.20550970027142007], [8.787878787878787, 0.23157569567121947, -0.0004265554098648195, 0.10367373119926179, -0.28552089890673177, 0.22082836257190425], [8.88888888888889, 0.25386965043872683, 0.006645234092682047, 0.08068995147761558, -0.23897799348435161, 0.2539674755909058], [8.98989898989899, 0.2598821154362591, -0.03539159139760611, 0.05634463688776137, -0.2234049057541872, 0.2601597120997219], [9.09090909090909, 0.2625694921753903, -0.035837872773446834, 0.06650845999952401, -0.17513311737368592, 0.27310868840021874], [9.191919191919192, 0.28884823624584716, -0.039021578733584875, 0.017238727001464088, -0.17729911335170112, 0.2393602759593848], [9.292929292929292, 0.32128439103609513, -0.07388040150481341, -0.005340630860500913, -0.22135661834938805, 0.2449639511572952], [9.393939393939394, 0.28338272017298627, -0.11746953582116887, 0.04364362507368495, -0.17788602005000806, 0.20949543072409033], [9.494949494949495, 0.3302669629318954, -0.09457239524338934, 0.07263077221283612, -0.21200951061216686, 0.23312212899710255], [9.595959595959595, 0.3054449932012254, -0.10194952043588329, 0.09621121691267759, -0.2087852039252722, 0.22419621639801007], [9.696969696969697, 0.27320314731274414, -0.14721359008909235, 0.1270775779944514, -0.2371223198457389, 0.22163551825263458], [9.797979797979798, 0.29885520661421705, -0.18433715775756987, 0.1605408085236631, -0.21493553081986744, 0.2404701335232085], [9.8989898989899, 0.34125246806174536, -0.19718516739874217, 0.15638234106502386, -0.24734707836319134, 0.209808335283991], [10.0, 0.322509636449207, -0.24185140609223735, 0.11316676939611744, -0.2524067227864443, 0.1977981961999645]]}, \"id\": \"el100754535078480\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "                 \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "                 mpld3.draw_figure(\"fig_el1007545350784807465296436\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.40000000000000002, 0.40000000000000002], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 10, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535757904\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535758480\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535775504\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535775952\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754535776400\"}], \"markers\": [], \"id\": \"el100754535078544\", \"ydomain\": [-0.40000000000000002, 0.40000000000000002], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.54772727272727284, 0.77500000000000002, 0.35227272727272718]}, {\"xlim\": [-2.0, 12.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-2.0, 12.0], \"ylim\": [-0.40000000000000002, 0.40000000000000002], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 10, \"tickvalues\": null}], \"lines\": [], \"markers\": [], \"id\": \"el100754534880656\", \"ydomain\": [-0.40000000000000002, 0.40000000000000002], \"collections\": [{\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 1, \"id\": \"el100754535084624\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#0000FF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 2, \"id\": \"el100754535817488\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#007F00\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 3, \"id\": \"el100754535819408\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#FF0000\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 4, \"id\": \"el100754535821200\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#00BFBF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 5, \"id\": \"el100754535822800\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#BF00BF\"]}], \"xscale\": \"linear\", \"bbox\": [0.125, 0.12500000000000011, 0.77500000000000002, 0.35227272727272724]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754535757904\", \"el100754535757904pts\"], [\"el100754535758480\", \"el100754535758480pts\"], [\"el100754535775504\", \"el100754535775504pts\"], [\"el100754535775952\", \"el100754535775952pts\"], [\"el100754535776400\", \"el100754535776400pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": \"el100754535078544\", \"alpha_sel\": 1}, {\"element_ids\": [[\"el100754535084624\"], [\"el100754535817488\"], [\"el100754535819408\"], [\"el100754535821200\"], [\"el100754535822800\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": \"el100754534880656\", \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.04115664770414362, -0.048049157353564034, 0.03788510057419991, -0.045536568788255086, 0.04531887786735557], [0.10101010101010101, -0.08927699100122766, -0.05460463494448629, 0.01776348698207584, -0.08971278316961129, 0.07323942479393558], [0.20202020202020202, -0.04967921129298758, -0.0076984490292012, 0.010870272450665864, -0.08340578274392707, 0.08921842614934253], [0.30303030303030304, -0.05971690461547298, -0.017518131981640934, -0.004344706483998638, -0.047069336230050336, 0.07254560149663397], [0.40404040404040403, -0.10515036247494106, -0.031209345706198974, -0.006442225227171626, -0.09134302631466254, 0.03628997932691944], [0.5050505050505051, -0.062345644328017515, 0.01116532069884138, -0.037919948762198015, -0.14073868457819677, 0.07591532681220155], [0.6060606060606061, -0.08533223573732707, -0.028203720025242768, -0.008802224614687555, -0.1562257957062492, 0.11605519636214504], [0.7070707070707071, -0.11586004193599066, -0.070995677967056, -0.010086241970747574, -0.11937823501547536, 0.15537099747104507], [0.8080808080808081, -0.10430297372870087, -0.0901470012353897, -0.026418826616197592, -0.10030979373097956, 0.1909740864645194], [0.9090909090909091, -0.11563452171587255, -0.13969764703429205, 0.006757556260636094, -0.0902201722654079, 0.14881381980218983], [1.0101010101010102, -0.09711637434910542, -0.15526723897955794, 0.014681905664425616, -0.041880952019327684, 0.15075083857997695], [1.1111111111111112, -0.09266250639115454, -0.16647196608810558, -0.01188775374410997, -0.06705113439408865, 0.1696989935866236], [1.2121212121212122, -0.1212744067723128, -0.16932562345367194, 0.03389530250570889, -0.1168358816499669, 0.14473821482480703], [1.3131313131313131, -0.08207730311034678, -0.16689889591128737, 0.058831874923272826, -0.09552030053644277, 0.18346365902389236], [1.4141414141414141, -0.04023642558896386, -0.15579264975319868, 0.03209590241160251, -0.13554731226819958, 0.13969645224319], [1.5151515151515151, -0.0838965190150158, -0.11689057090398436, 0.03875290574828937, -0.16686640062035318, 0.09750031763871396], [1.6161616161616161, -0.06970079822576261, -0.07166452390780956, 0.04006006779450986, -0.12947009961729783, 0.060469993262570194], [1.7171717171717171, -0.0997770656953606, -0.07286977750473722, 0.05674081766789696, -0.10758573011062532, 0.036307897478279345], [1.8181818181818181, -0.06724943624969865, -0.06941219656851572, 0.04426637350123843, -0.1224418713792689, 0.02510996375790598], [1.9191919191919191, -0.09779823222555531, -0.10875059220936381, 0.035417775249112445, -0.17204604574060264, -0.019007166292564645], [2.0202020202020203, -0.04857455043350259, -0.07503609642580429, 0.055497096584885816, -0.17201696140550776, -0.02921473453893564], [2.121212121212121, -0.02471701492124017, -0.08095501882653716, 0.04607801569375233, -0.1955175291292604, -0.07149493712817062], [2.2222222222222223, -0.018713932845432518, -0.1288263740052685, 0.08733068763245039, -0.1773893759390561, -0.029015207578141744], [2.323232323232323, -0.04246078967409447, -0.17255757978220126, 0.11007374674915504, -0.17955008845651121, -0.04631699773199564], [2.4242424242424243, -0.08575199353340732, -0.1867872581615811, 0.11334442028975686, -0.1934860278064171, -0.05177563017841434], [2.525252525252525, -0.08550651494738654, -0.22023363736928175, 0.15034695867102346, -0.15018688649707682, -0.07217596669805475], [2.6262626262626263, -0.1322816753976196, -0.1829956174511691, 0.12443935397581267, -0.18041680564761559, -0.10517990841365402], [2.727272727272727, -0.11255366137331435, -0.19340505250548135, 0.1082392415595328, -0.1762463488139595, -0.12493383259469464], [2.8282828282828283, -0.12855344675886465, -0.2433300914296911, 0.10934061260186867, -0.1577418255817036, -0.0772412538135785], [2.929292929292929, -0.15816239605031673, -0.2221004340201769, 0.10597113084227949, -0.19584890771106545, -0.07904738769545379], [3.0303030303030303, -0.16407954588034607, -0.20622452852261977, 0.13717018459062133, -0.24069060199632886, -0.050768945398397325], [3.131313131313131, -0.1240376523522965, -0.20260458851067117, 0.15353639998906363, -0.21852038111420002, -0.0313420495981034], [3.2323232323232323, -0.17353709306990617, -0.20162376372716836, 0.10378280043467933, -0.20154128525676412, -0.07126814342161654], [3.3333333333333335, -0.15460242498840904, -0.19204308443854087, 0.08969687323547383, -0.22785991760987467, -0.10289189757447348], [3.4343434343434343, -0.12865068444478517, -0.1984256404595091, 0.05160487205293175, -0.2310280472684826, -0.10667599271082394], [3.5353535353535355, -0.08369811905601707, -0.15719504951205326, 0.021089358596747744, -0.25544314354835657, -0.07460176180781192], [3.6363636363636362, -0.06359995808651754, -0.14939650685527545, 0.04950373528410001, -0.282759903720899, -0.11482899633755039], [3.7373737373737375, -0.017234882553026035, -0.1956229398027834, 0.08659930988942666, -0.30979989593605867, -0.12988246164067946], [3.8383838383838382, 0.03070309278289831, -0.20159854959116505, 0.10214570684508253, -0.2682228089415979, -0.16348816836494934], [3.9393939393939394, 0.0499667116452898, -0.19644519398982477, 0.1354209867550918, -0.284517941436369, -0.13868094883019763], [4.040404040404041, 0.043763314274207044, -0.1992432087120353, 0.1595757055973647, -0.2616523609275467, -0.09596716706346856], [4.141414141414141, 0.08388593083792664, -0.2281616529491856, 0.12865962063273115, -0.290109000033615, -0.12794381450931447], [4.242424242424242, 0.07266201797352007, -0.2670065053281189, 0.12610353697572213, -0.30874211306197225, -0.13503984880196723], [4.343434343434343, 0.06901442354188567, -0.29021721494354774, 0.11070811519089516, -0.26032536826191427, -0.09424695209657388], [4.444444444444445, 0.06436390309720812, -0.2412040112556873, 0.14155798614013712, -0.30020105419465554, -0.13325521968592943], [4.545454545454545, 0.0769874908168521, -0.20817136400769543, 0.11347624433597994, -0.28671994790435174, -0.16270963314118853], [4.646464646464646, 0.03278735730204044, -0.16091948163129446, 0.0905723171934864, -0.31533693457766476, -0.12364463661552036], [4.747474747474747, 0.0444877728859006, -0.11544235072375078, 0.05280865885909375, -0.3094707598034151, -0.09453844998889094], [4.848484848484849, 0.017672317380623997, -0.12109908132539254, 0.09502774780309226, -0.29323367858908694, -0.07301929688367984], [4.94949494949495, -0.016415277190935544, -0.1658728958874847, 0.08474611744133873, -0.3095525147691089, -0.03906733223990159], [5.05050505050505, -0.04666580028857252, -0.13517439820015506, 0.04255611702867819, -0.28186181335750377, -0.07450723573491692], [5.151515151515151, -0.003935537615043352, -0.15087209698219303, 0.04449806667473447, -0.2509648626202112, -0.028947583431608706], [5.252525252525253, -0.028389221168473727, -0.17304281004682687, 0.0936534867385013, -0.2287020207504156, -0.007245865277220487], [5.353535353535354, -0.0407106833311685, -0.17421097944247202, 0.08630051450886549, -0.22674232625199156, 0.010140087637844786], [5.454545454545454, 0.0017440203509418786, -0.14520594483493418, 0.08087139462014056, -0.22522295085469432, 0.039155845639200756], [5.555555555555555, 0.02852644112034959, -0.1089149177779005, 0.09714686369281925, -0.18902636180551097, 0.0863180688061832], [5.656565656565657, 0.05097350288168366, -0.12893822875102148, 0.08208750235142574, -0.18997111954003296, 0.11853287911704424], [5.757575757575758, 0.021067501885617675, -0.1090228178579104, 0.06835291696764641, -0.18746270419305092, 0.10111729604077821], [5.858585858585858, -0.0013393449799598486, -0.10747528464275583, 0.04107350340317957, -0.16921402593031892, 0.10931615013888187], [5.959595959595959, -0.00946189978038165, -0.0753022447561143, 0.0476935973308841, -0.18361801396190455, 0.06566367128235472], [6.0606060606060606, -0.0017931197424129238, -0.029968966428255535, 0.05287635335855561, -0.20201113950929334, 0.029226861487080612], [6.161616161616162, -0.022900257698899078, 0.015779474355561013, 0.0844250681075579, -0.23140208113671643, 0.048251502441302815], [6.262626262626262, 0.01674777843506988, 0.03360143887747019, 0.09464971659933803, -0.18306377826803888, 0.053874342070306454], [6.363636363636363, 0.055934338437090024, -0.003895707415064363, 0.0984099046797347, -0.16616954672369832, 0.043722465646923496], [6.4646464646464645, 0.0898148470247052, -0.04584209746337732, 0.07113595117742758, -0.12690269560378328, 0.09285295416334531], [6.565656565656566, 0.09346919279667505, -0.06363840665726091, 0.07895180200756932, -0.14346218320974016, 0.05190024648633341], [6.666666666666667, 0.09237832109376351, -0.04936954527918082, 0.09629453794866577, -0.15537086509165066, 0.024458378565855605], [6.767676767676767, 0.06647387671349198, -0.021957389480929113, 0.1098722250682925, -0.14139355826941102, 0.045987795309294754], [6.8686868686868685, 0.09546113704965674, -0.07112787946418685, 0.1497428426240836, -0.188121908581815, 0.07413394892841604], [6.96969696969697, 0.1115760981728907, -0.06389319415210967, 0.1308985100136493, -0.2341399746266031, 0.05582507663675472], [7.070707070707071, 0.10479125434240265, -0.07099262677075889, 0.17328370709025298, -0.234059864263707, 0.03797003474382436], [7.171717171717171, 0.13232251739194772, -0.058498408769117737, 0.14463162818061243, -0.18817103686934447, 0.08706905241135049], [7.2727272727272725, 0.11547301515200643, -0.07489169098828122, 0.10269018368550431, -0.21104132014524163, 0.12820198485429607], [7.373737373737374, 0.14310350434025393, -0.025717407216927092, 0.11140164166411834, -0.19314757712674163, 0.16869068925327488], [7.474747474747475, 0.14414890505406702, 0.003951066334028343, 0.09858290034107764, -0.19442546722160467, 0.16048163969005078], [7.575757575757575, 0.14874983273279394, 0.04618066263373219, 0.14461543332168236, -0.22165637998368246, 0.14306348657133466], [7.6767676767676765, 0.19555292325066176, 0.004863784419171735, 0.10372468320778394, -0.2700678820543884, 0.12805540479066788], [7.777777777777778, 0.18368589692431972, -0.028751275076283722, 0.13091035054514422, -0.31780241524233244, 0.11484981440899783], [7.878787878787879, 0.1771880980798672, -0.009641625082180003, 0.09765515178755861, -0.34248972023659563, 0.15214464259341196], [7.979797979797979, 0.1873652469348349, -0.017525615539447856, 0.05897215771537501, -0.33108172741778286, 0.13071901814969164], [8.080808080808081, 0.22477296914921863, -0.017102352718936183, 0.09460156842887596, -0.28879998568633863, 0.10519191528660801], [8.181818181818182, 0.2738633512195425, -0.0017174003695022144, 0.11515523106981994, -0.28787761332120454, 0.0814920542405334], [8.282828282828282, 0.23368728366126587, 0.036720362680383666, 0.14379757525737963, -0.32453856342402926, 0.07435738911327806], [8.383838383838384, 0.27058163049858214, 0.00635624182072398, 0.10972930500613887, -0.2847561331095349, 0.10400330653226986], [8.484848484848484, 0.2565869271055691, 0.04806456153476761, 0.1531451019126603, -0.2522152352217555, 0.14374211559498512], [8.585858585858587, 0.25228851769076843, 0.006101819620032541, 0.168365939629834, -0.2349333212314259, 0.18911931635458915], [8.686868686868687, 0.26913571462637315, -0.011050398316563265, 0.14845654038657694, -0.2804098830419664, 0.20550970027142007], [8.787878787878787, 0.23157569567121947, -0.0004265554098648195, 0.10367373119926179, -0.28552089890673177, 0.22082836257190425], [8.88888888888889, 0.25386965043872683, 0.006645234092682047, 0.08068995147761558, -0.23897799348435161, 0.2539674755909058], [8.98989898989899, 0.2598821154362591, -0.03539159139760611, 0.05634463688776137, -0.2234049057541872, 0.2601597120997219], [9.09090909090909, 0.2625694921753903, -0.035837872773446834, 0.06650845999952401, -0.17513311737368592, 0.27310868840021874], [9.191919191919192, 0.28884823624584716, -0.039021578733584875, 0.017238727001464088, -0.17729911335170112, 0.2393602759593848], [9.292929292929292, 0.32128439103609513, -0.07388040150481341, -0.005340630860500913, -0.22135661834938805, 0.2449639511572952], [9.393939393939394, 0.28338272017298627, -0.11746953582116887, 0.04364362507368495, -0.17788602005000806, 0.20949543072409033], [9.494949494949495, 0.3302669629318954, -0.09457239524338934, 0.07263077221283612, -0.21200951061216686, 0.23312212899710255], [9.595959595959595, 0.3054449932012254, -0.10194952043588329, 0.09621121691267759, -0.2087852039252722, 0.22419621639801007], [9.696969696969697, 0.27320314731274414, -0.14721359008909235, 0.1270775779944514, -0.2371223198457389, 0.22163551825263458], [9.797979797979798, 0.29885520661421705, -0.18433715775756987, 0.1605408085236631, -0.21493553081986744, 0.2404701335232085], [9.8989898989899, 0.34125246806174536, -0.19718516739874217, 0.15638234106502386, -0.24734707836319134, 0.209808335283991], [10.0, 0.322509636449207, -0.24185140609223735, 0.11316676939611744, -0.2524067227864443, 0.1977981961999645]]}, \"id\": \"el100754535078480\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 3,
       "text": [
        "<IPython.core.display.HTML at 0x10e5a9b90>"
       ]
      }
     ],
     "prompt_number": 3
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## single legend for different axes\n",
      "\n",
      "We can link multiple matplotlib elements to a single item in the legend. This functionality works even when the elements belong to different axes as shown below. "
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "N_paths = 5\n",
      "N_steps = 100\n",
      "\n",
      "x = np.linspace(0, 10, 100)\n",
      "y = 0.1 * (np.random.random((N_paths, N_steps)) - 0.5)\n",
      "y = y.cumsum(1)\n",
      "\n",
      "\n",
      "fig = plt.figure()\n",
      "ax1 = fig.add_subplot(2,1,1)\n",
      "ax2 = fig.add_subplot(2,1,2)\n",
      "\n",
      "labels = [\"a\", \"b\", \"c\", \"d\", \"e\"]\n",
      "l1 = ax1.plot(x, y.T, lw=4, alpha=0.1)\n",
      "s1 = []\n",
      "for i in range(N_paths):\n",
      "    s = ax2.scatter(x,y[i, :], c=next(ax2._get_lines.color_cycle), alpha=0.1)\n",
      "    s1.append(s)\n",
      "    \n",
      "plugins.connect(fig, plugins.InteractiveLegendPlugin(zip(l1, s1), labels))\n",
      "mpld3.display()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "    .legend-box {\n",
        "      cursor: pointer;\n",
        "    }\n",
        "    \n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el1007545358547363404455654\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "       mpld3.draw_figure(\"fig_el1007545358547363404455654\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.40000000000000002, 0.59999999999999998], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565200400\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565213328\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565213904\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565214352\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565214800\"}], \"markers\": [], \"id\": \"el100754535855056\", \"ydomain\": [-0.40000000000000002, 0.59999999999999998], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.54772727272727284, 0.77500000000000002, 0.35227272727272718]}, {\"xlim\": [-2.0, 12.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-2.0, 12.0], \"ylim\": [-0.40000000000000002, 0.80000000000000016], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [], \"markers\": [], \"id\": \"el100754534911504\", \"ydomain\": [-0.40000000000000002, 0.80000000000000016], \"collections\": [{\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 1, \"id\": \"el100754565229072\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#0000FF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 2, \"id\": \"el100754565235408\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#007F00\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 3, \"id\": \"el100754565237328\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#FF0000\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 4, \"id\": \"el100754565259600\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#00BFBF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 5, \"id\": \"el100754565261200\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#BF00BF\"]}], \"xscale\": \"linear\", \"bbox\": [0.125, 0.12500000000000011, 0.77500000000000002, 0.35227272727272724]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754565200400\", \"el100754565200400pts\", \"el100754565229072\"], [\"el100754565213328\", \"el100754565213328pts\", \"el100754565235408\"], [\"el100754565213904\", \"el100754565213904pts\", \"el100754565237328\"], [\"el100754565214352\", \"el100754565214352pts\", \"el100754565259600\"], [\"el100754565214800\", \"el100754565214800pts\", \"el100754565261200\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.04682349741236419, -0.013648319947685228, -0.009111796055009813, -0.012432154082771409, 0.038404796628871946], [0.10101010101010101, -0.035082859955212764, -0.01861253559179088, -0.030351053535012794, -0.031073446790194872, 0.08679771512071827], [0.20202020202020202, 0.009269319300054119, -0.05956943835974249, -0.046410564055285944, -0.06586811607703637, 0.05454069254658622], [0.30303030303030304, 0.02616286079125561, -0.023445653257425265, -0.04634607233405772, -0.046577463014944476, 0.010818145554599035], [0.40404040404040403, 0.07513569979976929, -0.06206160157884639, -0.03442769897196642, -0.04268632889757558, 0.023825083225767752], [0.5050505050505051, 0.11715624554034733, -0.10932232299837302, -0.04971472423914813, -0.031029972267832606, 0.04031549438309366], [0.6060606060606061, 0.11562052024113516, -0.06051841410632564, -0.06725737084681853, 0.0024660764658923084, 0.013850616063366857], [0.7070707070707071, 0.13061293645278357, -0.1092091503383849, -0.06826277878530157, 0.008271336690019749, 0.05435593997798847], [0.8080808080808081, 0.11952092452754162, -0.06034627140629968, -0.11464988708023266, -0.0011560245227872686, 0.09269189147501412], [0.9090909090909091, 0.12067923466315338, -0.01752707125615651, -0.07190547885632154, -0.014939898504951933, 0.10693806205484774], [1.0101010101010102, 0.14311846546271056, 0.019732871099909816, -0.11140379847260945, 0.01485038035744114, 0.10135831764195155], [1.1111111111111112, 0.18930673762069283, 0.0437570867062287, -0.09048917390405718, 0.05894049960568208, 0.05351403769005591], [1.2121212121212122, 0.18584996732081224, -0.0025611472951542896, -0.11421034534435215, 0.0490954614016233, 0.06227725032967055], [1.3131313131313131, 0.20971169077569562, 0.04574900440604064, -0.06544810023991712, 0.0766592408411291, 0.06345743406794674], [1.4141414141414141, 0.25849348253971166, 0.07270869880584292, -0.10885701298834022, 0.08889448046337056, 0.07450817569602813], [1.5151515151515151, 0.2903260138319344, 0.06735549948814532, -0.13966882280865922, 0.06648762965100403, 0.05333985010551892], [1.6161616161616161, 0.28734487750870225, 0.02719921761418264, -0.14512701698051172, 0.027863959485002088, 0.09035330712590049], [1.7171717171717171, 0.2816785770054433, -0.0008435493410645159, -0.12497598719789364, 0.05319119363972101, 0.1026727800259388], [1.8181818181818181, 0.32948843762853713, 0.033010493077924405, -0.07910811941071806, 0.007307013955768764, 0.12359229404583316], [1.9191919191919191, 0.29178748071581395, 0.002532902595106308, -0.06288408102449285, -0.030922778561825168, 0.11468087479043153], [2.0202020202020203, 0.3079705366706352, 0.031978407088723224, -0.07974447362507375, -0.004885844235159781, 0.138036895652906], [2.121212121212121, 0.31835741594959444, -0.007123144461199729, -0.12663077008767476, -0.030606015178025487, 0.14429851540564498], [2.2222222222222223, 0.3485692814553967, -0.039583588117656415, -0.09973481491894225, -0.07562010150093641, 0.13188110078175816], [2.323232323232323, 0.3169749042549661, -0.04574886693928564, -0.14452168915570013, -0.061564501774898674, 0.08224490260739684], [2.4242424242424243, 0.3659763979124687, -0.019062158557270628, -0.17396087933873292, -0.022361841879977147, 0.09190072127924441], [2.525252525252525, 0.3308965451079469, 0.024945347717924858, -0.15386159425144516, 0.009960708587446347, 0.06842961005863625], [2.6262626262626263, 0.3486015362440379, 0.036182074701124466, -0.1260313235838808, -0.03674150462851857, 0.08352292007482554], [2.727272727272727, 0.3367204018377496, 0.06713620701977693, -0.16846661945170993, -0.04201309371967075, 0.1201931142079934], [2.8282828282828283, 0.34940583268406994, 0.08372971019050979, -0.15379734945186438, -0.044546732397818256, 0.08335569169886484], [2.929292929292929, 0.30285070217942395, 0.05845187651001806, -0.15009725720347697, -0.07258765164178768, 0.05352274112149309], [3.0303030303030303, 0.35202105301595066, 0.09860530818519439, -0.12077042054952482, -0.025823345588232342, 0.03620543288488263], [3.131313131313131, 0.33030163058175, 0.10854364526677718, -0.09893598973122568, -0.06525214763344275, 0.022954802311706227], [3.2323232323232323, 0.35800148807368226, 0.11134082056799226, -0.07333394847144954, -0.03431444176081221, 0.06354968074763712], [3.3333333333333335, 0.39859888759322426, 0.14861209844119194, -0.09493694795252461, -0.04223821483699351, 0.019011813160513355], [3.4343434343434343, 0.42363467530564014, 0.17126058450642717, -0.05700309373208566, -0.06216882593442343, -0.007215297467010988], [3.5353535353535355, 0.46035507379675916, 0.19831249481510738, -0.0433088627870681, -0.09239461322840084, -0.00017482990610750287], [3.6363636363636362, 0.43991508104207183, 0.16065037649826283, -0.027174034202902507, -0.05998924518920399, 0.014243847926813089], [3.7373737373737375, 0.4887286915101016, 0.19759315006140402, 0.008273911699286408, -0.05634631568617817, 0.024804351396738887], [3.8383838383838382, 0.47757415865536323, 0.20822842461311067, 0.01827153773464868, -0.06487211730570247, 0.04908866764742063], [3.9393939393939394, 0.5189833604756706, 0.1937591926624336, -0.009560413937553736, -0.04398188081068477, 0.08831213550775915], [4.040404040404041, 0.5405497436910492, 0.1668669274759624, 0.0318475465040154, -0.01266247691838416, 0.04465634772508177], [4.141414141414141, 0.5477382187004063, 0.14521986268397824, 0.0393950910010957, -0.040944239746208304, 0.05861823249839082], [4.242424242424242, 0.5751847727199091, 0.16844353553806254, 0.08440676326220944, -0.04884505644893229, 0.0686399972124962], [4.343434343434343, 0.5773787593784668, 0.12227932724863705, 0.12402837358985846, -0.08701661901042788, 0.07204999920103809], [4.444444444444445, 0.5915184244203381, 0.14494567847661416, 0.0885916088494058, -0.09777305884802935, 0.025437346206567575], [4.545454545454545, 0.5642422851771557, 0.1627800845434609, 0.0956189017419178, -0.1005525720297449, 0.023501537058531682], [4.646464646464646, 0.5475723651316369, 0.17222770395901957, 0.13726417922765394, -0.15053758831336778, -0.0068998847280476935], [4.747474747474747, 0.5651269632306808, 0.14737099315332158, 0.1377508455880344, -0.1737015374979684, -0.04348485306937543], [4.848484848484849, 0.5159079287291976, 0.14255507532029071, 0.15903382878096972, -0.18160503114896756, -0.03668970661799023], [4.94949494949495, 0.5422080663294958, 0.1522548117514979, 0.168846266610721, -0.1989349555016197, -0.004541442668828402], [5.05050505050505, 0.503654520917276, 0.14758090639175744, 0.15456026475602214, -0.19574146700453132, -0.04390813437274498], [5.151515151515151, 0.47588133906480856, 0.1295793089588697, 0.1693247943445647, -0.20456466849439628, -0.03729074595506146], [5.252525252525253, 0.5191965641060848, 0.15314659416736068, 0.1536739478826702, -0.20577735535726238, -0.03282435353681944], [5.353535353535354, 0.5414888667802574, 0.1054095955387563, 0.18951904229359973, -0.21274985248051786, -0.06021229264378321], [5.454545454545454, 0.4971348457696604, 0.0656473906169678, 0.21292906002442102, -0.1887628053978249, -0.06997200682441745], [5.555555555555555, 0.48170556461779274, 0.09468006182893034, 0.22275181945166955, -0.18457544942557794, -0.0278224125985731], [5.656565656565657, 0.4978380060146903, 0.10859935113145974, 0.20813246170803432, -0.22575043496445182, -0.009746764600145317], [5.757575757575758, 0.5008399066832776, 0.09004434531552435, 0.21910890288084317, -0.2508074825399359, 0.004167791591253503], [5.858585858585858, 0.46855795429629654, 0.044334696615372725, 0.2090732996999164, -0.2710016588587811, 0.017404251619236893], [5.959595959595959, 0.4443285464418522, 0.0051504746430802925, 0.23622534159674188, -0.22409802242839133, 0.009445825544043879], [6.0606060606060606, 0.44178719171212927, -0.042642355369066014, 0.19661086690680368, -0.22905352914724517, -0.03284953040072378], [6.161616161616162, 0.4306825756084015, -0.05445612481696048, 0.17751067622718497, -0.25710855047429293, -0.04894025367815946], [6.262626262626262, 0.4116385175754177, -0.08654919852747872, 0.18294861418300384, -0.24564281268890287, -0.002683216087295423], [6.363636363636363, 0.45809521417860694, -0.11210689178338247, 0.2222641878682573, -0.27647235212157933, -0.04122997599878665], [6.4646464646464645, 0.4610252294162816, -0.12431900567416052, 0.23548348382552264, -0.301804896199263, -0.0665100088857409], [6.565656565656566, 0.49729128672439893, -0.11725491539284805, 0.25815275703067914, -0.3165342717961402, -0.045792561166282914], [6.666666666666667, 0.5427476175654682, -0.16325561161227084, 0.23024699093248258, -0.29694840150801377, -0.011853315131261179], [6.767676767676767, 0.5868027597988089, -0.17322142518048025, 0.20799832652347347, -0.2525706809021729, -0.030524466434968412], [6.8686868686868685, 0.5404868091810621, -0.20271225900639056, 0.21297355950155614, -0.280626767452479, -0.048435828930627076], [6.96969696969697, 0.5213871513255444, -0.21039684938443542, 0.1679716814469657, -0.23932596000995707, -0.08533343918724795], [7.070707070707071, 0.5367246616088052, -0.1821563791811626, 0.21388987011964164, -0.2554783584070568, -0.05133351084706784], [7.171717171717171, 0.5445786699884535, -0.13284462656115598, 0.26142468825355625, -0.2674738760930971, -0.07896157335252255], [7.2727272727272725, 0.5142129434205066, -0.11958901717089837, 0.2381722988134773, -0.23527465565782088, -0.029868835332089297], [7.373737373737374, 0.4742256811075144, -0.08843097363729616, 0.24154895189639908, -0.23381078528206525, -0.025962967956932995], [7.474747474747475, 0.4361937167442265, -0.09960077155365095, 0.19759976786428718, -0.22712935998977588, -0.05014557219908407], [7.575757575757575, 0.45349383397425946, -0.13629446619462188, 0.15289355042512967, -0.26904137388982813, -0.09542846064381542], [7.6767676767676765, 0.47390559112202163, -0.14739233261600634, 0.1217426297312151, -0.301942115574887, -0.07568406157768093], [7.777777777777778, 0.42729503613198155, -0.10336742029473997, 0.15227713831027842, -0.2660959658948718, -0.06828611202658831], [7.878787878787879, 0.4662421757166044, -0.08483078713656585, 0.10618816383320337, -0.2312249211768413, -0.10784626193176872], [7.979797979797979, 0.4243090549267513, -0.1333363049128179, 0.09012104401079071, -0.1856031189617674, -0.12287325862015269], [8.080808080808081, 0.460505133494046, -0.1255047488752789, 0.10718039804987427, -0.1588260862513721, -0.08480485053206031], [8.181818181818182, 0.4109373280131075, -0.12385894284551875, 0.12522357432948053, -0.1565470144559798, -0.05914722791622335], [8.282828282828282, 0.4425980586858498, -0.0950407732582133, 0.07525514266394015, -0.14819474548593844, -0.023334935206522918], [8.383838383838384, 0.4615381302517908, -0.08410222135818171, 0.07067684483421695, -0.18943519481677365, 0.026603655531691778], [8.484848484848484, 0.4257874230824016, -0.08666181290299649, 0.07910875581491056, -0.1594943003387243, -0.013363825420908665], [8.585858585858587, 0.4604353866536528, -0.1311149114259973, 0.09334893136355182, -0.15900504059822138, -0.0038250623152681074], [8.686868686868687, 0.4296971578183278, -0.09800857205248292, 0.05000617011873182, -0.17161719284876573, -0.01268880763383678], [8.787878787878787, 0.41995734681202473, -0.12796212703570048, 0.08506185731141566, -0.1272402419713442, 0.03403564181788338], [8.88888888888889, 0.3840957930297466, -0.16843493763440165, 0.07518280005995784, -0.11050592238079845, 0.07138527532673468], [8.98989898989899, 0.40611498805224255, -0.19594485992497593, 0.02746103306603323, -0.1023659052700816, 0.03643051524466689], [9.09090909090909, 0.37383531615735827, -0.1844631341249371, 0.030506641886360524, -0.0902894736679314, 0.030228575687567132], [9.191919191919192, 0.34808552474313326, -0.1423230767896836, 0.013772579842887614, -0.1238026695721734, 0.0013978894608367466], [9.292929292929292, 0.3772940936266633, -0.11373458674790302, -0.029048246558213663, -0.13761113742455264, 0.013430059992370418], [9.393939393939394, 0.42380653082493774, -0.06808249944381436, -0.07016091851533365, -0.13537318504122628, -0.016170399487365712], [9.494949494949495, 0.3756919510446044, -0.08640442549943436, -0.0665619387626718, -0.13366264031157782, -0.01980023156344169], [9.595959595959595, 0.34746928098619034, -0.06702969790722439, -0.11378107655706007, -0.13359889952717735, 0.020751346347465803], [9.696969696969697, 0.3538724644476281, -0.08824108537816731, -0.0846676057569874, -0.12232772115898184, 0.06923517152473271], [9.797979797979798, 0.3178623250002622, -0.1115667942556787, -0.1159832086874811, -0.09597204729652259, 0.03333846300667704], [9.8989898989899, 0.3395133301313769, -0.06934494765648239, -0.0807047140130952, -0.06608721928418128, 0.05280879318650675], [10.0, 0.34597351083838424, -0.044466159790058815, -0.10673776575353804, -0.06018612868542979, 0.007206385264265952]]}, \"id\": \"el100754535854736\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "         \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "         mpld3.draw_figure(\"fig_el1007545358547363404455654\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.40000000000000002, 0.59999999999999998], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565200400\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565213328\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565213904\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565214352\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565214800\"}], \"markers\": [], \"id\": \"el100754535855056\", \"ydomain\": [-0.40000000000000002, 0.59999999999999998], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.54772727272727284, 0.77500000000000002, 0.35227272727272718]}, {\"xlim\": [-2.0, 12.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-2.0, 12.0], \"ylim\": [-0.40000000000000002, 0.80000000000000016], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [], \"markers\": [], \"id\": \"el100754534911504\", \"ydomain\": [-0.40000000000000002, 0.80000000000000016], \"collections\": [{\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 1, \"id\": \"el100754565229072\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#0000FF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 2, \"id\": \"el100754565235408\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#007F00\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 3, \"id\": \"el100754565237328\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#FF0000\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 4, \"id\": \"el100754565259600\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#00BFBF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 5, \"id\": \"el100754565261200\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#BF00BF\"]}], \"xscale\": \"linear\", \"bbox\": [0.125, 0.12500000000000011, 0.77500000000000002, 0.35227272727272724]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754565200400\", \"el100754565200400pts\", \"el100754565229072\"], [\"el100754565213328\", \"el100754565213328pts\", \"el100754565235408\"], [\"el100754565213904\", \"el100754565213904pts\", \"el100754565237328\"], [\"el100754565214352\", \"el100754565214352pts\", \"el100754565259600\"], [\"el100754565214800\", \"el100754565214800pts\", \"el100754565261200\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.04682349741236419, -0.013648319947685228, -0.009111796055009813, -0.012432154082771409, 0.038404796628871946], [0.10101010101010101, -0.035082859955212764, -0.01861253559179088, -0.030351053535012794, -0.031073446790194872, 0.08679771512071827], [0.20202020202020202, 0.009269319300054119, -0.05956943835974249, -0.046410564055285944, -0.06586811607703637, 0.05454069254658622], [0.30303030303030304, 0.02616286079125561, -0.023445653257425265, -0.04634607233405772, -0.046577463014944476, 0.010818145554599035], [0.40404040404040403, 0.07513569979976929, -0.06206160157884639, -0.03442769897196642, -0.04268632889757558, 0.023825083225767752], [0.5050505050505051, 0.11715624554034733, -0.10932232299837302, -0.04971472423914813, -0.031029972267832606, 0.04031549438309366], [0.6060606060606061, 0.11562052024113516, -0.06051841410632564, -0.06725737084681853, 0.0024660764658923084, 0.013850616063366857], [0.7070707070707071, 0.13061293645278357, -0.1092091503383849, -0.06826277878530157, 0.008271336690019749, 0.05435593997798847], [0.8080808080808081, 0.11952092452754162, -0.06034627140629968, -0.11464988708023266, -0.0011560245227872686, 0.09269189147501412], [0.9090909090909091, 0.12067923466315338, -0.01752707125615651, -0.07190547885632154, -0.014939898504951933, 0.10693806205484774], [1.0101010101010102, 0.14311846546271056, 0.019732871099909816, -0.11140379847260945, 0.01485038035744114, 0.10135831764195155], [1.1111111111111112, 0.18930673762069283, 0.0437570867062287, -0.09048917390405718, 0.05894049960568208, 0.05351403769005591], [1.2121212121212122, 0.18584996732081224, -0.0025611472951542896, -0.11421034534435215, 0.0490954614016233, 0.06227725032967055], [1.3131313131313131, 0.20971169077569562, 0.04574900440604064, -0.06544810023991712, 0.0766592408411291, 0.06345743406794674], [1.4141414141414141, 0.25849348253971166, 0.07270869880584292, -0.10885701298834022, 0.08889448046337056, 0.07450817569602813], [1.5151515151515151, 0.2903260138319344, 0.06735549948814532, -0.13966882280865922, 0.06648762965100403, 0.05333985010551892], [1.6161616161616161, 0.28734487750870225, 0.02719921761418264, -0.14512701698051172, 0.027863959485002088, 0.09035330712590049], [1.7171717171717171, 0.2816785770054433, -0.0008435493410645159, -0.12497598719789364, 0.05319119363972101, 0.1026727800259388], [1.8181818181818181, 0.32948843762853713, 0.033010493077924405, -0.07910811941071806, 0.007307013955768764, 0.12359229404583316], [1.9191919191919191, 0.29178748071581395, 0.002532902595106308, -0.06288408102449285, -0.030922778561825168, 0.11468087479043153], [2.0202020202020203, 0.3079705366706352, 0.031978407088723224, -0.07974447362507375, -0.004885844235159781, 0.138036895652906], [2.121212121212121, 0.31835741594959444, -0.007123144461199729, -0.12663077008767476, -0.030606015178025487, 0.14429851540564498], [2.2222222222222223, 0.3485692814553967, -0.039583588117656415, -0.09973481491894225, -0.07562010150093641, 0.13188110078175816], [2.323232323232323, 0.3169749042549661, -0.04574886693928564, -0.14452168915570013, -0.061564501774898674, 0.08224490260739684], [2.4242424242424243, 0.3659763979124687, -0.019062158557270628, -0.17396087933873292, -0.022361841879977147, 0.09190072127924441], [2.525252525252525, 0.3308965451079469, 0.024945347717924858, -0.15386159425144516, 0.009960708587446347, 0.06842961005863625], [2.6262626262626263, 0.3486015362440379, 0.036182074701124466, -0.1260313235838808, -0.03674150462851857, 0.08352292007482554], [2.727272727272727, 0.3367204018377496, 0.06713620701977693, -0.16846661945170993, -0.04201309371967075, 0.1201931142079934], [2.8282828282828283, 0.34940583268406994, 0.08372971019050979, -0.15379734945186438, -0.044546732397818256, 0.08335569169886484], [2.929292929292929, 0.30285070217942395, 0.05845187651001806, -0.15009725720347697, -0.07258765164178768, 0.05352274112149309], [3.0303030303030303, 0.35202105301595066, 0.09860530818519439, -0.12077042054952482, -0.025823345588232342, 0.03620543288488263], [3.131313131313131, 0.33030163058175, 0.10854364526677718, -0.09893598973122568, -0.06525214763344275, 0.022954802311706227], [3.2323232323232323, 0.35800148807368226, 0.11134082056799226, -0.07333394847144954, -0.03431444176081221, 0.06354968074763712], [3.3333333333333335, 0.39859888759322426, 0.14861209844119194, -0.09493694795252461, -0.04223821483699351, 0.019011813160513355], [3.4343434343434343, 0.42363467530564014, 0.17126058450642717, -0.05700309373208566, -0.06216882593442343, -0.007215297467010988], [3.5353535353535355, 0.46035507379675916, 0.19831249481510738, -0.0433088627870681, -0.09239461322840084, -0.00017482990610750287], [3.6363636363636362, 0.43991508104207183, 0.16065037649826283, -0.027174034202902507, -0.05998924518920399, 0.014243847926813089], [3.7373737373737375, 0.4887286915101016, 0.19759315006140402, 0.008273911699286408, -0.05634631568617817, 0.024804351396738887], [3.8383838383838382, 0.47757415865536323, 0.20822842461311067, 0.01827153773464868, -0.06487211730570247, 0.04908866764742063], [3.9393939393939394, 0.5189833604756706, 0.1937591926624336, -0.009560413937553736, -0.04398188081068477, 0.08831213550775915], [4.040404040404041, 0.5405497436910492, 0.1668669274759624, 0.0318475465040154, -0.01266247691838416, 0.04465634772508177], [4.141414141414141, 0.5477382187004063, 0.14521986268397824, 0.0393950910010957, -0.040944239746208304, 0.05861823249839082], [4.242424242424242, 0.5751847727199091, 0.16844353553806254, 0.08440676326220944, -0.04884505644893229, 0.0686399972124962], [4.343434343434343, 0.5773787593784668, 0.12227932724863705, 0.12402837358985846, -0.08701661901042788, 0.07204999920103809], [4.444444444444445, 0.5915184244203381, 0.14494567847661416, 0.0885916088494058, -0.09777305884802935, 0.025437346206567575], [4.545454545454545, 0.5642422851771557, 0.1627800845434609, 0.0956189017419178, -0.1005525720297449, 0.023501537058531682], [4.646464646464646, 0.5475723651316369, 0.17222770395901957, 0.13726417922765394, -0.15053758831336778, -0.0068998847280476935], [4.747474747474747, 0.5651269632306808, 0.14737099315332158, 0.1377508455880344, -0.1737015374979684, -0.04348485306937543], [4.848484848484849, 0.5159079287291976, 0.14255507532029071, 0.15903382878096972, -0.18160503114896756, -0.03668970661799023], [4.94949494949495, 0.5422080663294958, 0.1522548117514979, 0.168846266610721, -0.1989349555016197, -0.004541442668828402], [5.05050505050505, 0.503654520917276, 0.14758090639175744, 0.15456026475602214, -0.19574146700453132, -0.04390813437274498], [5.151515151515151, 0.47588133906480856, 0.1295793089588697, 0.1693247943445647, -0.20456466849439628, -0.03729074595506146], [5.252525252525253, 0.5191965641060848, 0.15314659416736068, 0.1536739478826702, -0.20577735535726238, -0.03282435353681944], [5.353535353535354, 0.5414888667802574, 0.1054095955387563, 0.18951904229359973, -0.21274985248051786, -0.06021229264378321], [5.454545454545454, 0.4971348457696604, 0.0656473906169678, 0.21292906002442102, -0.1887628053978249, -0.06997200682441745], [5.555555555555555, 0.48170556461779274, 0.09468006182893034, 0.22275181945166955, -0.18457544942557794, -0.0278224125985731], [5.656565656565657, 0.4978380060146903, 0.10859935113145974, 0.20813246170803432, -0.22575043496445182, -0.009746764600145317], [5.757575757575758, 0.5008399066832776, 0.09004434531552435, 0.21910890288084317, -0.2508074825399359, 0.004167791591253503], [5.858585858585858, 0.46855795429629654, 0.044334696615372725, 0.2090732996999164, -0.2710016588587811, 0.017404251619236893], [5.959595959595959, 0.4443285464418522, 0.0051504746430802925, 0.23622534159674188, -0.22409802242839133, 0.009445825544043879], [6.0606060606060606, 0.44178719171212927, -0.042642355369066014, 0.19661086690680368, -0.22905352914724517, -0.03284953040072378], [6.161616161616162, 0.4306825756084015, -0.05445612481696048, 0.17751067622718497, -0.25710855047429293, -0.04894025367815946], [6.262626262626262, 0.4116385175754177, -0.08654919852747872, 0.18294861418300384, -0.24564281268890287, -0.002683216087295423], [6.363636363636363, 0.45809521417860694, -0.11210689178338247, 0.2222641878682573, -0.27647235212157933, -0.04122997599878665], [6.4646464646464645, 0.4610252294162816, -0.12431900567416052, 0.23548348382552264, -0.301804896199263, -0.0665100088857409], [6.565656565656566, 0.49729128672439893, -0.11725491539284805, 0.25815275703067914, -0.3165342717961402, -0.045792561166282914], [6.666666666666667, 0.5427476175654682, -0.16325561161227084, 0.23024699093248258, -0.29694840150801377, -0.011853315131261179], [6.767676767676767, 0.5868027597988089, -0.17322142518048025, 0.20799832652347347, -0.2525706809021729, -0.030524466434968412], [6.8686868686868685, 0.5404868091810621, -0.20271225900639056, 0.21297355950155614, -0.280626767452479, -0.048435828930627076], [6.96969696969697, 0.5213871513255444, -0.21039684938443542, 0.1679716814469657, -0.23932596000995707, -0.08533343918724795], [7.070707070707071, 0.5367246616088052, -0.1821563791811626, 0.21388987011964164, -0.2554783584070568, -0.05133351084706784], [7.171717171717171, 0.5445786699884535, -0.13284462656115598, 0.26142468825355625, -0.2674738760930971, -0.07896157335252255], [7.2727272727272725, 0.5142129434205066, -0.11958901717089837, 0.2381722988134773, -0.23527465565782088, -0.029868835332089297], [7.373737373737374, 0.4742256811075144, -0.08843097363729616, 0.24154895189639908, -0.23381078528206525, -0.025962967956932995], [7.474747474747475, 0.4361937167442265, -0.09960077155365095, 0.19759976786428718, -0.22712935998977588, -0.05014557219908407], [7.575757575757575, 0.45349383397425946, -0.13629446619462188, 0.15289355042512967, -0.26904137388982813, -0.09542846064381542], [7.6767676767676765, 0.47390559112202163, -0.14739233261600634, 0.1217426297312151, -0.301942115574887, -0.07568406157768093], [7.777777777777778, 0.42729503613198155, -0.10336742029473997, 0.15227713831027842, -0.2660959658948718, -0.06828611202658831], [7.878787878787879, 0.4662421757166044, -0.08483078713656585, 0.10618816383320337, -0.2312249211768413, -0.10784626193176872], [7.979797979797979, 0.4243090549267513, -0.1333363049128179, 0.09012104401079071, -0.1856031189617674, -0.12287325862015269], [8.080808080808081, 0.460505133494046, -0.1255047488752789, 0.10718039804987427, -0.1588260862513721, -0.08480485053206031], [8.181818181818182, 0.4109373280131075, -0.12385894284551875, 0.12522357432948053, -0.1565470144559798, -0.05914722791622335], [8.282828282828282, 0.4425980586858498, -0.0950407732582133, 0.07525514266394015, -0.14819474548593844, -0.023334935206522918], [8.383838383838384, 0.4615381302517908, -0.08410222135818171, 0.07067684483421695, -0.18943519481677365, 0.026603655531691778], [8.484848484848484, 0.4257874230824016, -0.08666181290299649, 0.07910875581491056, -0.1594943003387243, -0.013363825420908665], [8.585858585858587, 0.4604353866536528, -0.1311149114259973, 0.09334893136355182, -0.15900504059822138, -0.0038250623152681074], [8.686868686868687, 0.4296971578183278, -0.09800857205248292, 0.05000617011873182, -0.17161719284876573, -0.01268880763383678], [8.787878787878787, 0.41995734681202473, -0.12796212703570048, 0.08506185731141566, -0.1272402419713442, 0.03403564181788338], [8.88888888888889, 0.3840957930297466, -0.16843493763440165, 0.07518280005995784, -0.11050592238079845, 0.07138527532673468], [8.98989898989899, 0.40611498805224255, -0.19594485992497593, 0.02746103306603323, -0.1023659052700816, 0.03643051524466689], [9.09090909090909, 0.37383531615735827, -0.1844631341249371, 0.030506641886360524, -0.0902894736679314, 0.030228575687567132], [9.191919191919192, 0.34808552474313326, -0.1423230767896836, 0.013772579842887614, -0.1238026695721734, 0.0013978894608367466], [9.292929292929292, 0.3772940936266633, -0.11373458674790302, -0.029048246558213663, -0.13761113742455264, 0.013430059992370418], [9.393939393939394, 0.42380653082493774, -0.06808249944381436, -0.07016091851533365, -0.13537318504122628, -0.016170399487365712], [9.494949494949495, 0.3756919510446044, -0.08640442549943436, -0.0665619387626718, -0.13366264031157782, -0.01980023156344169], [9.595959595959595, 0.34746928098619034, -0.06702969790722439, -0.11378107655706007, -0.13359889952717735, 0.020751346347465803], [9.696969696969697, 0.3538724644476281, -0.08824108537816731, -0.0846676057569874, -0.12232772115898184, 0.06923517152473271], [9.797979797979798, 0.3178623250002622, -0.1115667942556787, -0.1159832086874811, -0.09597204729652259, 0.03333846300667704], [9.8989898989899, 0.3395133301313769, -0.06934494765648239, -0.0807047140130952, -0.06608721928418128, 0.05280879318650675], [10.0, 0.34597351083838424, -0.044466159790058815, -0.10673776575353804, -0.06018612868542979, 0.007206385264265952]]}, \"id\": \"el100754535854736\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "                 \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "                 mpld3.draw_figure(\"fig_el1007545358547363404455654\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.40000000000000002, 0.59999999999999998], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565200400\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565213328\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565213904\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565214352\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 4, \"data\": \"data01\", \"id\": \"el100754565214800\"}], \"markers\": [], \"id\": \"el100754535855056\", \"ydomain\": [-0.40000000000000002, 0.59999999999999998], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.54772727272727284, 0.77500000000000002, 0.35227272727272718]}, {\"xlim\": [-2.0, 12.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-2.0, 12.0], \"ylim\": [-0.40000000000000002, 0.80000000000000016], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [], \"markers\": [], \"id\": \"el100754534911504\", \"ydomain\": [-0.40000000000000002, 0.80000000000000016], \"collections\": [{\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 1, \"id\": \"el100754565229072\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#0000FF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 2, \"id\": \"el100754565235408\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#007F00\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 3, \"id\": \"el100754565237328\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#FF0000\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 4, \"id\": \"el100754565259600\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#00BFBF\"]}, {\"paths\": [[[[0.0, -0.5], [0.13260155, -0.5], [0.25978993539242673, -0.44731684579412084], [0.3535533905932738, -0.3535533905932738], [0.44731684579412084, -0.25978993539242673], [0.5, -0.13260155], [0.5, 0.0], [0.5, 0.13260155], [0.44731684579412084, 0.25978993539242673], [0.3535533905932738, 0.3535533905932738], [0.25978993539242673, 0.44731684579412084], [0.13260155, 0.5], [0.0, 0.5], [-0.13260155, 0.5], [-0.25978993539242673, 0.44731684579412084], [-0.3535533905932738, 0.3535533905932738], [-0.44731684579412084, 0.25978993539242673], [-0.5, 0.13260155], [-0.5, 0.0], [-0.5, -0.13260155], [-0.44731684579412084, -0.25978993539242673], [-0.3535533905932738, -0.3535533905932738], [-0.25978993539242673, -0.44731684579412084], [-0.13260155, -0.5], [0.0, -0.5]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 5, \"id\": \"el100754565261200\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.1], \"facecolors\": [\"#BF00BF\"]}], \"xscale\": \"linear\", \"bbox\": [0.125, 0.12500000000000011, 0.77500000000000002, 0.35227272727272724]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754565200400\", \"el100754565200400pts\", \"el100754565229072\"], [\"el100754565213328\", \"el100754565213328pts\", \"el100754565235408\"], [\"el100754565213904\", \"el100754565213904pts\", \"el100754565237328\"], [\"el100754565214352\", \"el100754565214352pts\", \"el100754565259600\"], [\"el100754565214800\", \"el100754565214800pts\", \"el100754565261200\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, -0.04682349741236419, -0.013648319947685228, -0.009111796055009813, -0.012432154082771409, 0.038404796628871946], [0.10101010101010101, -0.035082859955212764, -0.01861253559179088, -0.030351053535012794, -0.031073446790194872, 0.08679771512071827], [0.20202020202020202, 0.009269319300054119, -0.05956943835974249, -0.046410564055285944, -0.06586811607703637, 0.05454069254658622], [0.30303030303030304, 0.02616286079125561, -0.023445653257425265, -0.04634607233405772, -0.046577463014944476, 0.010818145554599035], [0.40404040404040403, 0.07513569979976929, -0.06206160157884639, -0.03442769897196642, -0.04268632889757558, 0.023825083225767752], [0.5050505050505051, 0.11715624554034733, -0.10932232299837302, -0.04971472423914813, -0.031029972267832606, 0.04031549438309366], [0.6060606060606061, 0.11562052024113516, -0.06051841410632564, -0.06725737084681853, 0.0024660764658923084, 0.013850616063366857], [0.7070707070707071, 0.13061293645278357, -0.1092091503383849, -0.06826277878530157, 0.008271336690019749, 0.05435593997798847], [0.8080808080808081, 0.11952092452754162, -0.06034627140629968, -0.11464988708023266, -0.0011560245227872686, 0.09269189147501412], [0.9090909090909091, 0.12067923466315338, -0.01752707125615651, -0.07190547885632154, -0.014939898504951933, 0.10693806205484774], [1.0101010101010102, 0.14311846546271056, 0.019732871099909816, -0.11140379847260945, 0.01485038035744114, 0.10135831764195155], [1.1111111111111112, 0.18930673762069283, 0.0437570867062287, -0.09048917390405718, 0.05894049960568208, 0.05351403769005591], [1.2121212121212122, 0.18584996732081224, -0.0025611472951542896, -0.11421034534435215, 0.0490954614016233, 0.06227725032967055], [1.3131313131313131, 0.20971169077569562, 0.04574900440604064, -0.06544810023991712, 0.0766592408411291, 0.06345743406794674], [1.4141414141414141, 0.25849348253971166, 0.07270869880584292, -0.10885701298834022, 0.08889448046337056, 0.07450817569602813], [1.5151515151515151, 0.2903260138319344, 0.06735549948814532, -0.13966882280865922, 0.06648762965100403, 0.05333985010551892], [1.6161616161616161, 0.28734487750870225, 0.02719921761418264, -0.14512701698051172, 0.027863959485002088, 0.09035330712590049], [1.7171717171717171, 0.2816785770054433, -0.0008435493410645159, -0.12497598719789364, 0.05319119363972101, 0.1026727800259388], [1.8181818181818181, 0.32948843762853713, 0.033010493077924405, -0.07910811941071806, 0.007307013955768764, 0.12359229404583316], [1.9191919191919191, 0.29178748071581395, 0.002532902595106308, -0.06288408102449285, -0.030922778561825168, 0.11468087479043153], [2.0202020202020203, 0.3079705366706352, 0.031978407088723224, -0.07974447362507375, -0.004885844235159781, 0.138036895652906], [2.121212121212121, 0.31835741594959444, -0.007123144461199729, -0.12663077008767476, -0.030606015178025487, 0.14429851540564498], [2.2222222222222223, 0.3485692814553967, -0.039583588117656415, -0.09973481491894225, -0.07562010150093641, 0.13188110078175816], [2.323232323232323, 0.3169749042549661, -0.04574886693928564, -0.14452168915570013, -0.061564501774898674, 0.08224490260739684], [2.4242424242424243, 0.3659763979124687, -0.019062158557270628, -0.17396087933873292, -0.022361841879977147, 0.09190072127924441], [2.525252525252525, 0.3308965451079469, 0.024945347717924858, -0.15386159425144516, 0.009960708587446347, 0.06842961005863625], [2.6262626262626263, 0.3486015362440379, 0.036182074701124466, -0.1260313235838808, -0.03674150462851857, 0.08352292007482554], [2.727272727272727, 0.3367204018377496, 0.06713620701977693, -0.16846661945170993, -0.04201309371967075, 0.1201931142079934], [2.8282828282828283, 0.34940583268406994, 0.08372971019050979, -0.15379734945186438, -0.044546732397818256, 0.08335569169886484], [2.929292929292929, 0.30285070217942395, 0.05845187651001806, -0.15009725720347697, -0.07258765164178768, 0.05352274112149309], [3.0303030303030303, 0.35202105301595066, 0.09860530818519439, -0.12077042054952482, -0.025823345588232342, 0.03620543288488263], [3.131313131313131, 0.33030163058175, 0.10854364526677718, -0.09893598973122568, -0.06525214763344275, 0.022954802311706227], [3.2323232323232323, 0.35800148807368226, 0.11134082056799226, -0.07333394847144954, -0.03431444176081221, 0.06354968074763712], [3.3333333333333335, 0.39859888759322426, 0.14861209844119194, -0.09493694795252461, -0.04223821483699351, 0.019011813160513355], [3.4343434343434343, 0.42363467530564014, 0.17126058450642717, -0.05700309373208566, -0.06216882593442343, -0.007215297467010988], [3.5353535353535355, 0.46035507379675916, 0.19831249481510738, -0.0433088627870681, -0.09239461322840084, -0.00017482990610750287], [3.6363636363636362, 0.43991508104207183, 0.16065037649826283, -0.027174034202902507, -0.05998924518920399, 0.014243847926813089], [3.7373737373737375, 0.4887286915101016, 0.19759315006140402, 0.008273911699286408, -0.05634631568617817, 0.024804351396738887], [3.8383838383838382, 0.47757415865536323, 0.20822842461311067, 0.01827153773464868, -0.06487211730570247, 0.04908866764742063], [3.9393939393939394, 0.5189833604756706, 0.1937591926624336, -0.009560413937553736, -0.04398188081068477, 0.08831213550775915], [4.040404040404041, 0.5405497436910492, 0.1668669274759624, 0.0318475465040154, -0.01266247691838416, 0.04465634772508177], [4.141414141414141, 0.5477382187004063, 0.14521986268397824, 0.0393950910010957, -0.040944239746208304, 0.05861823249839082], [4.242424242424242, 0.5751847727199091, 0.16844353553806254, 0.08440676326220944, -0.04884505644893229, 0.0686399972124962], [4.343434343434343, 0.5773787593784668, 0.12227932724863705, 0.12402837358985846, -0.08701661901042788, 0.07204999920103809], [4.444444444444445, 0.5915184244203381, 0.14494567847661416, 0.0885916088494058, -0.09777305884802935, 0.025437346206567575], [4.545454545454545, 0.5642422851771557, 0.1627800845434609, 0.0956189017419178, -0.1005525720297449, 0.023501537058531682], [4.646464646464646, 0.5475723651316369, 0.17222770395901957, 0.13726417922765394, -0.15053758831336778, -0.0068998847280476935], [4.747474747474747, 0.5651269632306808, 0.14737099315332158, 0.1377508455880344, -0.1737015374979684, -0.04348485306937543], [4.848484848484849, 0.5159079287291976, 0.14255507532029071, 0.15903382878096972, -0.18160503114896756, -0.03668970661799023], [4.94949494949495, 0.5422080663294958, 0.1522548117514979, 0.168846266610721, -0.1989349555016197, -0.004541442668828402], [5.05050505050505, 0.503654520917276, 0.14758090639175744, 0.15456026475602214, -0.19574146700453132, -0.04390813437274498], [5.151515151515151, 0.47588133906480856, 0.1295793089588697, 0.1693247943445647, -0.20456466849439628, -0.03729074595506146], [5.252525252525253, 0.5191965641060848, 0.15314659416736068, 0.1536739478826702, -0.20577735535726238, -0.03282435353681944], [5.353535353535354, 0.5414888667802574, 0.1054095955387563, 0.18951904229359973, -0.21274985248051786, -0.06021229264378321], [5.454545454545454, 0.4971348457696604, 0.0656473906169678, 0.21292906002442102, -0.1887628053978249, -0.06997200682441745], [5.555555555555555, 0.48170556461779274, 0.09468006182893034, 0.22275181945166955, -0.18457544942557794, -0.0278224125985731], [5.656565656565657, 0.4978380060146903, 0.10859935113145974, 0.20813246170803432, -0.22575043496445182, -0.009746764600145317], [5.757575757575758, 0.5008399066832776, 0.09004434531552435, 0.21910890288084317, -0.2508074825399359, 0.004167791591253503], [5.858585858585858, 0.46855795429629654, 0.044334696615372725, 0.2090732996999164, -0.2710016588587811, 0.017404251619236893], [5.959595959595959, 0.4443285464418522, 0.0051504746430802925, 0.23622534159674188, -0.22409802242839133, 0.009445825544043879], [6.0606060606060606, 0.44178719171212927, -0.042642355369066014, 0.19661086690680368, -0.22905352914724517, -0.03284953040072378], [6.161616161616162, 0.4306825756084015, -0.05445612481696048, 0.17751067622718497, -0.25710855047429293, -0.04894025367815946], [6.262626262626262, 0.4116385175754177, -0.08654919852747872, 0.18294861418300384, -0.24564281268890287, -0.002683216087295423], [6.363636363636363, 0.45809521417860694, -0.11210689178338247, 0.2222641878682573, -0.27647235212157933, -0.04122997599878665], [6.4646464646464645, 0.4610252294162816, -0.12431900567416052, 0.23548348382552264, -0.301804896199263, -0.0665100088857409], [6.565656565656566, 0.49729128672439893, -0.11725491539284805, 0.25815275703067914, -0.3165342717961402, -0.045792561166282914], [6.666666666666667, 0.5427476175654682, -0.16325561161227084, 0.23024699093248258, -0.29694840150801377, -0.011853315131261179], [6.767676767676767, 0.5868027597988089, -0.17322142518048025, 0.20799832652347347, -0.2525706809021729, -0.030524466434968412], [6.8686868686868685, 0.5404868091810621, -0.20271225900639056, 0.21297355950155614, -0.280626767452479, -0.048435828930627076], [6.96969696969697, 0.5213871513255444, -0.21039684938443542, 0.1679716814469657, -0.23932596000995707, -0.08533343918724795], [7.070707070707071, 0.5367246616088052, -0.1821563791811626, 0.21388987011964164, -0.2554783584070568, -0.05133351084706784], [7.171717171717171, 0.5445786699884535, -0.13284462656115598, 0.26142468825355625, -0.2674738760930971, -0.07896157335252255], [7.2727272727272725, 0.5142129434205066, -0.11958901717089837, 0.2381722988134773, -0.23527465565782088, -0.029868835332089297], [7.373737373737374, 0.4742256811075144, -0.08843097363729616, 0.24154895189639908, -0.23381078528206525, -0.025962967956932995], [7.474747474747475, 0.4361937167442265, -0.09960077155365095, 0.19759976786428718, -0.22712935998977588, -0.05014557219908407], [7.575757575757575, 0.45349383397425946, -0.13629446619462188, 0.15289355042512967, -0.26904137388982813, -0.09542846064381542], [7.6767676767676765, 0.47390559112202163, -0.14739233261600634, 0.1217426297312151, -0.301942115574887, -0.07568406157768093], [7.777777777777778, 0.42729503613198155, -0.10336742029473997, 0.15227713831027842, -0.2660959658948718, -0.06828611202658831], [7.878787878787879, 0.4662421757166044, -0.08483078713656585, 0.10618816383320337, -0.2312249211768413, -0.10784626193176872], [7.979797979797979, 0.4243090549267513, -0.1333363049128179, 0.09012104401079071, -0.1856031189617674, -0.12287325862015269], [8.080808080808081, 0.460505133494046, -0.1255047488752789, 0.10718039804987427, -0.1588260862513721, -0.08480485053206031], [8.181818181818182, 0.4109373280131075, -0.12385894284551875, 0.12522357432948053, -0.1565470144559798, -0.05914722791622335], [8.282828282828282, 0.4425980586858498, -0.0950407732582133, 0.07525514266394015, -0.14819474548593844, -0.023334935206522918], [8.383838383838384, 0.4615381302517908, -0.08410222135818171, 0.07067684483421695, -0.18943519481677365, 0.026603655531691778], [8.484848484848484, 0.4257874230824016, -0.08666181290299649, 0.07910875581491056, -0.1594943003387243, -0.013363825420908665], [8.585858585858587, 0.4604353866536528, -0.1311149114259973, 0.09334893136355182, -0.15900504059822138, -0.0038250623152681074], [8.686868686868687, 0.4296971578183278, -0.09800857205248292, 0.05000617011873182, -0.17161719284876573, -0.01268880763383678], [8.787878787878787, 0.41995734681202473, -0.12796212703570048, 0.08506185731141566, -0.1272402419713442, 0.03403564181788338], [8.88888888888889, 0.3840957930297466, -0.16843493763440165, 0.07518280005995784, -0.11050592238079845, 0.07138527532673468], [8.98989898989899, 0.40611498805224255, -0.19594485992497593, 0.02746103306603323, -0.1023659052700816, 0.03643051524466689], [9.09090909090909, 0.37383531615735827, -0.1844631341249371, 0.030506641886360524, -0.0902894736679314, 0.030228575687567132], [9.191919191919192, 0.34808552474313326, -0.1423230767896836, 0.013772579842887614, -0.1238026695721734, 0.0013978894608367466], [9.292929292929292, 0.3772940936266633, -0.11373458674790302, -0.029048246558213663, -0.13761113742455264, 0.013430059992370418], [9.393939393939394, 0.42380653082493774, -0.06808249944381436, -0.07016091851533365, -0.13537318504122628, -0.016170399487365712], [9.494949494949495, 0.3756919510446044, -0.08640442549943436, -0.0665619387626718, -0.13366264031157782, -0.01980023156344169], [9.595959595959595, 0.34746928098619034, -0.06702969790722439, -0.11378107655706007, -0.13359889952717735, 0.020751346347465803], [9.696969696969697, 0.3538724644476281, -0.08824108537816731, -0.0846676057569874, -0.12232772115898184, 0.06923517152473271], [9.797979797979798, 0.3178623250002622, -0.1115667942556787, -0.1159832086874811, -0.09597204729652259, 0.03333846300667704], [9.8989898989899, 0.3395133301313769, -0.06934494765648239, -0.0807047140130952, -0.06608721928418128, 0.05280879318650675], [10.0, 0.34597351083838424, -0.044466159790058815, -0.10673776575353804, -0.06018612868542979, 0.007206385264265952]]}, \"id\": \"el100754535854736\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 4,
       "text": [
        "<IPython.core.display.HTML at 0x1101bdd50>"
       ]
      }
     ],
     "prompt_number": 4
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## scatterplot demo"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "nr_elements = 5\n",
      "\n",
      "fig, ax = plt.subplots()\n",
      "elements = []\n",
      "for i in range(nr_elements):\n",
      "    x = np.random.rand(100)\n",
      "    y = np.random.rand(100)\n",
      "    \n",
      "    element = ax.scatter(x,y, color=next(ax2._get_lines.color_cycle), alpha=0.2, marker='+')\n",
      "    elements.append([element])\n",
      "\n",
      "labels = [\"{}\".format(i) for i in range(nr_elements)]\n",
      "plugins.connect(fig, plugins.InteractiveLegendPlugin(elements, labels))\n",
      "mpld3.display()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "    .legend-box {\n",
        "      cursor: pointer;\n",
        "    }\n",
        "    \n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el1007545358883369021618064\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "       mpld3.draw_figure(\"fig_el1007545358883369021618064\", {\"axes\": [{\"xlim\": [-0.20000000000000001, 1.2000000000000002], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-0.20000000000000001, 1.2000000000000002], \"ylim\": [-0.20000000000000001, 1.2000000000000002], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 9, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 9, \"tickvalues\": null}], \"lines\": [], \"markers\": [], \"id\": \"el100754564825296\", \"ydomain\": [-0.20000000000000001, 1.2000000000000002], \"collections\": [{\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#BFBF00\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 1, \"id\": \"el100754534924624\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#BFBF00\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data02\", \"yindex\": 1, \"id\": \"el100754535115472\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#000000\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#0000FF\"], \"edgewidths\": [1.0], \"offsets\": \"data03\", \"yindex\": 1, \"id\": \"el100754535112592\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#0000FF\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#007F00\"], \"edgewidths\": [1.0], \"offsets\": \"data04\", \"yindex\": 1, \"id\": \"el100754535845584\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#007F00\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#FF0000\"], \"edgewidths\": [1.0], \"offsets\": \"data05\", \"yindex\": 1, \"id\": \"el100754535847440\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#FF0000\"]}], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754534924624\"], [\"el100754535115472\"], [\"el100754535112592\"], [\"el100754535845584\"], [\"el100754535847440\"]], \"type\": \"interactive_legend\", \"labels\": [\"0\", \"1\", \"2\", \"3\", \"4\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data04\": [[0.9242519631087408, 0.39804086882196144], [0.9126097026627603, 0.9966812574636679], [0.16177892393363236, 0.9835478103937141], [0.7290207152190079, 0.30424873457519186], [0.22633003479410652, 0.1377797931238578], [0.7813052928901829, 0.9932452835915527], [0.511627211343237, 0.4561403153339668], [0.4331427984353847, 0.7472121091145788], [0.045386339333301384, 0.9733452237855091], [0.034598644287704206, 0.5466502285541966], [0.3612719946534252, 0.049663979477878706], [0.8543283471717548, 0.43236762953935415], [0.5647181799398293, 0.43851443078500296], [0.36167288584686363, 0.16229725352040503], [0.20304599789853517, 0.11038895897136092], [0.1515811733422764, 0.6094603522429083], [0.9087683303320383, 0.897613621940072], [0.901990648341611, 0.13254951313402696], [0.49456954491121574, 0.4422539373577671], [0.9241419221303792, 0.7725212485471615], [0.5934836870312762, 0.03506928483863481], [0.6205901296332685, 0.12232967326915056], [0.6475995188546149, 0.5863539955652299], [0.7578402507602906, 0.7239187419244221], [0.6341796250185249, 0.7093967781484286], [0.2852367881531317, 0.7874310283493733], [0.10378708251127533, 0.6728180752692836], [0.3748324712118384, 0.06758030806883275], [0.050921133450575584, 0.8253252989186546], [0.17337201194929286, 0.6887068053214239], [0.9349263028690167, 0.1461095475487837], [0.8978238994288542, 0.07955578785605977], [0.26722036674939276, 0.6309769909437343], [0.57387788373186, 0.6074204836513427], [0.21743854878208568, 0.41552395751324844], [0.7223835447005645, 0.2032068360596292], [0.3250653630626674, 0.66652248928253], [0.9797703787368516, 0.2319682036102848], [0.8001390060599199, 0.0945216013025898], [0.7492067125159604, 0.6149921849680753], [0.8020181902969954, 0.32131298721588275], [0.893733162911723, 0.08788242205955898], [0.8984066385728788, 0.8588957589407241], [0.5028592927379153, 0.810806577474733], [0.5879458605906736, 0.4142613690167992], [0.7988738670904313, 0.6629090860045823], [0.02543952472313904, 0.0011155447114389316], [0.6871121698402548, 0.8456218148794823], [0.0672718812024854, 0.2873353143050722], [0.7707035199501348, 0.13295966586873553], [0.9710420374930185, 0.18925168540274884], [0.9916389907887001, 0.07399906530135014], [0.24800614902198614, 0.8911066506717814], [0.13481783369188294, 0.8359012936320355], [0.7330238100877549, 0.5404546941997577], [0.6954896263303783, 0.6775779258477295], [0.8515601986012354, 0.04086213505331526], [0.695171596079609, 0.9114608544079199], [0.6033154073049452, 0.8770692870017625], [0.2145720323728718, 0.4112232353838494], [0.4427821886142954, 0.2826779825618091], [0.49890428160591327, 0.35992384107960285], [0.14416615428021906, 0.9511338695055563], [0.6751892035893142, 0.9065148942702237], [0.708541804826553, 0.40561686400140395], [0.5655725800793501, 0.5538489382195868], [0.2406609243946839, 0.1016675702287424], [0.8202332469394755, 0.6384139346887739], [0.8077922399555246, 0.3876071857071599], [0.40867045124791923, 0.9360801817211917], [0.7059342627237338, 0.27185090462073747], [0.519516694501997, 0.654718629604253], [0.8803934218803643, 0.3884939028466704], [0.09996565553723069, 0.7773404292816348], [0.6051028948373115, 0.307760208805379], [0.28630619692527337, 0.18235826122852605], [0.9254138247359804, 0.26848283235908077], [0.9871064431890462, 0.41626625151721763], [0.9055967613457812, 0.9522308434012204], [0.6518028959044958, 0.2922721713061237], [0.6932474425153093, 0.08801877979970107], [0.09731227699861356, 0.7906676529641823], [0.30894286807657156, 0.41399595645933684], [0.24610318780631524, 0.010548610304123685], [0.24514338877403274, 0.5279518129180067], [0.5570720342088052, 0.4366548014590623], [0.1388290857367228, 0.7532826547555839], [0.10673304004977613, 0.3096766502129693], [0.8082537335284038, 0.027747965349013803], [0.7544617775486192, 0.4703538962398426], [0.16797282173884742, 0.41604764069800027], [0.48082193732237843, 0.13259259308368754], [0.3284447161159144, 0.14731349797730886], [0.45780364015692154, 0.6095560252502288], [0.01820095657060905, 0.22415568146209897], [0.2349767799500877, 0.4325929577188884], [0.13278557186010875, 0.5037764884870928], [0.809697530772305, 0.6874428289257826], [0.42552618327856084, 0.3426171743185057], [0.3533085364318135, 0.3370968695051333]], \"data05\": [[0.5303590898478936, 0.13711428791109015], [0.12322490675551157, 0.886024852886269], [0.4089742660225866, 0.14071766847012235], [0.10941879286651779, 0.48282919093264076], [0.4728634153181045, 0.6361502366562537], [0.5680544970375454, 0.7085927608942354], [0.3234811723712886, 0.5978004054235319], [0.8913191773960594, 0.3336796792771711], [0.9536357985956547, 0.8908541623760522], [0.6302083823778912, 0.027048470946945846], [0.9982804845300204, 0.29941219899049554], [0.5948381724999198, 0.9612900038908112], [0.6989246952080482, 0.9811527676394494], [0.6549832929112029, 0.2839319657142868], [0.4866567528959358, 0.31319113187712166], [0.15620745746164766, 0.3530183658096693], [0.37369581146924347, 0.09427174906507774], [0.9746086918203388, 0.578470459470677], [0.8483243540818455, 0.28093001298546916], [0.37367302574151706, 0.6818242397190019], [0.2417931607898266, 0.4811527526511765], [0.49639137156393554, 0.2398641429788264], [0.14855806964180618, 0.8842859574274882], [0.5739347296103652, 0.172383578884151], [0.24223663887225344, 0.30814403349988095], [0.1220331440628114, 0.0768468480492891], [0.1030759019040417, 0.9928066438130376], [0.7548677954026867, 0.23581987298236284], [0.4664349774431229, 0.40971764048768944], [0.34750245248971656, 0.8597533597932135], [0.42372735483316515, 0.9481066021739991], [0.9151906877964716, 0.3276895157638441], [0.6142963919322558, 0.23371003537579949], [0.9936625068211631, 0.6110979935200785], [0.3254980679138474, 0.5833857888763009], [0.011304132829930147, 0.8790562911692762], [0.5653196518565355, 0.25358472800004395], [0.12194468991797869, 0.7123622705987561], [0.25728868880589917, 0.04359895035949535], [0.018691228834961326, 0.6423881938845716], [0.36321326425982914, 0.4009723390247496], [0.7052534909756388, 0.6011404087366192], [0.3510187095415981, 0.03388316114365986], [0.039039234827561886, 0.5006514843196327], [0.7484974994028434, 0.43626987170746534], [0.04701967105980742, 0.45287367270615386], [0.8977531073544337, 0.5409783137361621], [0.9428065486556295, 0.6568964066620901], [0.7655752246435434, 0.17919050668518388], [0.4637109182220772, 0.7097420304062763], [0.7961060269507684, 0.07049913908366179], [0.5669562681346024, 0.027410649888650718], [0.9406654157439517, 0.9161997528149837], [0.11632731874264224, 0.6875493862435358], [0.48464171270817125, 0.9887455834156222], [0.8854345413427909, 0.49530775678797445], [0.008197359860088071, 0.7597498106862539], [0.3586531582538418, 0.9628339543557296], [0.22764721330724302, 0.1405341173516369], [0.7282174787391045, 0.5266952761039118], [0.7762217629823028, 0.9682518311055232], [0.7260866242517884, 0.28203938167045295], [0.929153272673218, 0.5400713424363478], [0.8337855778393145, 0.6795875111461626], [0.8811577685468234, 0.9676050547116376], [0.16686808006119924, 0.02425116871348032], [0.9537611574141022, 0.46499078093429846], [0.3557643599271686, 0.18176818250012716], [0.5539694427896724, 0.9702486452125939], [0.8046574117521608, 0.1033350953965424], [0.8545637343389454, 0.28552444817017697], [0.6649160184185691, 0.5807541580054544], [0.8656474156668079, 0.010757553818076637], [0.7449843057340946, 0.11467989496079967], [0.022313719511357855, 0.4631106389943791], [0.6846131837001713, 0.5974023844003244], [0.08713516099208285, 0.03160862084948668], [0.07726363230708022, 0.43777601426565294], [0.6038222456380775, 0.7950979710584937], [0.5162786005582756, 0.5909702087113057], [0.6073608646745878, 0.6152722269956976], [0.7520048711147257, 0.18293980280385702], [0.8407469579182841, 0.3107740017846162], [0.7314393477783951, 0.0033205006476206833], [0.35927909474977293, 0.14011525238291211], [0.7660767539642495, 0.6850158748918177], [0.43992881261355854, 0.5276038891658873], [0.8106500220239526, 0.23103846501309344], [0.5851638380608137, 0.7897930722253051], [0.6311152524965394, 0.036093413779834216], [0.10508669958387984, 0.7511807817455597], [0.055370524456371806, 0.3943681075719089], [0.4096713516358751, 0.7868392811097878], [0.674225751740304, 0.2992275731499737], [0.9328139326950637, 0.3584841104098604], [0.32067802910475596, 0.04962728120086746], [0.39925061680451845, 0.5432935549737629], [0.9602342510141207, 0.0603765122472435], [0.5868120557355941, 0.4106064978457815], [0.29643089285171664, 0.37789664517154564]], \"data02\": [[0.5757281402347376, 0.12476822907952634], [0.8843691160959513, 0.5871710607925391], [0.6073338063051109, 0.18808934201908567], [0.10872697639641205, 0.9181416618801573], [0.43324928639328397, 0.3241244143937009], [0.9817042936056718, 0.5299763370829639], [0.38930607099283787, 0.6767587233228362], [0.8936662582765941, 0.03160166842793044], [0.46701333481729934, 0.3468895684080464], [0.5527106830801924, 0.12559908590827484], [0.2527553536672792, 0.7782016784466976], [0.5438063282122486, 0.33583124597023173], [0.7657595580414235, 0.8892752434091579], [0.48043927289390154, 0.6012612039899949], [0.5699371291323116, 0.6264430866819386], [0.6848164641409118, 0.3206319237601867], [0.2461711098756535, 0.4582381862704157], [0.36784406388138524, 0.6925870953637762], [0.15579851407905432, 0.03150131689977309], [0.8083211690028597, 0.29458313536486125], [0.23183111835471448, 0.6195056379907635], [0.303655801185987, 0.4933598706350324], [0.9910972375282245, 0.9987048732731857], [0.14915029471809094, 0.0530079750044139], [0.4843605314487036, 0.4152171128240163], [0.4215310154895132, 0.5724189902269761], [0.15969165105768113, 0.57135838256627], [0.4937904860816752, 0.03441955059008728], [0.8975134980182307, 0.23701690365976258], [0.8979676261133467, 0.4947689439974302], [0.4825111119164712, 0.8545792988266192], [0.34409472949080666, 0.872110157188082], [0.39479662597166665, 0.46469155745581214], [0.7987317241678275, 0.915429837838087], [0.2720848597448532, 0.6553682104630828], [0.2709611937895329, 0.28312882217308366], [0.43111187150711927, 0.627165161424004], [0.8962927410528921, 0.17286059137962873], [0.9942441292862435, 0.8084999232862351], [0.1869839365828223, 0.6311123046922498], [0.07478106312407284, 0.49605155971801995], [0.6894060829196746, 0.27283184947575523], [0.555454980856394, 0.8818082263512534], [0.919365377076473, 0.3325772558740304], [0.7707758279180693, 0.480229819316236], [0.05969728892868087, 0.118345293748645], [0.15284341350639907, 0.6848678380367137], [0.8551066979305005, 0.7616920746022339], [0.33693711927771497, 0.6687404568758009], [0.9125609804673384, 0.5529048904422192], [0.3359411606962315, 0.5288841483213786], [0.05052155732618979, 0.05950877774022745], [0.3524501217458965, 0.6196115432650898], [0.5305200243177363, 0.5319362876531476], [0.0022283663190201253, 0.2949436575951567], [0.7561711306231926, 0.7716035833712218], [0.7596971709722758, 0.9567732701078838], [0.06036500918266641, 0.5212764005429432], [0.9978682284162491, 0.10427503568378738], [0.6447678008341017, 0.9584601577655691], [0.02908904447419336, 0.39436012238564455], [0.3908872619618189, 0.45558625341149606], [0.6371304199691227, 0.5457447525344098], [0.13623691029323082, 0.5411728211394115], [0.5247676913785825, 0.13041952500466947], [0.8228473554343857, 0.5789756244310207], [0.8978245005252667, 0.677052336093371], [0.9143341136688948, 0.5747770897372464], [0.1571574619606657, 0.31502459111874415], [0.9552648182717801, 0.02708926530013156], [0.8444683509798371, 0.66793006669549], [0.10686738903399673, 0.4267213588433475], [0.5404954485483183, 0.8877805278368643], [0.1886686246693794, 0.9044014501384943], [0.33292859334492797, 0.6425655976460094], [0.8606635464289291, 0.22914407481263643], [0.978478164099745, 0.5541607766878734], [0.9757186728330539, 0.7292536531813154], [0.8326308545742289, 0.0444887678171112], [0.971713257448772, 0.12501290934513365], [0.9381042762597804, 0.11292392896662329], [0.6433334531281611, 0.3259190440975165], [0.19613315966438083, 0.6479199585954877], [0.5474074817305751, 0.409367251707921], [0.2113836295185879, 0.8123024933018266], [0.7095353228319472, 0.5438664471374718], [0.8467155618350992, 0.949149292567522], [0.8086112455708788, 0.37154756726534344], [0.2639808583307288, 0.4604507768885915], [0.9290934853411718, 0.8680728640837589], [0.9366520344626141, 0.3957927471674437], [0.8170074265433214, 0.9146206948357536], [0.19024385562183133, 0.4800984676174723], [0.8942492972672454, 0.4938249426140682], [0.007634068058193111, 0.7625756625276451], [0.33773774499334097, 0.4955250015526702], [0.8465187599128684, 0.534358654268412], [0.054443812525850954, 0.6173514064525885], [0.9401998454538012, 0.6667357629901194], [0.23961529090403366, 0.1359509251838089]], \"data03\": [[0.3203272351145975, 0.8335364155528318], [0.4203350338679286, 0.584762241149771], [0.8458639798311988, 0.8906032495198369], [0.36569269771874735, 0.7002245473157138], [0.514582647824789, 0.7063982140256597], [0.11968726090175474, 0.8514622057853115], [0.7043589198108782, 0.9298449970171021], [0.5586671887234631, 0.1881783329751664], [0.9406066290705133, 0.4052662780095634], [0.6143236276228166, 0.1745277887947705], [0.06452034116681016, 0.875698339147037], [0.37276098239427746, 0.2589212854809264], [0.3204813312273356, 0.04567472511498627], [0.05020939064342467, 0.5804152405709331], [0.8012843738835582, 0.5374880065802101], [0.7579810470114751, 0.5887530932875923], [0.8481572354792598, 0.8952291189669157], [0.9573301053022888, 0.8289680456937573], [0.29711097235301387, 0.009928056952544395], [0.7483782669117083, 0.6803795065816102], [0.4945666538414232, 0.3399336098755622], [0.6419954464424609, 0.7847696520022439], [0.7367662982915205, 0.015490719373013495], [0.13127105045556187, 0.5573011991022919], [0.307968509009243, 0.34319959349464535], [0.5761490557538225, 0.8927291491488131], [0.9292637911230446, 0.050683138825919016], [0.03510424677861601, 0.9787584387584772], [0.5801625021309482, 0.07911879358954843], [0.2206530621480013, 0.3860621997210878], [0.8784488972946168, 0.2913209752002516], [0.4350288213063911, 0.8869227572328181], [0.7244890661037738, 0.8486794347983503], [0.2754568487812361, 0.11272262719044424], [0.22663629898638227, 0.006918410814040654], [0.3019002650811834, 0.7232582487507958], [0.9802884870454528, 0.4414305826853173], [0.013019642582447366, 0.18427707554141037], [0.6576176575325052, 0.22968709290782607], [0.3141147250126384, 0.30308143562393086], [0.615022865061668, 0.06117413116278059], [0.565582163682745, 0.7415381817438464], [0.7909966769777126, 0.4926417517703615], [0.03978624278722798, 0.4775837200471805], [0.7205810535078038, 0.5655864632189355], [0.3676356739169201, 0.9431963940704721], [0.06311427632636823, 0.5552848231777624], [0.4835962769067277, 0.6639844394065039], [0.8390798580246669, 0.1384908280751619], [0.8999449978946574, 0.9793428274291679], [0.7811779061898314, 0.6694009215100615], [0.40269064412144306, 0.1688138073016029], [0.515259873315751, 0.7238613317416049], [0.051622142718159125, 0.922244924805143], [0.44910041094040176, 0.16428991157699135], [0.31195523017861504, 0.8704344689188473], [0.7070117141374869, 0.8788560723224652], [0.5136132681964638, 0.7263341581356326], [0.4313706935483065, 0.3246072413652301], [0.8358614104075586, 0.7464850338571996], [0.14611984546966528, 0.16890054843123659], [0.5004822100777583, 0.39824201214572674], [0.2622808611618471, 0.563260883592359], [0.3528956193470776, 0.19972110770186635], [0.8961098195690627, 0.742095307188639], [0.13829663560943228, 0.27610830585300983], [0.9614782010396442, 0.291723217937233], [0.20261628150031974, 0.06845897751753893], [0.5088636239566634, 0.899973641948937], [0.865146338911064, 0.7216209946215982], [0.013864929249599478, 0.48541237671852944], [0.5728845206806737, 0.5369642525095514], [0.8856409514308515, 0.8476710955335297], [0.5640774453007065, 0.9895982412452545], [0.28002569414603706, 0.43603926929229564], [0.3278847427815923, 0.9222573840671883], [0.306382072092913, 0.14702286688735444], [0.19800098348630712, 0.31718785122455895], [0.9074381004975539, 0.382700475111002], [0.6495242677368901, 0.07254363660559549], [0.790321771006596, 0.30508814255495253], [0.666047965281103, 0.8714281328927928], [0.04776343421843021, 0.007692553237056421], [0.8759782282749793, 0.6544502243372848], [0.7954157527270818, 0.5514512409979686], [0.39362160623603093, 0.1351856191958284], [0.6491887538883317, 0.459380653884503], [0.06312917874558444, 0.5172215795284358], [0.20840523955844892, 0.1061297456214979], [0.9212389782784505, 0.2155546500092128], [0.9687362124913973, 0.3585982712710848], [0.7047796484209112, 0.04828303955514768], [0.21219312391541845, 0.09468780706546076], [0.32748619966584636, 0.06505554809978875], [0.1923153446344461, 0.6473414127553371], [0.43247922523364823, 0.7586608358097756], [0.9759821325352058, 0.8209243300614341], [0.14096634550918907, 0.6078684398587265], [0.0007222708446895654, 0.11757361554347867], [0.6635772961552637, 0.9874937063615683]], \"data01\": [[0.9337896071508014, 0.26210487107557134], [0.8351585335742979, 0.5301133016445017], [0.3673902082932986, 0.8584560409380971], [0.34725246779809205, 0.1829624078714842], [0.7886932247826598, 0.8644865973032086], [0.4440580745862007, 0.8984811696374114], [0.0556294749848435, 0.6250967064409098], [0.3271288050721922, 0.8482029111071808], [0.7640337882344845, 0.8542562524350681], [0.4209935103323551, 0.8112651106877273], [0.7427017868043315, 0.7092822413465556], [0.9648585640913647, 0.352689847006323], [0.7004166324843947, 0.46150329910374777], [0.3328931759476179, 0.0823400774292401], [0.7713894461060906, 0.39810122807227566], [0.67004561859263, 0.8223547875907317], [0.4978749392031838, 0.7817255212732233], [0.782907432220163, 0.24655043090304374], [0.4498514959337665, 0.43333604741219933], [0.6832836668091845, 0.011719239883924648], [0.027293294429139192, 0.039422800253637424], [0.6823274047513601, 0.2509069937274274], [0.006891408250362496, 0.7727781662753845], [0.014293395719481627, 0.7190528371266814], [0.21605330492782526, 0.09838533011594686], [0.7533639880865395, 0.012406388943960178], [0.05461015075829612, 0.46626599955489134], [0.7146447733528821, 0.7706113871630651], [0.2595749779142966, 0.7825260697442016], [0.6745381757431145, 0.20316618514663032], [0.982099069568953, 0.9100843563836049], [0.4133607728897334, 0.1547614923144307], [0.28805648260311456, 0.36515559016704735], [0.26356953265468164, 0.4282693042704998], [0.9388618440704766, 0.33105601503412274], [0.0029162112554420583, 0.3264326397669771], [0.8593812286893946, 0.3103658831443934], [0.4519623682802859, 0.0040882847845443715], [0.40781556329252566, 0.9005600782306642], [0.639425411794307, 0.0952900296454634], [0.5548007927131505, 0.08765781003361761], [0.37978080517027923, 0.5462540144109883], [0.7702113715966054, 0.34272740822367487], [0.5633988570181039, 0.9267468690420295], [0.6267682456988396, 0.67495262862907], [0.9770246190397904, 0.9404447767744459], [0.10850795865645069, 0.6590642106998655], [0.573519394636228, 0.08303538680528266], [0.1985601570031139, 0.4617266688731311], [0.3689458481010012, 0.5979611763732767], [0.09816499431899284, 0.8590848563728619], [0.7854227651304604, 0.4584359018973586], [0.4716496822096633, 0.8729352906587778], [0.4650544134556974, 0.422595699709889], [0.9052038650056381, 0.2965880531428532], [0.8120825259052143, 0.11285364123655262], [0.9403571650492082, 0.6860693263879939], [0.63592817515658, 0.37493433102400286], [0.7984938638086895, 0.007901762178482818], [0.8686207086495045, 0.5778510529393696], [0.018144694325693655, 0.3132543168929912], [0.6192431292345925, 0.3132388939183731], [0.7183065252294973, 0.10619854401501183], [0.9090996564565473, 0.16655593811919223], [0.6134956329060927, 0.9052526862673087], [0.5249254354384066, 0.36349953365941345], [0.026096540722630013, 0.31501732674967486], [0.6461233160251367, 0.13195097142448597], [0.6106530732727414, 0.4315702441121203], [0.4836920528410096, 0.9140973888407937], [0.9106456031211833, 0.0842870601237019], [0.6644383401541888, 0.6533080493904203], [0.6503710212604545, 0.7561640824697892], [0.7243497027619566, 0.24017708737403398], [0.13582427381408024, 0.19003435227318233], [0.9213243561824673, 0.1498281035456397], [0.9304062315332647, 0.741816496635188], [0.3122438152895588, 0.3078838024784528], [0.4793345078460184, 0.5317666354287778], [0.5568539330050538, 0.2953423154570297], [0.06519593979517235, 0.6415473019210939], [0.3894476731410479, 0.32360291703446686], [0.5335442990981843, 0.9709040106764336], [0.7982222112686944, 0.9565480376702594], [0.49564261995579617, 0.7883959987966798], [0.7813193296381757, 0.27414367360434755], [0.3358464154926011, 0.09551171745684373], [0.8675785718727186, 0.41075312704753286], [0.8457361396420353, 0.008828999792782843], [0.34981063159440673, 0.38516513550330744], [0.12204686820349964, 0.44621057220271887], [0.6882374234689828, 0.8596091372132191], [0.6144071646482189, 0.030344647148762727], [0.5152773923208307, 0.19325968170302688], [0.7209742279562512, 0.6316887135073014], [0.964392536579791, 0.7103663521811615], [0.4885163059730062, 0.4354552241790316], [0.977595760053659, 0.46582174451005043], [0.7145474439075008, 0.7294681726999905], [0.9429986923599958, 0.1275189841784946]]}, \"id\": \"el100754535888336\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "         \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "         mpld3.draw_figure(\"fig_el1007545358883369021618064\", {\"axes\": [{\"xlim\": [-0.20000000000000001, 1.2000000000000002], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-0.20000000000000001, 1.2000000000000002], \"ylim\": [-0.20000000000000001, 1.2000000000000002], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 9, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 9, \"tickvalues\": null}], \"lines\": [], \"markers\": [], \"id\": \"el100754564825296\", \"ydomain\": [-0.20000000000000001, 1.2000000000000002], \"collections\": [{\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#BFBF00\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 1, \"id\": \"el100754534924624\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#BFBF00\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data02\", \"yindex\": 1, \"id\": \"el100754535115472\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#000000\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#0000FF\"], \"edgewidths\": [1.0], \"offsets\": \"data03\", \"yindex\": 1, \"id\": \"el100754535112592\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#0000FF\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#007F00\"], \"edgewidths\": [1.0], \"offsets\": \"data04\", \"yindex\": 1, \"id\": \"el100754535845584\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#007F00\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#FF0000\"], \"edgewidths\": [1.0], \"offsets\": \"data05\", \"yindex\": 1, \"id\": \"el100754535847440\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#FF0000\"]}], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754534924624\"], [\"el100754535115472\"], [\"el100754535112592\"], [\"el100754535845584\"], [\"el100754535847440\"]], \"type\": \"interactive_legend\", \"labels\": [\"0\", \"1\", \"2\", \"3\", \"4\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data04\": [[0.9242519631087408, 0.39804086882196144], [0.9126097026627603, 0.9966812574636679], [0.16177892393363236, 0.9835478103937141], [0.7290207152190079, 0.30424873457519186], [0.22633003479410652, 0.1377797931238578], [0.7813052928901829, 0.9932452835915527], [0.511627211343237, 0.4561403153339668], [0.4331427984353847, 0.7472121091145788], [0.045386339333301384, 0.9733452237855091], [0.034598644287704206, 0.5466502285541966], [0.3612719946534252, 0.049663979477878706], [0.8543283471717548, 0.43236762953935415], [0.5647181799398293, 0.43851443078500296], [0.36167288584686363, 0.16229725352040503], [0.20304599789853517, 0.11038895897136092], [0.1515811733422764, 0.6094603522429083], [0.9087683303320383, 0.897613621940072], [0.901990648341611, 0.13254951313402696], [0.49456954491121574, 0.4422539373577671], [0.9241419221303792, 0.7725212485471615], [0.5934836870312762, 0.03506928483863481], [0.6205901296332685, 0.12232967326915056], [0.6475995188546149, 0.5863539955652299], [0.7578402507602906, 0.7239187419244221], [0.6341796250185249, 0.7093967781484286], [0.2852367881531317, 0.7874310283493733], [0.10378708251127533, 0.6728180752692836], [0.3748324712118384, 0.06758030806883275], [0.050921133450575584, 0.8253252989186546], [0.17337201194929286, 0.6887068053214239], [0.9349263028690167, 0.1461095475487837], [0.8978238994288542, 0.07955578785605977], [0.26722036674939276, 0.6309769909437343], [0.57387788373186, 0.6074204836513427], [0.21743854878208568, 0.41552395751324844], [0.7223835447005645, 0.2032068360596292], [0.3250653630626674, 0.66652248928253], [0.9797703787368516, 0.2319682036102848], [0.8001390060599199, 0.0945216013025898], [0.7492067125159604, 0.6149921849680753], [0.8020181902969954, 0.32131298721588275], [0.893733162911723, 0.08788242205955898], [0.8984066385728788, 0.8588957589407241], [0.5028592927379153, 0.810806577474733], [0.5879458605906736, 0.4142613690167992], [0.7988738670904313, 0.6629090860045823], [0.02543952472313904, 0.0011155447114389316], [0.6871121698402548, 0.8456218148794823], [0.0672718812024854, 0.2873353143050722], [0.7707035199501348, 0.13295966586873553], [0.9710420374930185, 0.18925168540274884], [0.9916389907887001, 0.07399906530135014], [0.24800614902198614, 0.8911066506717814], [0.13481783369188294, 0.8359012936320355], [0.7330238100877549, 0.5404546941997577], [0.6954896263303783, 0.6775779258477295], [0.8515601986012354, 0.04086213505331526], [0.695171596079609, 0.9114608544079199], [0.6033154073049452, 0.8770692870017625], [0.2145720323728718, 0.4112232353838494], [0.4427821886142954, 0.2826779825618091], [0.49890428160591327, 0.35992384107960285], [0.14416615428021906, 0.9511338695055563], [0.6751892035893142, 0.9065148942702237], [0.708541804826553, 0.40561686400140395], [0.5655725800793501, 0.5538489382195868], [0.2406609243946839, 0.1016675702287424], [0.8202332469394755, 0.6384139346887739], [0.8077922399555246, 0.3876071857071599], [0.40867045124791923, 0.9360801817211917], [0.7059342627237338, 0.27185090462073747], [0.519516694501997, 0.654718629604253], [0.8803934218803643, 0.3884939028466704], [0.09996565553723069, 0.7773404292816348], [0.6051028948373115, 0.307760208805379], [0.28630619692527337, 0.18235826122852605], [0.9254138247359804, 0.26848283235908077], [0.9871064431890462, 0.41626625151721763], [0.9055967613457812, 0.9522308434012204], [0.6518028959044958, 0.2922721713061237], [0.6932474425153093, 0.08801877979970107], [0.09731227699861356, 0.7906676529641823], [0.30894286807657156, 0.41399595645933684], [0.24610318780631524, 0.010548610304123685], [0.24514338877403274, 0.5279518129180067], [0.5570720342088052, 0.4366548014590623], [0.1388290857367228, 0.7532826547555839], [0.10673304004977613, 0.3096766502129693], [0.8082537335284038, 0.027747965349013803], [0.7544617775486192, 0.4703538962398426], [0.16797282173884742, 0.41604764069800027], [0.48082193732237843, 0.13259259308368754], [0.3284447161159144, 0.14731349797730886], [0.45780364015692154, 0.6095560252502288], [0.01820095657060905, 0.22415568146209897], [0.2349767799500877, 0.4325929577188884], [0.13278557186010875, 0.5037764884870928], [0.809697530772305, 0.6874428289257826], [0.42552618327856084, 0.3426171743185057], [0.3533085364318135, 0.3370968695051333]], \"data05\": [[0.5303590898478936, 0.13711428791109015], [0.12322490675551157, 0.886024852886269], [0.4089742660225866, 0.14071766847012235], [0.10941879286651779, 0.48282919093264076], [0.4728634153181045, 0.6361502366562537], [0.5680544970375454, 0.7085927608942354], [0.3234811723712886, 0.5978004054235319], [0.8913191773960594, 0.3336796792771711], [0.9536357985956547, 0.8908541623760522], [0.6302083823778912, 0.027048470946945846], [0.9982804845300204, 0.29941219899049554], [0.5948381724999198, 0.9612900038908112], [0.6989246952080482, 0.9811527676394494], [0.6549832929112029, 0.2839319657142868], [0.4866567528959358, 0.31319113187712166], [0.15620745746164766, 0.3530183658096693], [0.37369581146924347, 0.09427174906507774], [0.9746086918203388, 0.578470459470677], [0.8483243540818455, 0.28093001298546916], [0.37367302574151706, 0.6818242397190019], [0.2417931607898266, 0.4811527526511765], [0.49639137156393554, 0.2398641429788264], [0.14855806964180618, 0.8842859574274882], [0.5739347296103652, 0.172383578884151], [0.24223663887225344, 0.30814403349988095], [0.1220331440628114, 0.0768468480492891], [0.1030759019040417, 0.9928066438130376], [0.7548677954026867, 0.23581987298236284], [0.4664349774431229, 0.40971764048768944], [0.34750245248971656, 0.8597533597932135], [0.42372735483316515, 0.9481066021739991], [0.9151906877964716, 0.3276895157638441], [0.6142963919322558, 0.23371003537579949], [0.9936625068211631, 0.6110979935200785], [0.3254980679138474, 0.5833857888763009], [0.011304132829930147, 0.8790562911692762], [0.5653196518565355, 0.25358472800004395], [0.12194468991797869, 0.7123622705987561], [0.25728868880589917, 0.04359895035949535], [0.018691228834961326, 0.6423881938845716], [0.36321326425982914, 0.4009723390247496], [0.7052534909756388, 0.6011404087366192], [0.3510187095415981, 0.03388316114365986], [0.039039234827561886, 0.5006514843196327], [0.7484974994028434, 0.43626987170746534], [0.04701967105980742, 0.45287367270615386], [0.8977531073544337, 0.5409783137361621], [0.9428065486556295, 0.6568964066620901], [0.7655752246435434, 0.17919050668518388], [0.4637109182220772, 0.7097420304062763], [0.7961060269507684, 0.07049913908366179], [0.5669562681346024, 0.027410649888650718], [0.9406654157439517, 0.9161997528149837], [0.11632731874264224, 0.6875493862435358], [0.48464171270817125, 0.9887455834156222], [0.8854345413427909, 0.49530775678797445], [0.008197359860088071, 0.7597498106862539], [0.3586531582538418, 0.9628339543557296], [0.22764721330724302, 0.1405341173516369], [0.7282174787391045, 0.5266952761039118], [0.7762217629823028, 0.9682518311055232], [0.7260866242517884, 0.28203938167045295], [0.929153272673218, 0.5400713424363478], [0.8337855778393145, 0.6795875111461626], [0.8811577685468234, 0.9676050547116376], [0.16686808006119924, 0.02425116871348032], [0.9537611574141022, 0.46499078093429846], [0.3557643599271686, 0.18176818250012716], [0.5539694427896724, 0.9702486452125939], [0.8046574117521608, 0.1033350953965424], [0.8545637343389454, 0.28552444817017697], [0.6649160184185691, 0.5807541580054544], [0.8656474156668079, 0.010757553818076637], [0.7449843057340946, 0.11467989496079967], [0.022313719511357855, 0.4631106389943791], [0.6846131837001713, 0.5974023844003244], [0.08713516099208285, 0.03160862084948668], [0.07726363230708022, 0.43777601426565294], [0.6038222456380775, 0.7950979710584937], [0.5162786005582756, 0.5909702087113057], [0.6073608646745878, 0.6152722269956976], [0.7520048711147257, 0.18293980280385702], [0.8407469579182841, 0.3107740017846162], [0.7314393477783951, 0.0033205006476206833], [0.35927909474977293, 0.14011525238291211], [0.7660767539642495, 0.6850158748918177], [0.43992881261355854, 0.5276038891658873], [0.8106500220239526, 0.23103846501309344], [0.5851638380608137, 0.7897930722253051], [0.6311152524965394, 0.036093413779834216], [0.10508669958387984, 0.7511807817455597], [0.055370524456371806, 0.3943681075719089], [0.4096713516358751, 0.7868392811097878], [0.674225751740304, 0.2992275731499737], [0.9328139326950637, 0.3584841104098604], [0.32067802910475596, 0.04962728120086746], [0.39925061680451845, 0.5432935549737629], [0.9602342510141207, 0.0603765122472435], [0.5868120557355941, 0.4106064978457815], [0.29643089285171664, 0.37789664517154564]], \"data02\": [[0.5757281402347376, 0.12476822907952634], [0.8843691160959513, 0.5871710607925391], [0.6073338063051109, 0.18808934201908567], [0.10872697639641205, 0.9181416618801573], [0.43324928639328397, 0.3241244143937009], [0.9817042936056718, 0.5299763370829639], [0.38930607099283787, 0.6767587233228362], [0.8936662582765941, 0.03160166842793044], [0.46701333481729934, 0.3468895684080464], [0.5527106830801924, 0.12559908590827484], [0.2527553536672792, 0.7782016784466976], [0.5438063282122486, 0.33583124597023173], [0.7657595580414235, 0.8892752434091579], [0.48043927289390154, 0.6012612039899949], [0.5699371291323116, 0.6264430866819386], [0.6848164641409118, 0.3206319237601867], [0.2461711098756535, 0.4582381862704157], [0.36784406388138524, 0.6925870953637762], [0.15579851407905432, 0.03150131689977309], [0.8083211690028597, 0.29458313536486125], [0.23183111835471448, 0.6195056379907635], [0.303655801185987, 0.4933598706350324], [0.9910972375282245, 0.9987048732731857], [0.14915029471809094, 0.0530079750044139], [0.4843605314487036, 0.4152171128240163], [0.4215310154895132, 0.5724189902269761], [0.15969165105768113, 0.57135838256627], [0.4937904860816752, 0.03441955059008728], [0.8975134980182307, 0.23701690365976258], [0.8979676261133467, 0.4947689439974302], [0.4825111119164712, 0.8545792988266192], [0.34409472949080666, 0.872110157188082], [0.39479662597166665, 0.46469155745581214], [0.7987317241678275, 0.915429837838087], [0.2720848597448532, 0.6553682104630828], [0.2709611937895329, 0.28312882217308366], [0.43111187150711927, 0.627165161424004], [0.8962927410528921, 0.17286059137962873], [0.9942441292862435, 0.8084999232862351], [0.1869839365828223, 0.6311123046922498], [0.07478106312407284, 0.49605155971801995], [0.6894060829196746, 0.27283184947575523], [0.555454980856394, 0.8818082263512534], [0.919365377076473, 0.3325772558740304], [0.7707758279180693, 0.480229819316236], [0.05969728892868087, 0.118345293748645], [0.15284341350639907, 0.6848678380367137], [0.8551066979305005, 0.7616920746022339], [0.33693711927771497, 0.6687404568758009], [0.9125609804673384, 0.5529048904422192], [0.3359411606962315, 0.5288841483213786], [0.05052155732618979, 0.05950877774022745], [0.3524501217458965, 0.6196115432650898], [0.5305200243177363, 0.5319362876531476], [0.0022283663190201253, 0.2949436575951567], [0.7561711306231926, 0.7716035833712218], [0.7596971709722758, 0.9567732701078838], [0.06036500918266641, 0.5212764005429432], [0.9978682284162491, 0.10427503568378738], [0.6447678008341017, 0.9584601577655691], [0.02908904447419336, 0.39436012238564455], [0.3908872619618189, 0.45558625341149606], [0.6371304199691227, 0.5457447525344098], [0.13623691029323082, 0.5411728211394115], [0.5247676913785825, 0.13041952500466947], [0.8228473554343857, 0.5789756244310207], [0.8978245005252667, 0.677052336093371], [0.9143341136688948, 0.5747770897372464], [0.1571574619606657, 0.31502459111874415], [0.9552648182717801, 0.02708926530013156], [0.8444683509798371, 0.66793006669549], [0.10686738903399673, 0.4267213588433475], [0.5404954485483183, 0.8877805278368643], [0.1886686246693794, 0.9044014501384943], [0.33292859334492797, 0.6425655976460094], [0.8606635464289291, 0.22914407481263643], [0.978478164099745, 0.5541607766878734], [0.9757186728330539, 0.7292536531813154], [0.8326308545742289, 0.0444887678171112], [0.971713257448772, 0.12501290934513365], [0.9381042762597804, 0.11292392896662329], [0.6433334531281611, 0.3259190440975165], [0.19613315966438083, 0.6479199585954877], [0.5474074817305751, 0.409367251707921], [0.2113836295185879, 0.8123024933018266], [0.7095353228319472, 0.5438664471374718], [0.8467155618350992, 0.949149292567522], [0.8086112455708788, 0.37154756726534344], [0.2639808583307288, 0.4604507768885915], [0.9290934853411718, 0.8680728640837589], [0.9366520344626141, 0.3957927471674437], [0.8170074265433214, 0.9146206948357536], [0.19024385562183133, 0.4800984676174723], [0.8942492972672454, 0.4938249426140682], [0.007634068058193111, 0.7625756625276451], [0.33773774499334097, 0.4955250015526702], [0.8465187599128684, 0.534358654268412], [0.054443812525850954, 0.6173514064525885], [0.9401998454538012, 0.6667357629901194], [0.23961529090403366, 0.1359509251838089]], \"data03\": [[0.3203272351145975, 0.8335364155528318], [0.4203350338679286, 0.584762241149771], [0.8458639798311988, 0.8906032495198369], [0.36569269771874735, 0.7002245473157138], [0.514582647824789, 0.7063982140256597], [0.11968726090175474, 0.8514622057853115], [0.7043589198108782, 0.9298449970171021], [0.5586671887234631, 0.1881783329751664], [0.9406066290705133, 0.4052662780095634], [0.6143236276228166, 0.1745277887947705], [0.06452034116681016, 0.875698339147037], [0.37276098239427746, 0.2589212854809264], [0.3204813312273356, 0.04567472511498627], [0.05020939064342467, 0.5804152405709331], [0.8012843738835582, 0.5374880065802101], [0.7579810470114751, 0.5887530932875923], [0.8481572354792598, 0.8952291189669157], [0.9573301053022888, 0.8289680456937573], [0.29711097235301387, 0.009928056952544395], [0.7483782669117083, 0.6803795065816102], [0.4945666538414232, 0.3399336098755622], [0.6419954464424609, 0.7847696520022439], [0.7367662982915205, 0.015490719373013495], [0.13127105045556187, 0.5573011991022919], [0.307968509009243, 0.34319959349464535], [0.5761490557538225, 0.8927291491488131], [0.9292637911230446, 0.050683138825919016], [0.03510424677861601, 0.9787584387584772], [0.5801625021309482, 0.07911879358954843], [0.2206530621480013, 0.3860621997210878], [0.8784488972946168, 0.2913209752002516], [0.4350288213063911, 0.8869227572328181], [0.7244890661037738, 0.8486794347983503], [0.2754568487812361, 0.11272262719044424], [0.22663629898638227, 0.006918410814040654], [0.3019002650811834, 0.7232582487507958], [0.9802884870454528, 0.4414305826853173], [0.013019642582447366, 0.18427707554141037], [0.6576176575325052, 0.22968709290782607], [0.3141147250126384, 0.30308143562393086], [0.615022865061668, 0.06117413116278059], [0.565582163682745, 0.7415381817438464], [0.7909966769777126, 0.4926417517703615], [0.03978624278722798, 0.4775837200471805], [0.7205810535078038, 0.5655864632189355], [0.3676356739169201, 0.9431963940704721], [0.06311427632636823, 0.5552848231777624], [0.4835962769067277, 0.6639844394065039], [0.8390798580246669, 0.1384908280751619], [0.8999449978946574, 0.9793428274291679], [0.7811779061898314, 0.6694009215100615], [0.40269064412144306, 0.1688138073016029], [0.515259873315751, 0.7238613317416049], [0.051622142718159125, 0.922244924805143], [0.44910041094040176, 0.16428991157699135], [0.31195523017861504, 0.8704344689188473], [0.7070117141374869, 0.8788560723224652], [0.5136132681964638, 0.7263341581356326], [0.4313706935483065, 0.3246072413652301], [0.8358614104075586, 0.7464850338571996], [0.14611984546966528, 0.16890054843123659], [0.5004822100777583, 0.39824201214572674], [0.2622808611618471, 0.563260883592359], [0.3528956193470776, 0.19972110770186635], [0.8961098195690627, 0.742095307188639], [0.13829663560943228, 0.27610830585300983], [0.9614782010396442, 0.291723217937233], [0.20261628150031974, 0.06845897751753893], [0.5088636239566634, 0.899973641948937], [0.865146338911064, 0.7216209946215982], [0.013864929249599478, 0.48541237671852944], [0.5728845206806737, 0.5369642525095514], [0.8856409514308515, 0.8476710955335297], [0.5640774453007065, 0.9895982412452545], [0.28002569414603706, 0.43603926929229564], [0.3278847427815923, 0.9222573840671883], [0.306382072092913, 0.14702286688735444], [0.19800098348630712, 0.31718785122455895], [0.9074381004975539, 0.382700475111002], [0.6495242677368901, 0.07254363660559549], [0.790321771006596, 0.30508814255495253], [0.666047965281103, 0.8714281328927928], [0.04776343421843021, 0.007692553237056421], [0.8759782282749793, 0.6544502243372848], [0.7954157527270818, 0.5514512409979686], [0.39362160623603093, 0.1351856191958284], [0.6491887538883317, 0.459380653884503], [0.06312917874558444, 0.5172215795284358], [0.20840523955844892, 0.1061297456214979], [0.9212389782784505, 0.2155546500092128], [0.9687362124913973, 0.3585982712710848], [0.7047796484209112, 0.04828303955514768], [0.21219312391541845, 0.09468780706546076], [0.32748619966584636, 0.06505554809978875], [0.1923153446344461, 0.6473414127553371], [0.43247922523364823, 0.7586608358097756], [0.9759821325352058, 0.8209243300614341], [0.14096634550918907, 0.6078684398587265], [0.0007222708446895654, 0.11757361554347867], [0.6635772961552637, 0.9874937063615683]], \"data01\": [[0.9337896071508014, 0.26210487107557134], [0.8351585335742979, 0.5301133016445017], [0.3673902082932986, 0.8584560409380971], [0.34725246779809205, 0.1829624078714842], [0.7886932247826598, 0.8644865973032086], [0.4440580745862007, 0.8984811696374114], [0.0556294749848435, 0.6250967064409098], [0.3271288050721922, 0.8482029111071808], [0.7640337882344845, 0.8542562524350681], [0.4209935103323551, 0.8112651106877273], [0.7427017868043315, 0.7092822413465556], [0.9648585640913647, 0.352689847006323], [0.7004166324843947, 0.46150329910374777], [0.3328931759476179, 0.0823400774292401], [0.7713894461060906, 0.39810122807227566], [0.67004561859263, 0.8223547875907317], [0.4978749392031838, 0.7817255212732233], [0.782907432220163, 0.24655043090304374], [0.4498514959337665, 0.43333604741219933], [0.6832836668091845, 0.011719239883924648], [0.027293294429139192, 0.039422800253637424], [0.6823274047513601, 0.2509069937274274], [0.006891408250362496, 0.7727781662753845], [0.014293395719481627, 0.7190528371266814], [0.21605330492782526, 0.09838533011594686], [0.7533639880865395, 0.012406388943960178], [0.05461015075829612, 0.46626599955489134], [0.7146447733528821, 0.7706113871630651], [0.2595749779142966, 0.7825260697442016], [0.6745381757431145, 0.20316618514663032], [0.982099069568953, 0.9100843563836049], [0.4133607728897334, 0.1547614923144307], [0.28805648260311456, 0.36515559016704735], [0.26356953265468164, 0.4282693042704998], [0.9388618440704766, 0.33105601503412274], [0.0029162112554420583, 0.3264326397669771], [0.8593812286893946, 0.3103658831443934], [0.4519623682802859, 0.0040882847845443715], [0.40781556329252566, 0.9005600782306642], [0.639425411794307, 0.0952900296454634], [0.5548007927131505, 0.08765781003361761], [0.37978080517027923, 0.5462540144109883], [0.7702113715966054, 0.34272740822367487], [0.5633988570181039, 0.9267468690420295], [0.6267682456988396, 0.67495262862907], [0.9770246190397904, 0.9404447767744459], [0.10850795865645069, 0.6590642106998655], [0.573519394636228, 0.08303538680528266], [0.1985601570031139, 0.4617266688731311], [0.3689458481010012, 0.5979611763732767], [0.09816499431899284, 0.8590848563728619], [0.7854227651304604, 0.4584359018973586], [0.4716496822096633, 0.8729352906587778], [0.4650544134556974, 0.422595699709889], [0.9052038650056381, 0.2965880531428532], [0.8120825259052143, 0.11285364123655262], [0.9403571650492082, 0.6860693263879939], [0.63592817515658, 0.37493433102400286], [0.7984938638086895, 0.007901762178482818], [0.8686207086495045, 0.5778510529393696], [0.018144694325693655, 0.3132543168929912], [0.6192431292345925, 0.3132388939183731], [0.7183065252294973, 0.10619854401501183], [0.9090996564565473, 0.16655593811919223], [0.6134956329060927, 0.9052526862673087], [0.5249254354384066, 0.36349953365941345], [0.026096540722630013, 0.31501732674967486], [0.6461233160251367, 0.13195097142448597], [0.6106530732727414, 0.4315702441121203], [0.4836920528410096, 0.9140973888407937], [0.9106456031211833, 0.0842870601237019], [0.6644383401541888, 0.6533080493904203], [0.6503710212604545, 0.7561640824697892], [0.7243497027619566, 0.24017708737403398], [0.13582427381408024, 0.19003435227318233], [0.9213243561824673, 0.1498281035456397], [0.9304062315332647, 0.741816496635188], [0.3122438152895588, 0.3078838024784528], [0.4793345078460184, 0.5317666354287778], [0.5568539330050538, 0.2953423154570297], [0.06519593979517235, 0.6415473019210939], [0.3894476731410479, 0.32360291703446686], [0.5335442990981843, 0.9709040106764336], [0.7982222112686944, 0.9565480376702594], [0.49564261995579617, 0.7883959987966798], [0.7813193296381757, 0.27414367360434755], [0.3358464154926011, 0.09551171745684373], [0.8675785718727186, 0.41075312704753286], [0.8457361396420353, 0.008828999792782843], [0.34981063159440673, 0.38516513550330744], [0.12204686820349964, 0.44621057220271887], [0.6882374234689828, 0.8596091372132191], [0.6144071646482189, 0.030344647148762727], [0.5152773923208307, 0.19325968170302688], [0.7209742279562512, 0.6316887135073014], [0.964392536579791, 0.7103663521811615], [0.4885163059730062, 0.4354552241790316], [0.977595760053659, 0.46582174451005043], [0.7145474439075008, 0.7294681726999905], [0.9429986923599958, 0.1275189841784946]]}, \"id\": \"el100754535888336\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "                 \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "                 mpld3.draw_figure(\"fig_el1007545358883369021618064\", {\"axes\": [{\"xlim\": [-0.20000000000000001, 1.2000000000000002], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-0.20000000000000001, 1.2000000000000002], \"ylim\": [-0.20000000000000001, 1.2000000000000002], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 9, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 9, \"tickvalues\": null}], \"lines\": [], \"markers\": [], \"id\": \"el100754564825296\", \"ydomain\": [-0.20000000000000001, 1.2000000000000002], \"collections\": [{\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#BFBF00\"], \"edgewidths\": [1.0], \"offsets\": \"data01\", \"yindex\": 1, \"id\": \"el100754534924624\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#BFBF00\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#000000\"], \"edgewidths\": [1.0], \"offsets\": \"data02\", \"yindex\": 1, \"id\": \"el100754535115472\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#000000\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#0000FF\"], \"edgewidths\": [1.0], \"offsets\": \"data03\", \"yindex\": 1, \"id\": \"el100754535112592\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#0000FF\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#007F00\"], \"edgewidths\": [1.0], \"offsets\": \"data04\", \"yindex\": 1, \"id\": \"el100754535845584\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#007F00\"]}, {\"paths\": [[[[-0.5, 0.0], [0.5, 0.0], [0.0, -0.5], [0.0, 0.5]], [\"M\", \"L\", \"M\", \"L\"]]], \"edgecolors\": [\"#FF0000\"], \"edgewidths\": [1.0], \"offsets\": \"data05\", \"yindex\": 1, \"id\": \"el100754535847440\", \"pathtransforms\": [[4.969039949999533, 0.0, 0.0, 4.969039949999533, 0.0, 0.0]], \"pathcoordinates\": \"display\", \"offsetcoordinates\": \"data\", \"zorder\": 1, \"xindex\": 0, \"alphas\": [0.2], \"facecolors\": [\"#FF0000\"]}], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754534924624\"], [\"el100754535115472\"], [\"el100754535112592\"], [\"el100754535845584\"], [\"el100754535847440\"]], \"type\": \"interactive_legend\", \"labels\": [\"0\", \"1\", \"2\", \"3\", \"4\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data04\": [[0.9242519631087408, 0.39804086882196144], [0.9126097026627603, 0.9966812574636679], [0.16177892393363236, 0.9835478103937141], [0.7290207152190079, 0.30424873457519186], [0.22633003479410652, 0.1377797931238578], [0.7813052928901829, 0.9932452835915527], [0.511627211343237, 0.4561403153339668], [0.4331427984353847, 0.7472121091145788], [0.045386339333301384, 0.9733452237855091], [0.034598644287704206, 0.5466502285541966], [0.3612719946534252, 0.049663979477878706], [0.8543283471717548, 0.43236762953935415], [0.5647181799398293, 0.43851443078500296], [0.36167288584686363, 0.16229725352040503], [0.20304599789853517, 0.11038895897136092], [0.1515811733422764, 0.6094603522429083], [0.9087683303320383, 0.897613621940072], [0.901990648341611, 0.13254951313402696], [0.49456954491121574, 0.4422539373577671], [0.9241419221303792, 0.7725212485471615], [0.5934836870312762, 0.03506928483863481], [0.6205901296332685, 0.12232967326915056], [0.6475995188546149, 0.5863539955652299], [0.7578402507602906, 0.7239187419244221], [0.6341796250185249, 0.7093967781484286], [0.2852367881531317, 0.7874310283493733], [0.10378708251127533, 0.6728180752692836], [0.3748324712118384, 0.06758030806883275], [0.050921133450575584, 0.8253252989186546], [0.17337201194929286, 0.6887068053214239], [0.9349263028690167, 0.1461095475487837], [0.8978238994288542, 0.07955578785605977], [0.26722036674939276, 0.6309769909437343], [0.57387788373186, 0.6074204836513427], [0.21743854878208568, 0.41552395751324844], [0.7223835447005645, 0.2032068360596292], [0.3250653630626674, 0.66652248928253], [0.9797703787368516, 0.2319682036102848], [0.8001390060599199, 0.0945216013025898], [0.7492067125159604, 0.6149921849680753], [0.8020181902969954, 0.32131298721588275], [0.893733162911723, 0.08788242205955898], [0.8984066385728788, 0.8588957589407241], [0.5028592927379153, 0.810806577474733], [0.5879458605906736, 0.4142613690167992], [0.7988738670904313, 0.6629090860045823], [0.02543952472313904, 0.0011155447114389316], [0.6871121698402548, 0.8456218148794823], [0.0672718812024854, 0.2873353143050722], [0.7707035199501348, 0.13295966586873553], [0.9710420374930185, 0.18925168540274884], [0.9916389907887001, 0.07399906530135014], [0.24800614902198614, 0.8911066506717814], [0.13481783369188294, 0.8359012936320355], [0.7330238100877549, 0.5404546941997577], [0.6954896263303783, 0.6775779258477295], [0.8515601986012354, 0.04086213505331526], [0.695171596079609, 0.9114608544079199], [0.6033154073049452, 0.8770692870017625], [0.2145720323728718, 0.4112232353838494], [0.4427821886142954, 0.2826779825618091], [0.49890428160591327, 0.35992384107960285], [0.14416615428021906, 0.9511338695055563], [0.6751892035893142, 0.9065148942702237], [0.708541804826553, 0.40561686400140395], [0.5655725800793501, 0.5538489382195868], [0.2406609243946839, 0.1016675702287424], [0.8202332469394755, 0.6384139346887739], [0.8077922399555246, 0.3876071857071599], [0.40867045124791923, 0.9360801817211917], [0.7059342627237338, 0.27185090462073747], [0.519516694501997, 0.654718629604253], [0.8803934218803643, 0.3884939028466704], [0.09996565553723069, 0.7773404292816348], [0.6051028948373115, 0.307760208805379], [0.28630619692527337, 0.18235826122852605], [0.9254138247359804, 0.26848283235908077], [0.9871064431890462, 0.41626625151721763], [0.9055967613457812, 0.9522308434012204], [0.6518028959044958, 0.2922721713061237], [0.6932474425153093, 0.08801877979970107], [0.09731227699861356, 0.7906676529641823], [0.30894286807657156, 0.41399595645933684], [0.24610318780631524, 0.010548610304123685], [0.24514338877403274, 0.5279518129180067], [0.5570720342088052, 0.4366548014590623], [0.1388290857367228, 0.7532826547555839], [0.10673304004977613, 0.3096766502129693], [0.8082537335284038, 0.027747965349013803], [0.7544617775486192, 0.4703538962398426], [0.16797282173884742, 0.41604764069800027], [0.48082193732237843, 0.13259259308368754], [0.3284447161159144, 0.14731349797730886], [0.45780364015692154, 0.6095560252502288], [0.01820095657060905, 0.22415568146209897], [0.2349767799500877, 0.4325929577188884], [0.13278557186010875, 0.5037764884870928], [0.809697530772305, 0.6874428289257826], [0.42552618327856084, 0.3426171743185057], [0.3533085364318135, 0.3370968695051333]], \"data05\": [[0.5303590898478936, 0.13711428791109015], [0.12322490675551157, 0.886024852886269], [0.4089742660225866, 0.14071766847012235], [0.10941879286651779, 0.48282919093264076], [0.4728634153181045, 0.6361502366562537], [0.5680544970375454, 0.7085927608942354], [0.3234811723712886, 0.5978004054235319], [0.8913191773960594, 0.3336796792771711], [0.9536357985956547, 0.8908541623760522], [0.6302083823778912, 0.027048470946945846], [0.9982804845300204, 0.29941219899049554], [0.5948381724999198, 0.9612900038908112], [0.6989246952080482, 0.9811527676394494], [0.6549832929112029, 0.2839319657142868], [0.4866567528959358, 0.31319113187712166], [0.15620745746164766, 0.3530183658096693], [0.37369581146924347, 0.09427174906507774], [0.9746086918203388, 0.578470459470677], [0.8483243540818455, 0.28093001298546916], [0.37367302574151706, 0.6818242397190019], [0.2417931607898266, 0.4811527526511765], [0.49639137156393554, 0.2398641429788264], [0.14855806964180618, 0.8842859574274882], [0.5739347296103652, 0.172383578884151], [0.24223663887225344, 0.30814403349988095], [0.1220331440628114, 0.0768468480492891], [0.1030759019040417, 0.9928066438130376], [0.7548677954026867, 0.23581987298236284], [0.4664349774431229, 0.40971764048768944], [0.34750245248971656, 0.8597533597932135], [0.42372735483316515, 0.9481066021739991], [0.9151906877964716, 0.3276895157638441], [0.6142963919322558, 0.23371003537579949], [0.9936625068211631, 0.6110979935200785], [0.3254980679138474, 0.5833857888763009], [0.011304132829930147, 0.8790562911692762], [0.5653196518565355, 0.25358472800004395], [0.12194468991797869, 0.7123622705987561], [0.25728868880589917, 0.04359895035949535], [0.018691228834961326, 0.6423881938845716], [0.36321326425982914, 0.4009723390247496], [0.7052534909756388, 0.6011404087366192], [0.3510187095415981, 0.03388316114365986], [0.039039234827561886, 0.5006514843196327], [0.7484974994028434, 0.43626987170746534], [0.04701967105980742, 0.45287367270615386], [0.8977531073544337, 0.5409783137361621], [0.9428065486556295, 0.6568964066620901], [0.7655752246435434, 0.17919050668518388], [0.4637109182220772, 0.7097420304062763], [0.7961060269507684, 0.07049913908366179], [0.5669562681346024, 0.027410649888650718], [0.9406654157439517, 0.9161997528149837], [0.11632731874264224, 0.6875493862435358], [0.48464171270817125, 0.9887455834156222], [0.8854345413427909, 0.49530775678797445], [0.008197359860088071, 0.7597498106862539], [0.3586531582538418, 0.9628339543557296], [0.22764721330724302, 0.1405341173516369], [0.7282174787391045, 0.5266952761039118], [0.7762217629823028, 0.9682518311055232], [0.7260866242517884, 0.28203938167045295], [0.929153272673218, 0.5400713424363478], [0.8337855778393145, 0.6795875111461626], [0.8811577685468234, 0.9676050547116376], [0.16686808006119924, 0.02425116871348032], [0.9537611574141022, 0.46499078093429846], [0.3557643599271686, 0.18176818250012716], [0.5539694427896724, 0.9702486452125939], [0.8046574117521608, 0.1033350953965424], [0.8545637343389454, 0.28552444817017697], [0.6649160184185691, 0.5807541580054544], [0.8656474156668079, 0.010757553818076637], [0.7449843057340946, 0.11467989496079967], [0.022313719511357855, 0.4631106389943791], [0.6846131837001713, 0.5974023844003244], [0.08713516099208285, 0.03160862084948668], [0.07726363230708022, 0.43777601426565294], [0.6038222456380775, 0.7950979710584937], [0.5162786005582756, 0.5909702087113057], [0.6073608646745878, 0.6152722269956976], [0.7520048711147257, 0.18293980280385702], [0.8407469579182841, 0.3107740017846162], [0.7314393477783951, 0.0033205006476206833], [0.35927909474977293, 0.14011525238291211], [0.7660767539642495, 0.6850158748918177], [0.43992881261355854, 0.5276038891658873], [0.8106500220239526, 0.23103846501309344], [0.5851638380608137, 0.7897930722253051], [0.6311152524965394, 0.036093413779834216], [0.10508669958387984, 0.7511807817455597], [0.055370524456371806, 0.3943681075719089], [0.4096713516358751, 0.7868392811097878], [0.674225751740304, 0.2992275731499737], [0.9328139326950637, 0.3584841104098604], [0.32067802910475596, 0.04962728120086746], [0.39925061680451845, 0.5432935549737629], [0.9602342510141207, 0.0603765122472435], [0.5868120557355941, 0.4106064978457815], [0.29643089285171664, 0.37789664517154564]], \"data02\": [[0.5757281402347376, 0.12476822907952634], [0.8843691160959513, 0.5871710607925391], [0.6073338063051109, 0.18808934201908567], [0.10872697639641205, 0.9181416618801573], [0.43324928639328397, 0.3241244143937009], [0.9817042936056718, 0.5299763370829639], [0.38930607099283787, 0.6767587233228362], [0.8936662582765941, 0.03160166842793044], [0.46701333481729934, 0.3468895684080464], [0.5527106830801924, 0.12559908590827484], [0.2527553536672792, 0.7782016784466976], [0.5438063282122486, 0.33583124597023173], [0.7657595580414235, 0.8892752434091579], [0.48043927289390154, 0.6012612039899949], [0.5699371291323116, 0.6264430866819386], [0.6848164641409118, 0.3206319237601867], [0.2461711098756535, 0.4582381862704157], [0.36784406388138524, 0.6925870953637762], [0.15579851407905432, 0.03150131689977309], [0.8083211690028597, 0.29458313536486125], [0.23183111835471448, 0.6195056379907635], [0.303655801185987, 0.4933598706350324], [0.9910972375282245, 0.9987048732731857], [0.14915029471809094, 0.0530079750044139], [0.4843605314487036, 0.4152171128240163], [0.4215310154895132, 0.5724189902269761], [0.15969165105768113, 0.57135838256627], [0.4937904860816752, 0.03441955059008728], [0.8975134980182307, 0.23701690365976258], [0.8979676261133467, 0.4947689439974302], [0.4825111119164712, 0.8545792988266192], [0.34409472949080666, 0.872110157188082], [0.39479662597166665, 0.46469155745581214], [0.7987317241678275, 0.915429837838087], [0.2720848597448532, 0.6553682104630828], [0.2709611937895329, 0.28312882217308366], [0.43111187150711927, 0.627165161424004], [0.8962927410528921, 0.17286059137962873], [0.9942441292862435, 0.8084999232862351], [0.1869839365828223, 0.6311123046922498], [0.07478106312407284, 0.49605155971801995], [0.6894060829196746, 0.27283184947575523], [0.555454980856394, 0.8818082263512534], [0.919365377076473, 0.3325772558740304], [0.7707758279180693, 0.480229819316236], [0.05969728892868087, 0.118345293748645], [0.15284341350639907, 0.6848678380367137], [0.8551066979305005, 0.7616920746022339], [0.33693711927771497, 0.6687404568758009], [0.9125609804673384, 0.5529048904422192], [0.3359411606962315, 0.5288841483213786], [0.05052155732618979, 0.05950877774022745], [0.3524501217458965, 0.6196115432650898], [0.5305200243177363, 0.5319362876531476], [0.0022283663190201253, 0.2949436575951567], [0.7561711306231926, 0.7716035833712218], [0.7596971709722758, 0.9567732701078838], [0.06036500918266641, 0.5212764005429432], [0.9978682284162491, 0.10427503568378738], [0.6447678008341017, 0.9584601577655691], [0.02908904447419336, 0.39436012238564455], [0.3908872619618189, 0.45558625341149606], [0.6371304199691227, 0.5457447525344098], [0.13623691029323082, 0.5411728211394115], [0.5247676913785825, 0.13041952500466947], [0.8228473554343857, 0.5789756244310207], [0.8978245005252667, 0.677052336093371], [0.9143341136688948, 0.5747770897372464], [0.1571574619606657, 0.31502459111874415], [0.9552648182717801, 0.02708926530013156], [0.8444683509798371, 0.66793006669549], [0.10686738903399673, 0.4267213588433475], [0.5404954485483183, 0.8877805278368643], [0.1886686246693794, 0.9044014501384943], [0.33292859334492797, 0.6425655976460094], [0.8606635464289291, 0.22914407481263643], [0.978478164099745, 0.5541607766878734], [0.9757186728330539, 0.7292536531813154], [0.8326308545742289, 0.0444887678171112], [0.971713257448772, 0.12501290934513365], [0.9381042762597804, 0.11292392896662329], [0.6433334531281611, 0.3259190440975165], [0.19613315966438083, 0.6479199585954877], [0.5474074817305751, 0.409367251707921], [0.2113836295185879, 0.8123024933018266], [0.7095353228319472, 0.5438664471374718], [0.8467155618350992, 0.949149292567522], [0.8086112455708788, 0.37154756726534344], [0.2639808583307288, 0.4604507768885915], [0.9290934853411718, 0.8680728640837589], [0.9366520344626141, 0.3957927471674437], [0.8170074265433214, 0.9146206948357536], [0.19024385562183133, 0.4800984676174723], [0.8942492972672454, 0.4938249426140682], [0.007634068058193111, 0.7625756625276451], [0.33773774499334097, 0.4955250015526702], [0.8465187599128684, 0.534358654268412], [0.054443812525850954, 0.6173514064525885], [0.9401998454538012, 0.6667357629901194], [0.23961529090403366, 0.1359509251838089]], \"data03\": [[0.3203272351145975, 0.8335364155528318], [0.4203350338679286, 0.584762241149771], [0.8458639798311988, 0.8906032495198369], [0.36569269771874735, 0.7002245473157138], [0.514582647824789, 0.7063982140256597], [0.11968726090175474, 0.8514622057853115], [0.7043589198108782, 0.9298449970171021], [0.5586671887234631, 0.1881783329751664], [0.9406066290705133, 0.4052662780095634], [0.6143236276228166, 0.1745277887947705], [0.06452034116681016, 0.875698339147037], [0.37276098239427746, 0.2589212854809264], [0.3204813312273356, 0.04567472511498627], [0.05020939064342467, 0.5804152405709331], [0.8012843738835582, 0.5374880065802101], [0.7579810470114751, 0.5887530932875923], [0.8481572354792598, 0.8952291189669157], [0.9573301053022888, 0.8289680456937573], [0.29711097235301387, 0.009928056952544395], [0.7483782669117083, 0.6803795065816102], [0.4945666538414232, 0.3399336098755622], [0.6419954464424609, 0.7847696520022439], [0.7367662982915205, 0.015490719373013495], [0.13127105045556187, 0.5573011991022919], [0.307968509009243, 0.34319959349464535], [0.5761490557538225, 0.8927291491488131], [0.9292637911230446, 0.050683138825919016], [0.03510424677861601, 0.9787584387584772], [0.5801625021309482, 0.07911879358954843], [0.2206530621480013, 0.3860621997210878], [0.8784488972946168, 0.2913209752002516], [0.4350288213063911, 0.8869227572328181], [0.7244890661037738, 0.8486794347983503], [0.2754568487812361, 0.11272262719044424], [0.22663629898638227, 0.006918410814040654], [0.3019002650811834, 0.7232582487507958], [0.9802884870454528, 0.4414305826853173], [0.013019642582447366, 0.18427707554141037], [0.6576176575325052, 0.22968709290782607], [0.3141147250126384, 0.30308143562393086], [0.615022865061668, 0.06117413116278059], [0.565582163682745, 0.7415381817438464], [0.7909966769777126, 0.4926417517703615], [0.03978624278722798, 0.4775837200471805], [0.7205810535078038, 0.5655864632189355], [0.3676356739169201, 0.9431963940704721], [0.06311427632636823, 0.5552848231777624], [0.4835962769067277, 0.6639844394065039], [0.8390798580246669, 0.1384908280751619], [0.8999449978946574, 0.9793428274291679], [0.7811779061898314, 0.6694009215100615], [0.40269064412144306, 0.1688138073016029], [0.515259873315751, 0.7238613317416049], [0.051622142718159125, 0.922244924805143], [0.44910041094040176, 0.16428991157699135], [0.31195523017861504, 0.8704344689188473], [0.7070117141374869, 0.8788560723224652], [0.5136132681964638, 0.7263341581356326], [0.4313706935483065, 0.3246072413652301], [0.8358614104075586, 0.7464850338571996], [0.14611984546966528, 0.16890054843123659], [0.5004822100777583, 0.39824201214572674], [0.2622808611618471, 0.563260883592359], [0.3528956193470776, 0.19972110770186635], [0.8961098195690627, 0.742095307188639], [0.13829663560943228, 0.27610830585300983], [0.9614782010396442, 0.291723217937233], [0.20261628150031974, 0.06845897751753893], [0.5088636239566634, 0.899973641948937], [0.865146338911064, 0.7216209946215982], [0.013864929249599478, 0.48541237671852944], [0.5728845206806737, 0.5369642525095514], [0.8856409514308515, 0.8476710955335297], [0.5640774453007065, 0.9895982412452545], [0.28002569414603706, 0.43603926929229564], [0.3278847427815923, 0.9222573840671883], [0.306382072092913, 0.14702286688735444], [0.19800098348630712, 0.31718785122455895], [0.9074381004975539, 0.382700475111002], [0.6495242677368901, 0.07254363660559549], [0.790321771006596, 0.30508814255495253], [0.666047965281103, 0.8714281328927928], [0.04776343421843021, 0.007692553237056421], [0.8759782282749793, 0.6544502243372848], [0.7954157527270818, 0.5514512409979686], [0.39362160623603093, 0.1351856191958284], [0.6491887538883317, 0.459380653884503], [0.06312917874558444, 0.5172215795284358], [0.20840523955844892, 0.1061297456214979], [0.9212389782784505, 0.2155546500092128], [0.9687362124913973, 0.3585982712710848], [0.7047796484209112, 0.04828303955514768], [0.21219312391541845, 0.09468780706546076], [0.32748619966584636, 0.06505554809978875], [0.1923153446344461, 0.6473414127553371], [0.43247922523364823, 0.7586608358097756], [0.9759821325352058, 0.8209243300614341], [0.14096634550918907, 0.6078684398587265], [0.0007222708446895654, 0.11757361554347867], [0.6635772961552637, 0.9874937063615683]], \"data01\": [[0.9337896071508014, 0.26210487107557134], [0.8351585335742979, 0.5301133016445017], [0.3673902082932986, 0.8584560409380971], [0.34725246779809205, 0.1829624078714842], [0.7886932247826598, 0.8644865973032086], [0.4440580745862007, 0.8984811696374114], [0.0556294749848435, 0.6250967064409098], [0.3271288050721922, 0.8482029111071808], [0.7640337882344845, 0.8542562524350681], [0.4209935103323551, 0.8112651106877273], [0.7427017868043315, 0.7092822413465556], [0.9648585640913647, 0.352689847006323], [0.7004166324843947, 0.46150329910374777], [0.3328931759476179, 0.0823400774292401], [0.7713894461060906, 0.39810122807227566], [0.67004561859263, 0.8223547875907317], [0.4978749392031838, 0.7817255212732233], [0.782907432220163, 0.24655043090304374], [0.4498514959337665, 0.43333604741219933], [0.6832836668091845, 0.011719239883924648], [0.027293294429139192, 0.039422800253637424], [0.6823274047513601, 0.2509069937274274], [0.006891408250362496, 0.7727781662753845], [0.014293395719481627, 0.7190528371266814], [0.21605330492782526, 0.09838533011594686], [0.7533639880865395, 0.012406388943960178], [0.05461015075829612, 0.46626599955489134], [0.7146447733528821, 0.7706113871630651], [0.2595749779142966, 0.7825260697442016], [0.6745381757431145, 0.20316618514663032], [0.982099069568953, 0.9100843563836049], [0.4133607728897334, 0.1547614923144307], [0.28805648260311456, 0.36515559016704735], [0.26356953265468164, 0.4282693042704998], [0.9388618440704766, 0.33105601503412274], [0.0029162112554420583, 0.3264326397669771], [0.8593812286893946, 0.3103658831443934], [0.4519623682802859, 0.0040882847845443715], [0.40781556329252566, 0.9005600782306642], [0.639425411794307, 0.0952900296454634], [0.5548007927131505, 0.08765781003361761], [0.37978080517027923, 0.5462540144109883], [0.7702113715966054, 0.34272740822367487], [0.5633988570181039, 0.9267468690420295], [0.6267682456988396, 0.67495262862907], [0.9770246190397904, 0.9404447767744459], [0.10850795865645069, 0.6590642106998655], [0.573519394636228, 0.08303538680528266], [0.1985601570031139, 0.4617266688731311], [0.3689458481010012, 0.5979611763732767], [0.09816499431899284, 0.8590848563728619], [0.7854227651304604, 0.4584359018973586], [0.4716496822096633, 0.8729352906587778], [0.4650544134556974, 0.422595699709889], [0.9052038650056381, 0.2965880531428532], [0.8120825259052143, 0.11285364123655262], [0.9403571650492082, 0.6860693263879939], [0.63592817515658, 0.37493433102400286], [0.7984938638086895, 0.007901762178482818], [0.8686207086495045, 0.5778510529393696], [0.018144694325693655, 0.3132543168929912], [0.6192431292345925, 0.3132388939183731], [0.7183065252294973, 0.10619854401501183], [0.9090996564565473, 0.16655593811919223], [0.6134956329060927, 0.9052526862673087], [0.5249254354384066, 0.36349953365941345], [0.026096540722630013, 0.31501732674967486], [0.6461233160251367, 0.13195097142448597], [0.6106530732727414, 0.4315702441121203], [0.4836920528410096, 0.9140973888407937], [0.9106456031211833, 0.0842870601237019], [0.6644383401541888, 0.6533080493904203], [0.6503710212604545, 0.7561640824697892], [0.7243497027619566, 0.24017708737403398], [0.13582427381408024, 0.19003435227318233], [0.9213243561824673, 0.1498281035456397], [0.9304062315332647, 0.741816496635188], [0.3122438152895588, 0.3078838024784528], [0.4793345078460184, 0.5317666354287778], [0.5568539330050538, 0.2953423154570297], [0.06519593979517235, 0.6415473019210939], [0.3894476731410479, 0.32360291703446686], [0.5335442990981843, 0.9709040106764336], [0.7982222112686944, 0.9565480376702594], [0.49564261995579617, 0.7883959987966798], [0.7813193296381757, 0.27414367360434755], [0.3358464154926011, 0.09551171745684373], [0.8675785718727186, 0.41075312704753286], [0.8457361396420353, 0.008828999792782843], [0.34981063159440673, 0.38516513550330744], [0.12204686820349964, 0.44621057220271887], [0.6882374234689828, 0.8596091372132191], [0.6144071646482189, 0.030344647148762727], [0.5152773923208307, 0.19325968170302688], [0.7209742279562512, 0.6316887135073014], [0.964392536579791, 0.7103663521811615], [0.4885163059730062, 0.4354552241790316], [0.977595760053659, 0.46582174451005043], [0.7145474439075008, 0.7294681726999905], [0.9429986923599958, 0.1275189841784946]]}, \"id\": \"el100754535888336\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 5,
       "text": [
        "<IPython.core.display.HTML at 0x1101c5d10>"
       ]
      }
     ],
     "prompt_number": 5
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## Markers and Lines in case of Line2D instances\n",
      "A Line2d instance can have both a line, as well as markers at each vertex. In D3 these are two distinct things. The interactive legend can handle both as demonstrated by the example below. See the code and comments there on how this is achieved for details. \n"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "N_paths = 5\n",
      "N_steps = 100\n",
      "\n",
      "x = np.linspace(0, 10, 100)\n",
      "y = 0.1 * (np.random.random((N_paths, N_steps)) - 0.5)\n",
      "y = y.cumsum(1)\n",
      "\n",
      "\n",
      "fig = plt.figure()\n",
      "ax1 = fig.add_subplot(2,1,1)\n",
      "ax2 = fig.add_subplot(2,1,2)\n",
      "\n",
      "labels = [\"a\", \"b\", \"c\", \"d\", \"e\"]\n",
      "l1 = ax1.plot(x, y.T, marker='x',lw=2, alpha=0.1)\n",
      "s1 = ax2.plot(x, y.T, 'o', ms=8, alpha=0.1)\n",
      "    \n",
      "plugins.connect(fig, plugins.InteractiveLegendPlugin(zip(l1, s1), labels))\n",
      "mpld3.display()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "    .legend-box {\n",
        "      cursor: pointer;\n",
        "    }\n",
        "    \n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el1007545349550245890167983\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "       mpld3.draw_figure(\"fig_el1007545349550245890167983\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.80000000000000004, 0.40000000000000013], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565425488\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565426064\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565425552\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565431120\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565431504\"}], \"markers\": [{\"edgecolor\": \"#0000FF\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565425488pts\"}, {\"edgecolor\": \"#007F00\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565426064pts\"}, {\"edgecolor\": \"#FF0000\", \"facecolor\": \"#FF0000\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565425552pts\"}, {\"edgecolor\": \"#00BFBF\", \"facecolor\": \"#00BFBF\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565431120pts\"}, {\"edgecolor\": \"#BF00BF\", \"facecolor\": \"#BF00BF\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565431504pts\"}], \"id\": \"el100754534954512\", \"ydomain\": [-0.80000000000000004, 0.40000000000000013], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.54772727272727284, 0.77500000000000002, 0.35227272727272718]}, {\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.80000000000000004, 0.40000000000000013], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754535761040pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565450320pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF0000\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565454992pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#00BFBF\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565455376pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#BF00BF\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565455760pts\"}], \"id\": \"el100754535593936\", \"ydomain\": [-0.80000000000000004, 0.40000000000000013], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.12500000000000011, 0.77500000000000002, 0.35227272727272724]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754565425488\", \"el100754565425488pts\", \"el100754535761040\", \"el100754535761040pts\"], [\"el100754565426064\", \"el100754565426064pts\", \"el100754565450320\", \"el100754565450320pts\"], [\"el100754565425552\", \"el100754565425552pts\", \"el100754565454992\", \"el100754565454992pts\"], [\"el100754565431120\", \"el100754565431120pts\", \"el100754565455376\", \"el100754565455376pts\"], [\"el100754565431504\", \"el100754565431504pts\", \"el100754565455760\", \"el100754565455760pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, 0.04498483498573447, 0.013415618391208162, -0.03781283217083797, 0.01657867085915853, 0.027984465952350046], [0.10101010101010101, 0.08286561291620814, -0.006274344283376676, 0.0031115815359028867, 0.004106233645652713, 0.046251320740037696], [0.20202020202020202, 0.08462889086654593, -0.004405014418542352, 0.001905603098745802, -0.016747245677078682, 0.06231844133695727], [0.30303030303030304, 0.08046052325945521, -0.03201490298867826, -0.024267780749074607, -0.06138548186365861, 0.04130908352670372], [0.40404040404040403, 0.10615569227277122, -0.07886951519422267, -0.027637367370713973, -0.05139889456490856, 0.053621742749842244], [0.5050505050505051, 0.11798505922107959, -0.10417102386502092, -0.03283506351490713, -0.006619407802635029, 0.05294795084609232], [0.6060606060606061, 0.06821359668102932, -0.08402746855074125, -0.07246256237239958, -0.021225752877420484, 0.05428575784769638], [0.7070707070707071, 0.0923107938707093, -0.10382580175494008, -0.0902537214009236, -0.06553100579912144, 0.029371859895068166], [0.8080808080808081, 0.09192395930735557, -0.13865080939769636, -0.05991940861621911, -0.045662742445048615, 0.04726370015719486], [0.9090909090909091, 0.046577756156865796, -0.11673585567064781, -0.045393980377755376, -0.0449451358975531, 0.00793578861701675], [1.0101010101010102, 0.010567703868283887, -0.13197063784655347, -0.07426857387081359, -0.04001845903467363, -0.04053957290109891], [1.1111111111111112, 0.03888920299008304, -0.13656545424143435, -0.07989320477804913, -0.06500173737133319, -0.04305091953415979], [1.2121212121212122, 0.039257131976274964, -0.11445337823431564, -0.06486201627044666, -0.04643089255146062, -0.07346638711151368], [1.3131313131313131, 0.023048023825837184, -0.08703823133018172, -0.05956446717917627, -0.08927903838226087, -0.10916651634841942], [1.4141414141414141, -0.0012061442770730617, -0.13634752168349967, -0.042561023772302045, -0.08615410513612579, -0.1203224035290022], [1.5151515151515151, 0.026046038150575004, -0.1413344791503628, -0.07493090166331981, -0.08283846335932804, -0.11267565905632522], [1.6161616161616161, -0.006773674070703062, -0.10834038488678555, -0.10639886037300142, -0.12664729970906213, -0.152611574464107], [1.7171717171717171, -0.005329550192031585, -0.058943644665066325, -0.05906361041708699, -0.1201815727101598, -0.11714858556747501], [1.8181818181818181, 0.015248468567244756, -0.009676402680399404, -0.06208833354684963, -0.083668996654777, -0.1110747695763028], [1.9191919191919191, 0.0392900017050413, -0.027292617496800748, -0.0645279136765911, -0.05585490884520371, -0.09573758143868541], [2.0202020202020203, 0.03508361522101364, -0.014657819054050886, -0.08140078336622389, -0.08954763752822646, -0.04774340977195715], [2.121212121212121, -0.009793848727344137, 0.006715919700306166, -0.1181420028888292, -0.10497240915742552, -0.000316314333598966], [2.2222222222222223, -0.05829123190113897, 0.009615519411351975, -0.16364937821598463, -0.08009885334100245, -0.009389110891550733], [2.323232323232323, -0.048567801340425, 0.008023181379484106, -0.2089960852210617, -0.09342597775831211, -0.02594601503086804], [2.4242424242424243, -0.0411629538985145, -0.03959661780732253, -0.2522628135333969, -0.06253207525929286, -0.0288252821940128], [2.525252525252525, -0.0319896451694002, -0.015672817885402996, -0.25701816229286734, -0.10100536791246176, -0.06292819333618847], [2.6262626262626263, -0.023144420802859625, -0.049432737001133736, -0.23571542712707289, -0.07234897292186836, -0.08770813304637066], [2.727272727272727, -0.0016063020433686147, -0.022667827468076534, -0.2436597814733106, -0.10172005112910129, -0.0826145267626292], [2.8282828282828283, -0.03498600039896034, -0.047277700982779405, -0.22051231346130493, -0.1334514719973059, -0.09868654545912417], [2.929292929292929, -0.027631163162098796, 0.00010114326312218175, -0.21677647878655823, -0.0885034390809713, -0.14316615357079931], [3.0303030303030303, -0.022691034574502493, 0.03949112333481302, -0.2609789778776063, -0.059247136641237444, -0.10968697975252159], [3.131313131313131, -0.045589635481547756, 0.08688804981919145, -0.23717322380123138, -0.06205044111391133, -0.07125351470295839], [3.2323232323232323, -0.09100262035831552, 0.045461243041897775, -0.2563545754900074, -0.014746648252733495, -0.04045017046045862], [3.3333333333333335, -0.09131179572940087, 0.06621781353211587, -0.2510648429676208, 0.017424544440266587, -0.0764769344674974], [3.4343434343434343, -0.0655569651950515, 0.09903467693810117, -0.2737536292833842, 0.031817345619437144, -0.07032020776132356], [3.5353535353535355, -0.075741018147332, 0.13238738066791694, -0.3112869010761756, 0.0290765754294128, -0.11146214171655036], [3.6363636363636362, -0.10065928917837022, 0.11713454525359811, -0.3554614100965477, -0.019361947766785837, -0.07798964515685208], [3.7373737373737375, -0.1139888980206693, 0.09994506619621218, -0.3945788020964185, -0.0160117075936806, -0.06968024452708267], [3.8383838383838382, -0.14185650414165993, 0.1289649198948812, -0.38428709365205804, -0.061657471141079084, -0.057925669482712376], [3.9393939393939394, -0.15491775884545064, 0.09225702490911633, -0.4332547611632511, -0.028559954876581688, -0.06055435204955968], [4.040404040404041, -0.19066195959903512, 0.0719633552396089, -0.43024802262100165, -0.06553763355914703, -0.0873208957223432], [4.141414141414141, -0.20636576331734094, 0.07570681090100057, -0.4734309726744469, -0.0564633212286139, -0.05171437651498327], [4.242424242424242, -0.17443195862362462, 0.11898812371784478, -0.4630095226276546, -0.09314352856565987, -0.04933911889718013], [4.343434343434343, -0.20207407922265105, 0.08425620167738981, -0.42374474299443343, -0.117717863698525, -0.08297881317268782], [4.444444444444445, -0.22663627540695322, 0.050192096299283465, -0.39866410260425605, -0.09833102087078148, -0.12194456819126884], [4.545454545454545, -0.20795815729038744, 0.03708175969501183, -0.4345665829510054, -0.10974008583123114, -0.11751624210313422], [4.646464646464646, -0.24649859088715426, 0.0550212509569082, -0.46708570311146397, -0.06298200630515814, -0.15444491915135697], [4.747474747474747, -0.2789625116937272, 0.0071005049235357345, -0.5156025672440795, -0.04063427246792904, -0.1531474809276652], [4.848484848484849, -0.26773803447457456, 0.02855929830891897, -0.5363676970977338, -0.03695433257613451, -0.13593846799044243], [4.94949494949495, -0.22858691195641528, 0.04210819175001669, -0.5280405734285788, -0.06787083123012931, -0.17111525866676655], [5.05050505050505, -0.21887502291682231, 0.08931583415573938, -0.5417933704286835, -0.06069811514670498, -0.20618435543112895], [5.151515151515151, -0.1851547624073411, 0.09904247868561548, -0.5885028543114745, -0.07959265104769056, -0.16573554044493258], [5.252525252525253, -0.22813584321010302, 0.10936568095083063, -0.6020993568895565, -0.0840965413344567, -0.1728951290885727], [5.353535353535354, -0.18158660830663417, 0.11972267188679823, -0.5739609244925544, -0.10433946660713582, -0.13448815130454442], [5.454545454545454, -0.21736636765771478, 0.1429755823388231, -0.5381561230199845, -0.0816900589866927, -0.13717714012148294], [5.555555555555555, -0.17414818403972493, 0.09830219614168353, -0.5070388720413751, -0.04542384981535693, -0.16165304805090513], [5.656565656565657, -0.19255350888826012, 0.05145603261125429, -0.4833008409748218, -0.006280067919562836, -0.17422956132782622], [5.757575757575758, -0.23001986248134, 0.08169822428506335, -0.4930994386015815, -0.04506629107548034, -0.20006757589816732], [5.858585858585858, -0.2159772385418173, 0.08111518640929409, -0.46839077795509126, -0.03790444494988402, -0.23525887644614335], [5.959595959595959, -0.21212969846515203, 0.1258850649559528, -0.45224993599059693, -0.06516684387426336, -0.24213500439048602], [6.0606060606060606, -0.2544314976293923, 0.14863945602549436, -0.46226467812472755, -0.04549016307016583, -0.29196158023144875], [6.161616161616162, -0.27611349221318904, 0.13348104219972462, -0.43714627849616366, -0.038490696027065396, -0.2431412616361868], [6.262626262626262, -0.30017405928576396, 0.17452641108411615, -0.4648603128796377, -0.07762432741112277, -0.2623795393613294], [6.363636363636363, -0.3476851367204864, 0.17798228520502418, -0.48507229600279234, -0.06036132847024377, -0.26776407932635155], [6.4646464646464645, -0.32978112423718553, 0.1998127104502736, -0.4989570978604723, -0.11013490814526772, -0.2755719835896571], [6.565656565656566, -0.3403953433856838, 0.18061969799158528, -0.4846875662593255, -0.12291656463123293, -0.2485169289862538], [6.666666666666667, -0.3090739578652803, 0.18248955484335214, -0.474243300484984, -0.10423492028367579, -0.26399692113678086], [6.767676767676767, -0.26494770878007756, 0.1967191090619889, -0.46862136143999195, -0.11870698754135547, -0.23363797007696976], [6.8686868686868685, -0.2737400408180953, 0.16671292988253267, -0.4539060278458058, -0.1337327766608799, -0.25354649210211655], [6.96969696969697, -0.3236225406118457, 0.17654184010506976, -0.4404708155468108, -0.12104920247211136, -0.27004944375384454], [7.070707070707071, -0.3621753299256256, 0.1495526791982828, -0.42085125387288297, -0.16397346528762083, -0.29019404922127817], [7.171717171717171, -0.3515385086462672, 0.14623294980898427, -0.4224613266164565, -0.15505090017586637, -0.27702467807866643], [7.2727272727272725, -0.33382201288838087, 0.13872880742492188, -0.4239473124488232, -0.19246485964202104, -0.2657011493883885], [7.373737373737374, -0.3626930421161608, 0.16931578709766448, -0.4684721886767, -0.1696351965505163, -0.25859002590753677], [7.474747474747475, -0.3772193647023383, 0.20232436783789534, -0.4914108800812689, -0.15972286714197376, -0.23359713018414735], [7.575757575757575, -0.3485530627713764, 0.20097665872256096, -0.4505328100378987, -0.1992218927304731, -0.27225367244364734], [7.6767676767676765, -0.3613234331228465, 0.20397828339418442, -0.46804999528839797, -0.15104111416677543, -0.26258357225732], [7.777777777777778, -0.3417715622686577, 0.21227507665569892, -0.47968219438752363, -0.19356248009108726, -0.24914191434636135], [7.878787878787879, -0.3147069302854169, 0.1906301213674219, -0.44011101216249515, -0.19701607772458232, -0.25363177934032893], [7.979797979797979, -0.34125233642356195, 0.1558764134882634, -0.44253213566421645, -0.1690551082434381, -0.21657613349036822], [8.080808080808081, -0.37488135440507475, 0.11371565028624536, -0.47538850394658316, -0.12225521888776139, -0.22920613094008552], [8.181818181818182, -0.32749502076725023, 0.11326716411889041, -0.4638347131330166, -0.13075245331218008, -0.19807434251669306], [8.282828282828282, -0.3203988237134759, 0.14348476090098108, -0.47301844679276966, -0.14369851410118759, -0.17601957119603034], [8.383838383838384, -0.3296773993286675, 0.17538246902245777, -0.4242367562220675, -0.13365406621106726, -0.16662515411390214], [8.484848484848484, -0.32490877872691626, 0.22346837574561645, -0.4626804621475635, -0.14400866597201767, -0.1522362409790185], [8.585858585858587, -0.36179123100922794, 0.2518429376467052, -0.49319300170465835, -0.17452189797579465, -0.18563693321906266], [8.686868686868687, -0.36765236526999784, 0.2806425977677555, -0.5418389025195158, -0.17861303609395962, -0.14873258940349376], [8.787878787878787, -0.4081372568468698, 0.2880170516776693, -0.4934208397796425, -0.13207076505586787, -0.1122759311057569], [8.88888888888889, -0.3714302741193061, 0.28556940173389306, -0.48318622356162305, -0.09766686918298058, -0.15956287000991887], [8.98989898989899, -0.38112171890981356, 0.30266010897036355, -0.47234464440562446, -0.10951889181461122, -0.1146336329728965], [9.09090909090909, -0.4124400572611488, 0.31231643023075345, -0.43755698117046804, -0.10960028722263768, -0.08250564111077002], [9.191919191919192, -0.4594259962760907, 0.2704264762283102, -0.4571920906681531, -0.10291917646168319, -0.04004167683185514], [9.292929292929292, -0.4906091038701892, 0.2649155485290059, -0.4541111641669208, -0.08749106970030578, -0.04545586526836549], [9.393939393939394, -0.5220614661460425, 0.2155362266473772, -0.43168253981988763, -0.111310028285351, -0.0009102220987921503], [9.494949494949495, -0.5690730590517707, 0.23535537171199689, -0.40567501993782773, -0.11764441333020047, -0.014941932801744523], [9.595959595959595, -0.5765725666045367, 0.2534763800277013, -0.36164470921385944, -0.13951797614998335, 0.005196359938284163], [9.696969696969697, -0.5956849961001935, 0.20783039984739032, -0.3612987664781318, -0.14121301117163268, 0.025549945602495447], [9.797979797979798, -0.61676366066584, 0.24953729442731554, -0.33944788977692353, -0.1300733178847046, 0.05452637739529556], [9.8989898989899, -0.651615757829254, 0.24478597800176843, -0.355539392511711, -0.15826027265960896, 0.09134024771594504], [10.0, -0.6270237940231783, 0.22807847208384807, -0.36289733906548133, -0.13135612688964665, 0.06491193093623532]]}, \"id\": \"el100754534955024\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "         \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "         mpld3.draw_figure(\"fig_el1007545349550245890167983\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.80000000000000004, 0.40000000000000013], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565425488\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565426064\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565425552\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565431120\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565431504\"}], \"markers\": [{\"edgecolor\": \"#0000FF\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565425488pts\"}, {\"edgecolor\": \"#007F00\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565426064pts\"}, {\"edgecolor\": \"#FF0000\", \"facecolor\": \"#FF0000\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565425552pts\"}, {\"edgecolor\": \"#00BFBF\", \"facecolor\": \"#00BFBF\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565431120pts\"}, {\"edgecolor\": \"#BF00BF\", \"facecolor\": \"#BF00BF\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565431504pts\"}], \"id\": \"el100754534954512\", \"ydomain\": [-0.80000000000000004, 0.40000000000000013], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.54772727272727284, 0.77500000000000002, 0.35227272727272718]}, {\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.80000000000000004, 0.40000000000000013], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754535761040pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565450320pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF0000\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565454992pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#00BFBF\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565455376pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#BF00BF\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565455760pts\"}], \"id\": \"el100754535593936\", \"ydomain\": [-0.80000000000000004, 0.40000000000000013], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.12500000000000011, 0.77500000000000002, 0.35227272727272724]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754565425488\", \"el100754565425488pts\", \"el100754535761040\", \"el100754535761040pts\"], [\"el100754565426064\", \"el100754565426064pts\", \"el100754565450320\", \"el100754565450320pts\"], [\"el100754565425552\", \"el100754565425552pts\", \"el100754565454992\", \"el100754565454992pts\"], [\"el100754565431120\", \"el100754565431120pts\", \"el100754565455376\", \"el100754565455376pts\"], [\"el100754565431504\", \"el100754565431504pts\", \"el100754565455760\", \"el100754565455760pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, 0.04498483498573447, 0.013415618391208162, -0.03781283217083797, 0.01657867085915853, 0.027984465952350046], [0.10101010101010101, 0.08286561291620814, -0.006274344283376676, 0.0031115815359028867, 0.004106233645652713, 0.046251320740037696], [0.20202020202020202, 0.08462889086654593, -0.004405014418542352, 0.001905603098745802, -0.016747245677078682, 0.06231844133695727], [0.30303030303030304, 0.08046052325945521, -0.03201490298867826, -0.024267780749074607, -0.06138548186365861, 0.04130908352670372], [0.40404040404040403, 0.10615569227277122, -0.07886951519422267, -0.027637367370713973, -0.05139889456490856, 0.053621742749842244], [0.5050505050505051, 0.11798505922107959, -0.10417102386502092, -0.03283506351490713, -0.006619407802635029, 0.05294795084609232], [0.6060606060606061, 0.06821359668102932, -0.08402746855074125, -0.07246256237239958, -0.021225752877420484, 0.05428575784769638], [0.7070707070707071, 0.0923107938707093, -0.10382580175494008, -0.0902537214009236, -0.06553100579912144, 0.029371859895068166], [0.8080808080808081, 0.09192395930735557, -0.13865080939769636, -0.05991940861621911, -0.045662742445048615, 0.04726370015719486], [0.9090909090909091, 0.046577756156865796, -0.11673585567064781, -0.045393980377755376, -0.0449451358975531, 0.00793578861701675], [1.0101010101010102, 0.010567703868283887, -0.13197063784655347, -0.07426857387081359, -0.04001845903467363, -0.04053957290109891], [1.1111111111111112, 0.03888920299008304, -0.13656545424143435, -0.07989320477804913, -0.06500173737133319, -0.04305091953415979], [1.2121212121212122, 0.039257131976274964, -0.11445337823431564, -0.06486201627044666, -0.04643089255146062, -0.07346638711151368], [1.3131313131313131, 0.023048023825837184, -0.08703823133018172, -0.05956446717917627, -0.08927903838226087, -0.10916651634841942], [1.4141414141414141, -0.0012061442770730617, -0.13634752168349967, -0.042561023772302045, -0.08615410513612579, -0.1203224035290022], [1.5151515151515151, 0.026046038150575004, -0.1413344791503628, -0.07493090166331981, -0.08283846335932804, -0.11267565905632522], [1.6161616161616161, -0.006773674070703062, -0.10834038488678555, -0.10639886037300142, -0.12664729970906213, -0.152611574464107], [1.7171717171717171, -0.005329550192031585, -0.058943644665066325, -0.05906361041708699, -0.1201815727101598, -0.11714858556747501], [1.8181818181818181, 0.015248468567244756, -0.009676402680399404, -0.06208833354684963, -0.083668996654777, -0.1110747695763028], [1.9191919191919191, 0.0392900017050413, -0.027292617496800748, -0.0645279136765911, -0.05585490884520371, -0.09573758143868541], [2.0202020202020203, 0.03508361522101364, -0.014657819054050886, -0.08140078336622389, -0.08954763752822646, -0.04774340977195715], [2.121212121212121, -0.009793848727344137, 0.006715919700306166, -0.1181420028888292, -0.10497240915742552, -0.000316314333598966], [2.2222222222222223, -0.05829123190113897, 0.009615519411351975, -0.16364937821598463, -0.08009885334100245, -0.009389110891550733], [2.323232323232323, -0.048567801340425, 0.008023181379484106, -0.2089960852210617, -0.09342597775831211, -0.02594601503086804], [2.4242424242424243, -0.0411629538985145, -0.03959661780732253, -0.2522628135333969, -0.06253207525929286, -0.0288252821940128], [2.525252525252525, -0.0319896451694002, -0.015672817885402996, -0.25701816229286734, -0.10100536791246176, -0.06292819333618847], [2.6262626262626263, -0.023144420802859625, -0.049432737001133736, -0.23571542712707289, -0.07234897292186836, -0.08770813304637066], [2.727272727272727, -0.0016063020433686147, -0.022667827468076534, -0.2436597814733106, -0.10172005112910129, -0.0826145267626292], [2.8282828282828283, -0.03498600039896034, -0.047277700982779405, -0.22051231346130493, -0.1334514719973059, -0.09868654545912417], [2.929292929292929, -0.027631163162098796, 0.00010114326312218175, -0.21677647878655823, -0.0885034390809713, -0.14316615357079931], [3.0303030303030303, -0.022691034574502493, 0.03949112333481302, -0.2609789778776063, -0.059247136641237444, -0.10968697975252159], [3.131313131313131, -0.045589635481547756, 0.08688804981919145, -0.23717322380123138, -0.06205044111391133, -0.07125351470295839], [3.2323232323232323, -0.09100262035831552, 0.045461243041897775, -0.2563545754900074, -0.014746648252733495, -0.04045017046045862], [3.3333333333333335, -0.09131179572940087, 0.06621781353211587, -0.2510648429676208, 0.017424544440266587, -0.0764769344674974], [3.4343434343434343, -0.0655569651950515, 0.09903467693810117, -0.2737536292833842, 0.031817345619437144, -0.07032020776132356], [3.5353535353535355, -0.075741018147332, 0.13238738066791694, -0.3112869010761756, 0.0290765754294128, -0.11146214171655036], [3.6363636363636362, -0.10065928917837022, 0.11713454525359811, -0.3554614100965477, -0.019361947766785837, -0.07798964515685208], [3.7373737373737375, -0.1139888980206693, 0.09994506619621218, -0.3945788020964185, -0.0160117075936806, -0.06968024452708267], [3.8383838383838382, -0.14185650414165993, 0.1289649198948812, -0.38428709365205804, -0.061657471141079084, -0.057925669482712376], [3.9393939393939394, -0.15491775884545064, 0.09225702490911633, -0.4332547611632511, -0.028559954876581688, -0.06055435204955968], [4.040404040404041, -0.19066195959903512, 0.0719633552396089, -0.43024802262100165, -0.06553763355914703, -0.0873208957223432], [4.141414141414141, -0.20636576331734094, 0.07570681090100057, -0.4734309726744469, -0.0564633212286139, -0.05171437651498327], [4.242424242424242, -0.17443195862362462, 0.11898812371784478, -0.4630095226276546, -0.09314352856565987, -0.04933911889718013], [4.343434343434343, -0.20207407922265105, 0.08425620167738981, -0.42374474299443343, -0.117717863698525, -0.08297881317268782], [4.444444444444445, -0.22663627540695322, 0.050192096299283465, -0.39866410260425605, -0.09833102087078148, -0.12194456819126884], [4.545454545454545, -0.20795815729038744, 0.03708175969501183, -0.4345665829510054, -0.10974008583123114, -0.11751624210313422], [4.646464646464646, -0.24649859088715426, 0.0550212509569082, -0.46708570311146397, -0.06298200630515814, -0.15444491915135697], [4.747474747474747, -0.2789625116937272, 0.0071005049235357345, -0.5156025672440795, -0.04063427246792904, -0.1531474809276652], [4.848484848484849, -0.26773803447457456, 0.02855929830891897, -0.5363676970977338, -0.03695433257613451, -0.13593846799044243], [4.94949494949495, -0.22858691195641528, 0.04210819175001669, -0.5280405734285788, -0.06787083123012931, -0.17111525866676655], [5.05050505050505, -0.21887502291682231, 0.08931583415573938, -0.5417933704286835, -0.06069811514670498, -0.20618435543112895], [5.151515151515151, -0.1851547624073411, 0.09904247868561548, -0.5885028543114745, -0.07959265104769056, -0.16573554044493258], [5.252525252525253, -0.22813584321010302, 0.10936568095083063, -0.6020993568895565, -0.0840965413344567, -0.1728951290885727], [5.353535353535354, -0.18158660830663417, 0.11972267188679823, -0.5739609244925544, -0.10433946660713582, -0.13448815130454442], [5.454545454545454, -0.21736636765771478, 0.1429755823388231, -0.5381561230199845, -0.0816900589866927, -0.13717714012148294], [5.555555555555555, -0.17414818403972493, 0.09830219614168353, -0.5070388720413751, -0.04542384981535693, -0.16165304805090513], [5.656565656565657, -0.19255350888826012, 0.05145603261125429, -0.4833008409748218, -0.006280067919562836, -0.17422956132782622], [5.757575757575758, -0.23001986248134, 0.08169822428506335, -0.4930994386015815, -0.04506629107548034, -0.20006757589816732], [5.858585858585858, -0.2159772385418173, 0.08111518640929409, -0.46839077795509126, -0.03790444494988402, -0.23525887644614335], [5.959595959595959, -0.21212969846515203, 0.1258850649559528, -0.45224993599059693, -0.06516684387426336, -0.24213500439048602], [6.0606060606060606, -0.2544314976293923, 0.14863945602549436, -0.46226467812472755, -0.04549016307016583, -0.29196158023144875], [6.161616161616162, -0.27611349221318904, 0.13348104219972462, -0.43714627849616366, -0.038490696027065396, -0.2431412616361868], [6.262626262626262, -0.30017405928576396, 0.17452641108411615, -0.4648603128796377, -0.07762432741112277, -0.2623795393613294], [6.363636363636363, -0.3476851367204864, 0.17798228520502418, -0.48507229600279234, -0.06036132847024377, -0.26776407932635155], [6.4646464646464645, -0.32978112423718553, 0.1998127104502736, -0.4989570978604723, -0.11013490814526772, -0.2755719835896571], [6.565656565656566, -0.3403953433856838, 0.18061969799158528, -0.4846875662593255, -0.12291656463123293, -0.2485169289862538], [6.666666666666667, -0.3090739578652803, 0.18248955484335214, -0.474243300484984, -0.10423492028367579, -0.26399692113678086], [6.767676767676767, -0.26494770878007756, 0.1967191090619889, -0.46862136143999195, -0.11870698754135547, -0.23363797007696976], [6.8686868686868685, -0.2737400408180953, 0.16671292988253267, -0.4539060278458058, -0.1337327766608799, -0.25354649210211655], [6.96969696969697, -0.3236225406118457, 0.17654184010506976, -0.4404708155468108, -0.12104920247211136, -0.27004944375384454], [7.070707070707071, -0.3621753299256256, 0.1495526791982828, -0.42085125387288297, -0.16397346528762083, -0.29019404922127817], [7.171717171717171, -0.3515385086462672, 0.14623294980898427, -0.4224613266164565, -0.15505090017586637, -0.27702467807866643], [7.2727272727272725, -0.33382201288838087, 0.13872880742492188, -0.4239473124488232, -0.19246485964202104, -0.2657011493883885], [7.373737373737374, -0.3626930421161608, 0.16931578709766448, -0.4684721886767, -0.1696351965505163, -0.25859002590753677], [7.474747474747475, -0.3772193647023383, 0.20232436783789534, -0.4914108800812689, -0.15972286714197376, -0.23359713018414735], [7.575757575757575, -0.3485530627713764, 0.20097665872256096, -0.4505328100378987, -0.1992218927304731, -0.27225367244364734], [7.6767676767676765, -0.3613234331228465, 0.20397828339418442, -0.46804999528839797, -0.15104111416677543, -0.26258357225732], [7.777777777777778, -0.3417715622686577, 0.21227507665569892, -0.47968219438752363, -0.19356248009108726, -0.24914191434636135], [7.878787878787879, -0.3147069302854169, 0.1906301213674219, -0.44011101216249515, -0.19701607772458232, -0.25363177934032893], [7.979797979797979, -0.34125233642356195, 0.1558764134882634, -0.44253213566421645, -0.1690551082434381, -0.21657613349036822], [8.080808080808081, -0.37488135440507475, 0.11371565028624536, -0.47538850394658316, -0.12225521888776139, -0.22920613094008552], [8.181818181818182, -0.32749502076725023, 0.11326716411889041, -0.4638347131330166, -0.13075245331218008, -0.19807434251669306], [8.282828282828282, -0.3203988237134759, 0.14348476090098108, -0.47301844679276966, -0.14369851410118759, -0.17601957119603034], [8.383838383838384, -0.3296773993286675, 0.17538246902245777, -0.4242367562220675, -0.13365406621106726, -0.16662515411390214], [8.484848484848484, -0.32490877872691626, 0.22346837574561645, -0.4626804621475635, -0.14400866597201767, -0.1522362409790185], [8.585858585858587, -0.36179123100922794, 0.2518429376467052, -0.49319300170465835, -0.17452189797579465, -0.18563693321906266], [8.686868686868687, -0.36765236526999784, 0.2806425977677555, -0.5418389025195158, -0.17861303609395962, -0.14873258940349376], [8.787878787878787, -0.4081372568468698, 0.2880170516776693, -0.4934208397796425, -0.13207076505586787, -0.1122759311057569], [8.88888888888889, -0.3714302741193061, 0.28556940173389306, -0.48318622356162305, -0.09766686918298058, -0.15956287000991887], [8.98989898989899, -0.38112171890981356, 0.30266010897036355, -0.47234464440562446, -0.10951889181461122, -0.1146336329728965], [9.09090909090909, -0.4124400572611488, 0.31231643023075345, -0.43755698117046804, -0.10960028722263768, -0.08250564111077002], [9.191919191919192, -0.4594259962760907, 0.2704264762283102, -0.4571920906681531, -0.10291917646168319, -0.04004167683185514], [9.292929292929292, -0.4906091038701892, 0.2649155485290059, -0.4541111641669208, -0.08749106970030578, -0.04545586526836549], [9.393939393939394, -0.5220614661460425, 0.2155362266473772, -0.43168253981988763, -0.111310028285351, -0.0009102220987921503], [9.494949494949495, -0.5690730590517707, 0.23535537171199689, -0.40567501993782773, -0.11764441333020047, -0.014941932801744523], [9.595959595959595, -0.5765725666045367, 0.2534763800277013, -0.36164470921385944, -0.13951797614998335, 0.005196359938284163], [9.696969696969697, -0.5956849961001935, 0.20783039984739032, -0.3612987664781318, -0.14121301117163268, 0.025549945602495447], [9.797979797979798, -0.61676366066584, 0.24953729442731554, -0.33944788977692353, -0.1300733178847046, 0.05452637739529556], [9.8989898989899, -0.651615757829254, 0.24478597800176843, -0.355539392511711, -0.15826027265960896, 0.09134024771594504], [10.0, -0.6270237940231783, 0.22807847208384807, -0.36289733906548133, -0.13135612688964665, 0.06491193093623532]]}, \"id\": \"el100754534955024\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.3git.js\", function(){\n",
        "                 \n",
        "    mpld3.register_plugin(\"interactive_legend\", InteractiveLegend);\n",
        "    InteractiveLegend.prototype = Object.create(mpld3.Plugin.prototype);\n",
        "    InteractiveLegend.prototype.constructor = InteractiveLegend;\n",
        "    InteractiveLegend.prototype.requiredProps = [\"element_ids\", \"labels\"];\n",
        "    InteractiveLegend.prototype.defaultProps = {\"ax\":null,\n",
        "                                                \"alpha_sel\":1.0,\n",
        "                                                \"alpha_unsel\":0}\n",
        "    function InteractiveLegend(fig, props){\n",
        "        mpld3.Plugin.call(this, fig, props);\n",
        "    };\n",
        "\n",
        "    InteractiveLegend.prototype.draw = function(){\n",
        "        console.log(this);\n",
        "        var alpha_sel = this.props.alpha_sel;\n",
        "        var alpha_unsel = this.props.alpha_unsel;\n",
        "\n",
        "        var legendItems = new Array();\n",
        "        for(var i=0; i<this.props.labels.length; i++){\n",
        "            var obj = {};\n",
        "            obj.label = this.props.labels[i];\n",
        "\n",
        "            var element_id = this.props.element_ids[i];\n",
        "            mpld3_elements = [];\n",
        "            for(var j=0; j<element_id.length; j++){\n",
        "                var mpld3_element = mpld3.get_element(element_id[j], this.fig);\n",
        "\n",
        "                // mpld3_element might be null in case of Line2D instances\n",
        "                // for we pass the id for both the line and the markers. Either\n",
        "                // one might not exist on the D3 side\n",
        "                if(mpld3_element){\n",
        "                    mpld3_elements.push(mpld3_element);\n",
        "                }\n",
        "            }\n",
        "\n",
        "            obj.mpld3_elements = mpld3_elements;\n",
        "            obj.visible = false; // should become be setable from python side\n",
        "            legendItems.push(obj);\n",
        "        }\n",
        "        console.log(legendItems);\n",
        "\n",
        "        // determine the axes with which this legend is associated\n",
        "        var ax = this.props.ax\n",
        "        if(!ax){\n",
        "            ax = this.fig.axes[0];\n",
        "        } else{\n",
        "            ax = mpld3.get_element(ax, this.fig);\n",
        "        }\n",
        "\n",
        "        // add a legend group to the canvas of the figure\n",
        "        var legend = this.fig.canvas.append(\"svg:g\")\n",
        "                               .attr(\"class\", \"legend\");\n",
        "\n",
        "        // add the rectangles\n",
        "        legend.selectAll(\"rect\")\n",
        "                .data(legendItems)\n",
        "             .enter().append(\"rect\")\n",
        "                .attr(\"height\",10)\n",
        "                .attr(\"width\", 25)\n",
        "                .attr(\"x\",ax.width+10+ax.position[0])\n",
        "                .attr(\"y\",function(d,i) {\n",
        "                            return ax.position[1]+ i * 25 - 10;})\n",
        "                .attr(\"stroke\", get_color)\n",
        "                .attr(\"class\", \"legend-box\")\n",
        "                .style(\"fill\", function(d, i) {\n",
        "                            return d.visible ? get_color(d) : \"white\";})\n",
        "                .on(\"click\", click);\n",
        "\n",
        "        // add the labels\n",
        "        legend.selectAll(\"text\")\n",
        "                .data(legendItems)\n",
        "            .enter().append(\"text\")\n",
        "              .attr(\"x\", function (d) {\n",
        "                            return ax.width+10+ax.position[0] + 40;})\n",
        "              .attr(\"y\", function(d,i) {\n",
        "                            return ax.position[1]+ i * 25;})\n",
        "              .text(function(d) { return d.label });\n",
        "\n",
        "        // specify the action on click\n",
        "        function click(d,i){\n",
        "            d.visible = !d.visible;\n",
        "            d3.select(this)\n",
        "              .style(\"fill\",function(d, i) {\n",
        "                return d.visible ? get_color(d) : \"white\";\n",
        "              })\n",
        "\n",
        "            for(var i=0; i<d.mpld3_elements.length; i++){\n",
        "                var type = d.mpld3_elements[i].constructor.name;\n",
        "                if(type ==\"mpld3_Line\"){\n",
        "                    d3.select(d.mpld3_elements[i].path[0][0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else if((type==\"mpld3_PathCollection\")||\n",
        "                         (type==\"mpld3_Markers\")){\n",
        "                    d3.selectAll(d.mpld3_elements[i].pathsobj[0])\n",
        "                        .style(\"stroke-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel)\n",
        "                        .style(\"fill-opacity\",\n",
        "                                d.visible ? alpha_sel : alpha_unsel);\n",
        "                } else{\n",
        "                    console.log(type + \" not yet supported\");\n",
        "                }\n",
        "            }\n",
        "        };\n",
        "\n",
        "        // helper function for determining the color of the rectangles\n",
        "        function get_color(d){\n",
        "            var type = d.mpld3_elements[0].constructor.name;\n",
        "            var color = \"black\";\n",
        "            if(type ==\"mpld3_Line\"){\n",
        "                color = d.mpld3_elements[0].props.edgecolor;\n",
        "            } else if((type==\"mpld3_PathCollection\")||\n",
        "                      (type==\"mpld3_Markers\")){\n",
        "                color = d.mpld3_elements[0].props.facecolors[0];\n",
        "            } else{\n",
        "                console.log(type + \" not yet supported\");\n",
        "            }\n",
        "            return color;\n",
        "        };\n",
        "    };\n",
        "    \n",
        "                 mpld3.draw_figure(\"fig_el1007545349550245890167983\", {\"axes\": [{\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.80000000000000004, 0.40000000000000013], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565425488\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565426064\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565425552\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565431120\"}, {\"color\": \"#BF00BF\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"none\", \"zorder\": 2, \"alpha\": 0.1, \"xindex\": 0, \"linewidth\": 2, \"data\": \"data01\", \"id\": \"el100754565431504\"}], \"markers\": [{\"edgecolor\": \"#0000FF\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565425488pts\"}, {\"edgecolor\": \"#007F00\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565426064pts\"}, {\"edgecolor\": \"#FF0000\", \"facecolor\": \"#FF0000\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565425552pts\"}, {\"edgecolor\": \"#00BFBF\", \"facecolor\": \"#00BFBF\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565431120pts\"}, {\"edgecolor\": \"#BF00BF\", \"facecolor\": \"#BF00BF\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[-3.0, 3.0], [3.0, -3.0], [-3.0, -3.0], [3.0, 3.0]], [\"M\", \"L\", \"M\", \"L\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565431504pts\"}], \"id\": \"el100754534954512\", \"ydomain\": [-0.80000000000000004, 0.40000000000000013], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.54772727272727284, 0.77500000000000002, 0.35227272727272718]}, {\"xlim\": [0.0, 10.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 10.0], \"ylim\": [-0.80000000000000004, 0.40000000000000013], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754535761040pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565450320pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF0000\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565454992pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#00BFBF\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565455376pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#BF00BF\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 4.0], [1.0608124, 4.0], [2.078319483139414, 3.5785347663529667], [2.8284271247461903, 2.8284271247461903], [3.5785347663529667, 2.078319483139414], [4.0, 1.0608124], [4.0, 0.0], [4.0, -1.0608124], [3.5785347663529667, -2.078319483139414], [2.8284271247461903, -2.8284271247461903], [2.078319483139414, -3.5785347663529667], [1.0608124, -4.0], [0.0, -4.0], [-1.0608124, -4.0], [-2.078319483139414, -3.5785347663529667], [-2.8284271247461903, -2.8284271247461903], [-3.5785347663529667, -2.078319483139414], [-4.0, -1.0608124], [-4.0, 0.0], [-4.0, 1.0608124], [-3.5785347663529667, 2.078319483139414], [-2.8284271247461903, 2.8284271247461903], [-2.078319483139414, 3.5785347663529667], [-1.0608124, 4.0], [0.0, 4.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 0.1, \"xindex\": 0, \"data\": \"data01\", \"id\": \"el100754565455760pts\"}], \"id\": \"el100754535593936\", \"ydomain\": [-0.80000000000000004, 0.40000000000000013], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.12500000000000011, 0.77500000000000002, 0.35227272727272724]}], \"height\": 640.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}, {\"element_ids\": [[\"el100754565425488\", \"el100754565425488pts\", \"el100754535761040\", \"el100754535761040pts\"], [\"el100754565426064\", \"el100754565426064pts\", \"el100754565450320\", \"el100754565450320pts\"], [\"el100754565425552\", \"el100754565425552pts\", \"el100754565454992\", \"el100754565454992pts\"], [\"el100754565431120\", \"el100754565431120pts\", \"el100754565455376\", \"el100754565455376pts\"], [\"el100754565431504\", \"el100754565431504pts\", \"el100754565455760\", \"el100754565455760pts\"]], \"type\": \"interactive_legend\", \"labels\": [\"a\", \"b\", \"c\", \"d\", \"e\"], \"alpha_unsel\": 0.2, \"ax\": null, \"alpha_sel\": 1}], \"data\": {\"data01\": [[0.0, 0.04498483498573447, 0.013415618391208162, -0.03781283217083797, 0.01657867085915853, 0.027984465952350046], [0.10101010101010101, 0.08286561291620814, -0.006274344283376676, 0.0031115815359028867, 0.004106233645652713, 0.046251320740037696], [0.20202020202020202, 0.08462889086654593, -0.004405014418542352, 0.001905603098745802, -0.016747245677078682, 0.06231844133695727], [0.30303030303030304, 0.08046052325945521, -0.03201490298867826, -0.024267780749074607, -0.06138548186365861, 0.04130908352670372], [0.40404040404040403, 0.10615569227277122, -0.07886951519422267, -0.027637367370713973, -0.05139889456490856, 0.053621742749842244], [0.5050505050505051, 0.11798505922107959, -0.10417102386502092, -0.03283506351490713, -0.006619407802635029, 0.05294795084609232], [0.6060606060606061, 0.06821359668102932, -0.08402746855074125, -0.07246256237239958, -0.021225752877420484, 0.05428575784769638], [0.7070707070707071, 0.0923107938707093, -0.10382580175494008, -0.0902537214009236, -0.06553100579912144, 0.029371859895068166], [0.8080808080808081, 0.09192395930735557, -0.13865080939769636, -0.05991940861621911, -0.045662742445048615, 0.04726370015719486], [0.9090909090909091, 0.046577756156865796, -0.11673585567064781, -0.045393980377755376, -0.0449451358975531, 0.00793578861701675], [1.0101010101010102, 0.010567703868283887, -0.13197063784655347, -0.07426857387081359, -0.04001845903467363, -0.04053957290109891], [1.1111111111111112, 0.03888920299008304, -0.13656545424143435, -0.07989320477804913, -0.06500173737133319, -0.04305091953415979], [1.2121212121212122, 0.039257131976274964, -0.11445337823431564, -0.06486201627044666, -0.04643089255146062, -0.07346638711151368], [1.3131313131313131, 0.023048023825837184, -0.08703823133018172, -0.05956446717917627, -0.08927903838226087, -0.10916651634841942], [1.4141414141414141, -0.0012061442770730617, -0.13634752168349967, -0.042561023772302045, -0.08615410513612579, -0.1203224035290022], [1.5151515151515151, 0.026046038150575004, -0.1413344791503628, -0.07493090166331981, -0.08283846335932804, -0.11267565905632522], [1.6161616161616161, -0.006773674070703062, -0.10834038488678555, -0.10639886037300142, -0.12664729970906213, -0.152611574464107], [1.7171717171717171, -0.005329550192031585, -0.058943644665066325, -0.05906361041708699, -0.1201815727101598, -0.11714858556747501], [1.8181818181818181, 0.015248468567244756, -0.009676402680399404, -0.06208833354684963, -0.083668996654777, -0.1110747695763028], [1.9191919191919191, 0.0392900017050413, -0.027292617496800748, -0.0645279136765911, -0.05585490884520371, -0.09573758143868541], [2.0202020202020203, 0.03508361522101364, -0.014657819054050886, -0.08140078336622389, -0.08954763752822646, -0.04774340977195715], [2.121212121212121, -0.009793848727344137, 0.006715919700306166, -0.1181420028888292, -0.10497240915742552, -0.000316314333598966], [2.2222222222222223, -0.05829123190113897, 0.009615519411351975, -0.16364937821598463, -0.08009885334100245, -0.009389110891550733], [2.323232323232323, -0.048567801340425, 0.008023181379484106, -0.2089960852210617, -0.09342597775831211, -0.02594601503086804], [2.4242424242424243, -0.0411629538985145, -0.03959661780732253, -0.2522628135333969, -0.06253207525929286, -0.0288252821940128], [2.525252525252525, -0.0319896451694002, -0.015672817885402996, -0.25701816229286734, -0.10100536791246176, -0.06292819333618847], [2.6262626262626263, -0.023144420802859625, -0.049432737001133736, -0.23571542712707289, -0.07234897292186836, -0.08770813304637066], [2.727272727272727, -0.0016063020433686147, -0.022667827468076534, -0.2436597814733106, -0.10172005112910129, -0.0826145267626292], [2.8282828282828283, -0.03498600039896034, -0.047277700982779405, -0.22051231346130493, -0.1334514719973059, -0.09868654545912417], [2.929292929292929, -0.027631163162098796, 0.00010114326312218175, -0.21677647878655823, -0.0885034390809713, -0.14316615357079931], [3.0303030303030303, -0.022691034574502493, 0.03949112333481302, -0.2609789778776063, -0.059247136641237444, -0.10968697975252159], [3.131313131313131, -0.045589635481547756, 0.08688804981919145, -0.23717322380123138, -0.06205044111391133, -0.07125351470295839], [3.2323232323232323, -0.09100262035831552, 0.045461243041897775, -0.2563545754900074, -0.014746648252733495, -0.04045017046045862], [3.3333333333333335, -0.09131179572940087, 0.06621781353211587, -0.2510648429676208, 0.017424544440266587, -0.0764769344674974], [3.4343434343434343, -0.0655569651950515, 0.09903467693810117, -0.2737536292833842, 0.031817345619437144, -0.07032020776132356], [3.5353535353535355, -0.075741018147332, 0.13238738066791694, -0.3112869010761756, 0.0290765754294128, -0.11146214171655036], [3.6363636363636362, -0.10065928917837022, 0.11713454525359811, -0.3554614100965477, -0.019361947766785837, -0.07798964515685208], [3.7373737373737375, -0.1139888980206693, 0.09994506619621218, -0.3945788020964185, -0.0160117075936806, -0.06968024452708267], [3.8383838383838382, -0.14185650414165993, 0.1289649198948812, -0.38428709365205804, -0.061657471141079084, -0.057925669482712376], [3.9393939393939394, -0.15491775884545064, 0.09225702490911633, -0.4332547611632511, -0.028559954876581688, -0.06055435204955968], [4.040404040404041, -0.19066195959903512, 0.0719633552396089, -0.43024802262100165, -0.06553763355914703, -0.0873208957223432], [4.141414141414141, -0.20636576331734094, 0.07570681090100057, -0.4734309726744469, -0.0564633212286139, -0.05171437651498327], [4.242424242424242, -0.17443195862362462, 0.11898812371784478, -0.4630095226276546, -0.09314352856565987, -0.04933911889718013], [4.343434343434343, -0.20207407922265105, 0.08425620167738981, -0.42374474299443343, -0.117717863698525, -0.08297881317268782], [4.444444444444445, -0.22663627540695322, 0.050192096299283465, -0.39866410260425605, -0.09833102087078148, -0.12194456819126884], [4.545454545454545, -0.20795815729038744, 0.03708175969501183, -0.4345665829510054, -0.10974008583123114, -0.11751624210313422], [4.646464646464646, -0.24649859088715426, 0.0550212509569082, -0.46708570311146397, -0.06298200630515814, -0.15444491915135697], [4.747474747474747, -0.2789625116937272, 0.0071005049235357345, -0.5156025672440795, -0.04063427246792904, -0.1531474809276652], [4.848484848484849, -0.26773803447457456, 0.02855929830891897, -0.5363676970977338, -0.03695433257613451, -0.13593846799044243], [4.94949494949495, -0.22858691195641528, 0.04210819175001669, -0.5280405734285788, -0.06787083123012931, -0.17111525866676655], [5.05050505050505, -0.21887502291682231, 0.08931583415573938, -0.5417933704286835, -0.06069811514670498, -0.20618435543112895], [5.151515151515151, -0.1851547624073411, 0.09904247868561548, -0.5885028543114745, -0.07959265104769056, -0.16573554044493258], [5.252525252525253, -0.22813584321010302, 0.10936568095083063, -0.6020993568895565, -0.0840965413344567, -0.1728951290885727], [5.353535353535354, -0.18158660830663417, 0.11972267188679823, -0.5739609244925544, -0.10433946660713582, -0.13448815130454442], [5.454545454545454, -0.21736636765771478, 0.1429755823388231, -0.5381561230199845, -0.0816900589866927, -0.13717714012148294], [5.555555555555555, -0.17414818403972493, 0.09830219614168353, -0.5070388720413751, -0.04542384981535693, -0.16165304805090513], [5.656565656565657, -0.19255350888826012, 0.05145603261125429, -0.4833008409748218, -0.006280067919562836, -0.17422956132782622], [5.757575757575758, -0.23001986248134, 0.08169822428506335, -0.4930994386015815, -0.04506629107548034, -0.20006757589816732], [5.858585858585858, -0.2159772385418173, 0.08111518640929409, -0.46839077795509126, -0.03790444494988402, -0.23525887644614335], [5.959595959595959, -0.21212969846515203, 0.1258850649559528, -0.45224993599059693, -0.06516684387426336, -0.24213500439048602], [6.0606060606060606, -0.2544314976293923, 0.14863945602549436, -0.46226467812472755, -0.04549016307016583, -0.29196158023144875], [6.161616161616162, -0.27611349221318904, 0.13348104219972462, -0.43714627849616366, -0.038490696027065396, -0.2431412616361868], [6.262626262626262, -0.30017405928576396, 0.17452641108411615, -0.4648603128796377, -0.07762432741112277, -0.2623795393613294], [6.363636363636363, -0.3476851367204864, 0.17798228520502418, -0.48507229600279234, -0.06036132847024377, -0.26776407932635155], [6.4646464646464645, -0.32978112423718553, 0.1998127104502736, -0.4989570978604723, -0.11013490814526772, -0.2755719835896571], [6.565656565656566, -0.3403953433856838, 0.18061969799158528, -0.4846875662593255, -0.12291656463123293, -0.2485169289862538], [6.666666666666667, -0.3090739578652803, 0.18248955484335214, -0.474243300484984, -0.10423492028367579, -0.26399692113678086], [6.767676767676767, -0.26494770878007756, 0.1967191090619889, -0.46862136143999195, -0.11870698754135547, -0.23363797007696976], [6.8686868686868685, -0.2737400408180953, 0.16671292988253267, -0.4539060278458058, -0.1337327766608799, -0.25354649210211655], [6.96969696969697, -0.3236225406118457, 0.17654184010506976, -0.4404708155468108, -0.12104920247211136, -0.27004944375384454], [7.070707070707071, -0.3621753299256256, 0.1495526791982828, -0.42085125387288297, -0.16397346528762083, -0.29019404922127817], [7.171717171717171, -0.3515385086462672, 0.14623294980898427, -0.4224613266164565, -0.15505090017586637, -0.27702467807866643], [7.2727272727272725, -0.33382201288838087, 0.13872880742492188, -0.4239473124488232, -0.19246485964202104, -0.2657011493883885], [7.373737373737374, -0.3626930421161608, 0.16931578709766448, -0.4684721886767, -0.1696351965505163, -0.25859002590753677], [7.474747474747475, -0.3772193647023383, 0.20232436783789534, -0.4914108800812689, -0.15972286714197376, -0.23359713018414735], [7.575757575757575, -0.3485530627713764, 0.20097665872256096, -0.4505328100378987, -0.1992218927304731, -0.27225367244364734], [7.6767676767676765, -0.3613234331228465, 0.20397828339418442, -0.46804999528839797, -0.15104111416677543, -0.26258357225732], [7.777777777777778, -0.3417715622686577, 0.21227507665569892, -0.47968219438752363, -0.19356248009108726, -0.24914191434636135], [7.878787878787879, -0.3147069302854169, 0.1906301213674219, -0.44011101216249515, -0.19701607772458232, -0.25363177934032893], [7.979797979797979, -0.34125233642356195, 0.1558764134882634, -0.44253213566421645, -0.1690551082434381, -0.21657613349036822], [8.080808080808081, -0.37488135440507475, 0.11371565028624536, -0.47538850394658316, -0.12225521888776139, -0.22920613094008552], [8.181818181818182, -0.32749502076725023, 0.11326716411889041, -0.4638347131330166, -0.13075245331218008, -0.19807434251669306], [8.282828282828282, -0.3203988237134759, 0.14348476090098108, -0.47301844679276966, -0.14369851410118759, -0.17601957119603034], [8.383838383838384, -0.3296773993286675, 0.17538246902245777, -0.4242367562220675, -0.13365406621106726, -0.16662515411390214], [8.484848484848484, -0.32490877872691626, 0.22346837574561645, -0.4626804621475635, -0.14400866597201767, -0.1522362409790185], [8.585858585858587, -0.36179123100922794, 0.2518429376467052, -0.49319300170465835, -0.17452189797579465, -0.18563693321906266], [8.686868686868687, -0.36765236526999784, 0.2806425977677555, -0.5418389025195158, -0.17861303609395962, -0.14873258940349376], [8.787878787878787, -0.4081372568468698, 0.2880170516776693, -0.4934208397796425, -0.13207076505586787, -0.1122759311057569], [8.88888888888889, -0.3714302741193061, 0.28556940173389306, -0.48318622356162305, -0.09766686918298058, -0.15956287000991887], [8.98989898989899, -0.38112171890981356, 0.30266010897036355, -0.47234464440562446, -0.10951889181461122, -0.1146336329728965], [9.09090909090909, -0.4124400572611488, 0.31231643023075345, -0.43755698117046804, -0.10960028722263768, -0.08250564111077002], [9.191919191919192, -0.4594259962760907, 0.2704264762283102, -0.4571920906681531, -0.10291917646168319, -0.04004167683185514], [9.292929292929292, -0.4906091038701892, 0.2649155485290059, -0.4541111641669208, -0.08749106970030578, -0.04545586526836549], [9.393939393939394, -0.5220614661460425, 0.2155362266473772, -0.43168253981988763, -0.111310028285351, -0.0009102220987921503], [9.494949494949495, -0.5690730590517707, 0.23535537171199689, -0.40567501993782773, -0.11764441333020047, -0.014941932801744523], [9.595959595959595, -0.5765725666045367, 0.2534763800277013, -0.36164470921385944, -0.13951797614998335, 0.005196359938284163], [9.696969696969697, -0.5956849961001935, 0.20783039984739032, -0.3612987664781318, -0.14121301117163268, 0.025549945602495447], [9.797979797979798, -0.61676366066584, 0.24953729442731554, -0.33944788977692353, -0.1300733178847046, 0.05452637739529556], [9.8989898989899, -0.651615757829254, 0.24478597800176843, -0.355539392511711, -0.15826027265960896, 0.09134024771594504], [10.0, -0.6270237940231783, 0.22807847208384807, -0.36289733906548133, -0.13135612688964665, 0.06491193093623532]]}, \"id\": \"el100754534955024\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 6,
       "text": [
        "<IPython.core.display.HTML at 0x10e582110>"
       ]
      }
     ],
     "prompt_number": 6
    }
   ],
   "metadata": {}
  }
 ]
}
